import { DependencyContainer } from "tsyringe";

import { ConfigServer } from "@spt-aki/servers/ConfigServer";
import { ConfigTypes } from "@spt-aki/models/enums/ConfigTypes";
import { DatabaseServer } from "@spt-aki/servers/DatabaseServer";
import { IPostDBLoadMod } from "@spt-aki/models/external/IPostDBLoadMod";


class GigaChad implements IPostDBLoadMod {

    postDBLoad(container: DependencyContainer): void {
        const logger = container.resolve<ILogger>("WinstonLogger");
        const databaseServer = container.resolve<DatabaseServer>("DatabaseServer");
        const configServer = container.resolve<ConfigServer>("ConfigServer");

        const tables = databaseServer.getTables();
        const profiles = tables.templates.profiles;
        const traders = tables.traders;

		// unlock all quest-locked items
		for (let tid in traders) {
			let trader = traders[tid];
			if (trader.questassort!=null) {
				trader.questassort.success = {};
			}
		}

		profiles["GigaChad"] = {
			"bear": {
				"character": {
					"_id": "__REPLACEME__",
					"aid": "__REPLACEME__",
					"savage": "__REPLACEME__",
					"Info": {
						"Nickname": "__REPLACEME__",
						"LowerNickname": "__REPLACEME__",
						"Side": "Bear",
						"Voice": "__REPLACEME__",
						"Level": 50,
						"Experience": 5000000,
						"RegistrationDate": "__REPLACEME__",
						"GameVersion": "edge_of_darkness",
						"AccountType": 0,
						"MemberCategory": 0,
						"lockedMoveCommands": false,
						"SavageLockTime": 0,
						"LastTimePlayedAsSavage": 0,
						"Settings": {
							"Role": "assault",
							"BotDifficulty": "easy",
							"Experience": -1
						},
						"NicknameChangeDate": 0,
						"IsStreamerModeAvailable": false,
						"Bans": [],
						"BannedState": false,
						"BannedUntil": 0
					},
					"Customization": {
						"Head": "__REPLACEME__",
						"Body": "5cc0858d14c02e000c6bea66",
						"Feet": "5cc085bb14c02e000e67a5c5",
						"Hands": "5cc0876314c02e000c6bea6b"
					},
					"Health": {
						"Hydration": {
							"Current": 100,
							"Maximum": 100
						},
						"Energy": {
							"Current": 100,
							"Maximum": 100
						},
						"Temperature": {
							"Current": 36.6,
							"Maximum": 40
						},
						"BodyParts": {
							"Head": {
								"Health": {
									"Current": 35,
									"Maximum": 35
								}
							},
							"Chest": {
								"Health": {
									"Current": 85,
									"Maximum": 85
								}
							},
							"Stomach": {
								"Health": {
									"Current": 70,
									"Maximum": 70
								}
							},
							"LeftArm": {
								"Health": {
									"Current": 60,
									"Maximum": 60
								}
							},
							"RightArm": {
								"Health": {
									"Current": 60,
									"Maximum": 60
								}
							},
							"LeftLeg": {
								"Health": {
									"Current": 65,
									"Maximum": 65
								}
							},
							"RightLeg": {
								"Health": {
									"Current": 65,
									"Maximum": 65
								}
							}
						},
						"UpdateTime": 1608815684
					},
					"Inventory": {
						"items": [
							{
								"_id": "5fe49444ae6628187a2e77b8",
								"_tpl": "55d7217a4bdc2d86028b456d"
							},
							{
								"_id": "5fe49444ae6628187a2e78b9",
								"_tpl": "5963866286f7747bf429b572"
							},
							{
								"_id": "60dca3da42ad9b706b369aca",
								"_tpl": "602543c13fee350cd564d032"
							},
							{
								"_id": "5daff21fb5c244a4688fefac",
								"_tpl": "5cadfbf7ae92152ac412eeef",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "FirstPrimaryWeapon",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 97.80438
									},
									"FireMode": {
										"FireMode": "fullauto"
									}
								}
							},
							{
								"_id": "085fd238df0f6b8cb523b015",
								"_tpl": "576165642459773c7a400233",
								"parentId": "af06df24bdba4fffafc713b4",
								"slotId": "main",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 98.8364258
									},
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									}
								},
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "08c303bb789e0195ab0709f1",
								"_tpl": "5c0126f40db834002a125382",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "Scabbard",
								"upd": {
									"Repairable": {
										"MaxDurability": 85,
										"Durability": 85
									}
								}
							},
							{
								"_id": "8df328f95424ab99fddd463f",
								"_tpl": "5e00c1ad86f774747333222c",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "Headwear",
								"upd": {
									"Repairable": {
										"MaxDurability": 45,
										"Durability": 45
									}
								}
							},
							{
								"_id": "72f360237fe8ee1284961d95",
								"_tpl": "5648a69d4bdc2ded0b8b457b",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "TacticalVest"
							},
							{
								"_id": "cdd348f89973bce51ac19dc1",
								"_tpl": "5857a8bc2459772bad15db29",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "SecuredContainer"
							},
							{
								"_id": "b59e12548a20f3bff9c1786f",
								"_tpl": "5f5e467b0bc58666c37e7821",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "Backpack"
							},
							{
								"_id": "f9cdbb89ef373b56e9dda9ae",
								"_tpl": "5ab8e79e86f7742d8b372e78",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "ArmorVest",
								"upd": {
									"Repairable": {
										"MaxDurability": 65,
										"Durability": 65
									}
								}
							},
							{
								"_id": "f0df421189d216fd315fea3e",
								"_tpl": "627a4e6b255f7527fb05a0f6",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "Pockets"
							},
							{
								"_id": "e67d133484516735789c8467",
								"_tpl": "6033fa48ffd42c541047f728",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "Earpiece"
							},
							{
								"_id": "0bfc981e9527cae6e288fc8f",
								"_tpl": "5caf187cae92157c28402e43",
								"parentId": "5daff21fb5c244a4688fefac",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "ba2ebd13f9e44ad3aa9c8de1",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "5daff21fb5c244a4688fefac",
								"slotId": "mod_magazine"
							},
							{
								"_id": "4b3a46e451e32854c42f98d5",
								"_tpl": "5cdaa99dd7f00c002412d0b2",
								"parentId": "5daff21fb5c244a4688fefac",
								"slotId": "mod_handguard"
							},
							{
								"_id": "f5a6a2a4344bfbb748ab894a",
								"_tpl": "6171407e50224f204c1da3c5",
								"parentId": "5daff21fb5c244a4688fefac",
								"slotId": "mod_scope"
							},
							{
								"_id": "dd53750403b430f7be3ec626",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "5daff21fb5c244a4688fefac",
								"slotId": "mod_tactical_002",
								"upd": {
									"Light": {
										"IsActive": false,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "6d181309b9a353d7455f1c06",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "5daff21fb5c244a4688fefac",
								"slotId": "patron_in_weapon"
							},
							{
								"_id": "444029a202f5ce2ee2850b6d",
								"_tpl": "591ee00d86f774592f7b841e",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_mount_000"
							},
							{
								"_id": "94b6249b17f352924d2979f0",
								"_tpl": "5f63418ef5750b524b45f116",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_handguard"
							},
							{
								"_id": "293b574ded89301e7f1a8c29",
								"_tpl": "59fb137a86f7740adb646af1",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "8ffcafd0ad5663f289b1a427",
								"_tpl": "5649ade84bdc2d1b2b8b4587",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_pistol_grip"
							},
							{
								"_id": "df49f93ad674e36163bdc63c",
								"_tpl": "57616c112459773cce774d66",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_reciever"
							},
							{
								"_id": "7436ea794321e92041e377e6",
								"_tpl": "57a9b9ce2459770ee926038d",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_sight_rear",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "1d295f6767e5513ea792404d",
								"_tpl": "57616ca52459773c69055192",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_stock"
							},
							{
								"_id": "8feda48615b1586ce64e8736",
								"_tpl": "5cf8f3b0d7f00c00217872ef",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_magazine"
							},
							{
								"_id": "76fe21224910d039b8c5eba0",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "patron_in_weapon"
							},
							{
								"_id": "05d7508cd30ca12d7e0bd12e",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "1",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "0fbefce31c5d8c749ddfa132",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "2",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "dfd0297db3b09e0037b147ba",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "3",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "c704ac1dcd0addd0dd6a8bbd",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "4",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "e835107b518e71f78cd058e2",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "5",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "660966aa5debb0e4c0b97d66",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "5",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "6e3eb18536bee2eaac687931",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "8",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "49dcb77c6d797cc1ed4d1480",
								"_tpl": "5e8488fa988a8701445df1e4",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "9",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"MedKit": {
										"HpResource": 3
									}
								}
							},
							{
								"_id": "e54403d5202f89f7e7df1c96",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "10",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "77512f3237c4e3970eda3889",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "11",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "2ce1f3af873078bee3041b48",
								"_tpl": "619cbf7d23893217ec30b689",
								"parentId": "cdd348f89973bce51ac19dc1",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "30af2f339c3d9e5fbab39e33",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "cdd348f89973bce51ac19dc1",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "4fc414af7fd108a5ccbe0ef7",
								"_tpl": "5755383e24597772cb798966",
								"parentId": "cdd348f89973bce51ac19dc1",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"MedKit": {
										"HpResource": 6
									}
								}
							},
							{
								"_id": "a10a45ccc990feb252b2cbab",
								"_tpl": "5af0454c86f7746bf20992e8",
								"parentId": "cdd348f89973bce51ac19dc1",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"MedKit": {
										"HpResource": 5
									}
								}
							},
							{
								"_id": "78e18bb2725891a10d8a5d4d",
								"_tpl": "61605e13ffa6e502ac5e7eef",
								"parentId": "f0df421189d216fd315fea3e",
								"slotId": "SpecialSlot1"
							},
							{
								"_id": "f3e702352faef0766f9e20de",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "f0df421189d216fd315fea3e",
								"slotId": "pocket4",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "e35e53b553b2280edde8863c",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "ba2ebd13f9e44ad3aa9c8de1",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "9195da2e7fbfea3568a5eeae",
								"_tpl": "5a7dbfc1159bd40016548fde",
								"parentId": "4b3a46e451e32854c42f98d5",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "fbe85aa90576f3840f013f8c",
								"_tpl": "5b3b99475acfc432ff4dcbee",
								"parentId": "f5a6a2a4344bfbb748ab894a",
								"slotId": "mod_scope_000",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											1
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "a215128785324188a73f22dc",
								"_tpl": "577d128124597739d65d0e56",
								"parentId": "f5a6a2a4344bfbb748ab894a",
								"slotId": "mod_scope_001"
							},
							{
								"_id": "45ccf52a98d105feb25f4d84",
								"_tpl": "577d141e24597739c5255e01",
								"parentId": "a215128785324188a73f22dc",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "9d8377f2fb367a23b7763172",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "444029a202f5ce2ee2850b6d",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "8281584f2068a24a33a18c9c",
								"_tpl": "5b3a337e5acfc4704b4a19a0",
								"parentId": "444029a202f5ce2ee2850b6d",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": false,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "235a1e6f37825bef846e9e55",
								"_tpl": "5b057b4f5acfc4771e1bd3e9",
								"parentId": "94b6249b17f352924d2979f0",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "4b28243b6ce791043e27e8a2",
								"_tpl": "5a7b483fe899ef0016170d15",
								"parentId": "94b6249b17f352924d2979f0",
								"slotId": "mod_tactical_000",
								"upd": {
									"Light": {
										"IsActive": false,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "a0b15568257164f43ea7070d",
								"_tpl": "5b3a337e5acfc4704b4a19a0",
								"parentId": "94b6249b17f352924d2979f0",
								"slotId": "mod_tactical_001",
								"upd": {
									"Light": {
										"IsActive": false,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "7d08c8e95553d6023af32681",
								"_tpl": "5b3a337e5acfc4704b4a19a0",
								"parentId": "94b6249b17f352924d2979f0",
								"slotId": "mod_tactical_002",
								"upd": {
									"Light": {
										"IsActive": false,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "784c6c1d5d7c8dd3454ea202",
								"_tpl": "5b3a337e5acfc4704b4a19a0",
								"parentId": "94b6249b17f352924d2979f0",
								"slotId": "mod_tactical_003",
								"upd": {
									"Light": {
										"IsActive": false,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "f6b6b12ff839e61d0b9a1815",
								"_tpl": "5b3a337e5acfc4704b4a19a0",
								"parentId": "94b6249b17f352924d2979f0",
								"slotId": "mod_tactical_004",
								"upd": {
									"Light": {
										"IsActive": false,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "1e57b3031fcc41cf18af2e90",
								"_tpl": "5a0c59791526d8dba737bba7",
								"parentId": "1d295f6767e5513ea792404d",
								"slotId": "mod_stock"
							},
							{
								"_id": "512808e2bc2d4633357096e7",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "8feda48615b1586ce64e8736",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "158d907ed0c1105a983da9ec",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "05d7508cd30ca12d7e0bd12e",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "1c0149ab91859bf35d4fcb28",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "0fbefce31c5d8c749ddfa132",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "e2622d13948df3c7c768038e",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "dfd0297db3b09e0037b147ba",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 13
								}
							},
							{
								"_id": "85179f750a46bd93a0667a14",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "c704ac1dcd0addd0dd6a8bbd",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "9c5cd6884592a977b363c6f3",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "e835107b518e71f78cd058e2",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "1aa6da43bbf54f963ae6b6ce",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "660966aa5debb0e4c0b97d66",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "91d2c8150051434785e982db",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "e54403d5202f89f7e7df1c96",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "cb6f8ade13378d9a7ca47817",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "13a93f7bc96a997bf801fc39",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "14aefc59dee7d96071424479",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "ef10316d461c00fb0ec23fb4",
								"_tpl": "5c0e531d86f7747fa23f4d42",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "da83962bcca7a6ce00fd64e3",
								"_tpl": "5c0e530286f7747fa1419862",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "8541fb08db69fe8b1b7ac4fa",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "add48490272037e6cbef57cc",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "8fbe2d99c247ba6b55adf2c8",
								"_tpl": "5c0e534186f7747fa1419867",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "7a4f54d3a4b38ffc942816b6",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "5fe49444ae6628187a2e78b8",
								"_tpl": "5811ce772459770e9e5f9532"
							},
							{
								"_id": "5fe49444ae6628187a2e78ba",
								"_tpl": "5963866b86f7747bfa1c4462"
							},
							{
								"_id": "5696e09b3448d14b8ad1f3e9",
								"_tpl": "569668774bdc2da2298b4568",
								"parentId": "98dcde79bc426a2b045ae19c",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 50000
								}
							},
							{
								"_id": "bb363db77d34926599d768f0",
								"_tpl": "59fb016586f7746d0d4b423a",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "b20df6cea32bf80c0001b99e",
								"_tpl": "5d235bb686f77443f4331278",
								"parentId": "9ebe7b2d496ce22c63be8525",
								"slotId": "2",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": "Reserve"
									}
								}
							},
							{
								"_id": "294e09e971ddf3e4e255218e",
								"_tpl": "59fb042886f7746c5005a7b2",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 19,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": ""
									}
								}
							},
							{
								"_id": "bbc30f508bed374aa0fe4d9e",
								"_tpl": "59fb042886f7746c5005a7b2",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 19,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": "Head gear"
									}
								}
							},
							{
								"_id": "d58bf4cc06ff1c1e56c804fe",
								"_tpl": "5aafbcd986f7745e590fff23",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": "Kits"
									}
								}
							},
							{
								"_id": "f320a05e44b55f269a28d835",
								"_tpl": "5c093db286f7740a1b2617e3",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": "Drinks"
									}
								}
							},
							{
								"_id": "b5394050928646602c4428fb",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "7412803b2647102af46de246",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "f48af07392c06188bbe67ceb",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "5532d43fdecaf4edce0edce9",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "54b42ca4e1c09091153b2779",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "6459b766b9422e3dc8906110",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "2e1b4f7c47ce7b50f1e6c38f",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "cd1d9f78e48931e91a9da9df",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "0175e00a717f38c307044b0e",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "68eb83d2ce59457b1bf031ab",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "eb297d821b714a2b22c03e20",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "2b0540a456546e39c383a429",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "d6c706e6d66e8749b05f9156",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "72648cfbc90c377f0e0fa4b0",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "2ef955a3de47d821879d802a",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "aebecf23b4841fe34208f525",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8ece6624620faa5ebcc895c7",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 334
									}
								}
							},
							{
								"_id": "616b287cb731842d736e3a6f",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "bc0d3ae634568fd321db38ca",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "795fb2352d6f2d5a3f5f8ab4",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "f7dfb944a241fc31a4d066dd",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "a0f715e41811cf297561211c",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "95eb87e5574eae56aefe55d4",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "3f9ad7b4c8e69da081c2bbb9",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "221a865e8819ca5bf8000a87",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "747fec673e985457853f6169",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "abfeac2975d9fa076ad748ec",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "93766b5b020dae6ad0c2be14",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d45b47ee5d34a052189fc0dd",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "01614a0ad8f3ec40038019d0",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5077a50e85fcf5fc8dd6ca0c",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "685bee94d717ac6cb841645d",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0f3a01265fce96742b2fc2f4",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5728340149abb8be258098d2",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0fe374cf705e8f39c995a5f9",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ec56f17fc492b727b6eab5f3",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e7c0f9563f6b37f6d8c31a07",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "91e8fa35eaa0135136d7879b",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7952fb3ff929a545d4ea1f29",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2534720351a8316536183a1e",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "93ba38305ab2576eddcf0da8",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b2a367cbb17d04ebe2ed21f1",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f73a89a4d554d77adf39adfc",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4a2ad8f851785baf08912635",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "995382bfbc38d7a83b77ae8d",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7ac2908181192977e25c5043",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2cf68d7ae9130b486a75ba8f",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c6b37c914ccb7d6ae3402a22",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0604d70ae224692bde23a43f",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d17f3eafb09c0febad7c000a",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "24b94e795ecd81ee06069b1e",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f6347c5d41377af39b164481",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "75c385eb78c5f502c55b1852",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "090333ae995362b8351a4d63",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f497279f27742e7d85f6d32d",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "963970562c716ebfb37560e8",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c845614e52eb9f62eaf8185c",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a7b3a8eb864d17ab103555a7",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1cedc365cb47abab2a815d5f",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "072c601499b7cb51ef2f320a",
								"_tpl": "628e4e576d783146b124c64d",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "395e577551fc114e3bd7f6a0",
								"_tpl": "628e4e576d783146b124c64d",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2bbe9b21e5453d236e8ac2c8",
								"_tpl": "6033fa48ffd42c541047f728",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9d3545f74260002ba99f281c",
								"_tpl": "6033fa48ffd42c541047f728",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "da24e3d047f2f2ca7482f705",
								"_tpl": "5e00c1ad86f774747333222c",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e82614e65846a38e6d775e26",
								"_tpl": "5e00c1ad86f774747333222c",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9065104db0dd85f3db288ea8",
								"_tpl": "5ab8e79e86f7742d8b372e78",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "63692f1e268d06fcbd1375e2",
								"_tpl": "5ab8e79e86f7742d8b372e78",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cf70e23b122d7f020293a126",
								"_tpl": "5e2af55f86f7746d4159f07c",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "7fb3e6cf4b3f9139a2a8628d",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "0ca979353cdd6966a43aae25",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "19eb30ae524641d49ac4ecba",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "222de4b3db5a9c2d330e6692",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "9ef27104d0a5f8b9a0216bf6",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "52c36b67c245273dcb08b343",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8a747ef284e2cb4c739dcfdc",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "6d9ed817307aceb6565534b9",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "c875176952b8743a0bd154e8",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "43339dab09d84ba540a280b1",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "3332239a9ffec32ef7c02000",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "69ebdc19c82e889dfc0e99be",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "eb1d63b6e9273e0759735eea",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "f5501a557a566f414e3dccef",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "553b62ddc696807e9033e8ae",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8034f52b196b776f29a9609b",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "13cb6f91112c93554ee01eda",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "29ebe7d2e0587c00d4ffe4c4",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "42955af40e8b919e0804cff6",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "cdfc5e830addbc66d9da57d4",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "cf3a9815171b5a303892d59c",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "49635a941fe4f42d4da142ef",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "7256e25e1acea7caa43ac81a",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "5eac21b7df325aa5e1a9043d",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "1bc8b2c377942676a70fcc75",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "373a07dd99d53e717051a7d2",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8f27aca9a66685d3a9e6e924",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "2e989ccfc06b2ec231cc11e7",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8072e31d8940b7375573acdb",
								"_tpl": "5910968f86f77425cf569c32",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "81d6b0ba8d55d99ac1765d4a",
								"_tpl": "591094e086f7747caa7bb2ef",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "82b6f2edbcc846f8fc77108d",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Other"
									}
								}
							},
							{
								"_id": "8f1d8e5f96d933f306a79b5e",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 2,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "762x39"
									}
								}
							},
							{
								"_id": "38914e925722c0bd710283ba",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 6,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "762x51"
									}
								}
							},
							{
								"_id": "08616521e6794e5f812fe4b1",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "556x45"
									}
								}
							},
							{
								"_id": "1cb12514507b72446601028d",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": ".45"
									}
								}
							},
							{
								"_id": "e16dee62f9d7483fd0beb908",
								"_tpl": "5b6d9ce188a4501afc1b2b25",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 14,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Assault Rifles"
									}
								}
							},
							{
								"_id": "af06df24bdba4fffafc713b4",
								"_tpl": "5b6d9ce188a4501afc1b2b25",
								"slotId": "hideout",
								"location": {
									"x": 5,
									"y": 14,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Other"
									}
								}
							},
							{
								"_id": "984d6454f5797cb1e1060315",
								"_tpl": "5b7c710788a4506dec015957",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 23,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "37acef9c25cb283bf0313b0c",
								"_tpl": "5b7c710788a4506dec015957",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 23,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7d94997370b1fddae46da869",
								"_tpl": "5c093e3486f77430cb02e593",
								"slotId": "7",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "600951b8f6a2da6ae32c4424",
								"_tpl": "5c0a840b86f7742ffa4f2482",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 16,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Armor & Rigs"
									}
								}
							},
							{
								"_id": "b330c2a8b154d6401ab7afa1",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Other"
									}
								}
							},
							{
								"_id": "f5b916fc823e3f79bf4d82fc",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 2,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "762x39"
									}
								}
							},
							{
								"_id": "d82ef485d9095b4208e1147e",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "556x45"
									}
								}
							},
							{
								"_id": "b7af0761d04c91ff0bccea8d",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 6,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "762x51"
									}
								}
							},
							{
								"_id": "30305c344a2eaaf517de854a",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": ".45"
									}
								}
							},
							{
								"_id": "24442780538965a0eec3ae85",
								"_tpl": "5696686a4bdc2da3298b456a",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "98dcde79bc426a2b045ae19c",
								"upd": {
									"StackObjectsCount": 50000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1ad7e8f05bcb7345a08da9f5",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "49f2afe2fc23ca45af6e7567",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "dee59a401920a88acc1d9727",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c8b5f2925c3a4a96a12e9bfd",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "840cd785b5b6f5b971907974",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "56d5ba5a34a72c31affbfca8",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "176ee840f2622896747e4fd5",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "134309998dcfbf8639698b26",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0a11e27909cbc5fcbd478fac",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"parentId": "2c9bf00b11854cbc165b2264",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 250000
								}
							},
							{
								"_id": "b37d2af121d07432c2d38106",
								"_tpl": "5c0a840b86f7742ffa4f2482",
								"slotId": "hideout",
								"location": {
									"x": 5,
									"y": 16,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Backpacks"
									}
								}
							},
							{
								"_id": "5d9901441bd6291b1ab9b5cc",
								"_tpl": "5a0dc45586f7742f6b0b73e3",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7d95c6290f56de04baa99a0b",
								"_tpl": "5a0dc95c86f77452440fc675",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8f55c8bb721609c7f6f09a0d",
								"_tpl": "5a0eb6ac86f7743124037a28",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0d72532894bcbf9f2827155d",
								"_tpl": "61a64428a8c6aa1b795f0ba1",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e6e3db327e732e0e6f6e1a5",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fc9b9d3b7a70b55270d8b782",
								"_tpl": "5a0ea64786f7741707720468",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b29c2695c6e86b420e4d2801",
								"_tpl": "5a144dfd86f77445cb5a0982",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6427507b3992ed3a585623ab",
								"_tpl": "5a0ee30786f774023b6ee08f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ca50f8e08ee8fe4ec6ed48a3",
								"_tpl": "5a13eebd86f7746fd639aa93",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2e770672b2a4a9a8916ee277",
								"_tpl": "5a0f0f5886f7741c4e32a472",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "89d546c9619e0cf1f45adb05",
								"_tpl": "5a0f08bc86f77478f33b84c2",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9e37d8bb6b7e47b01851113e",
								"_tpl": "5a144bdb86f7741d374bbde0",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "241bf167974f6b8b6370a0b9",
								"_tpl": "5a13f35286f77413ef1436b0",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a1a5c915a6470a3bfadef290",
								"_tpl": "5a0ee34586f774023b6ee092",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e42c0fca0b0eff6268d52fdc",
								"_tpl": "5a13ef7e86f7741290491063",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fe9109dad6d0d99407659b4e",
								"_tpl": "5a145d4786f7744cbb6f4a12",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0a4aedd1d53114e3536600d8",
								"_tpl": "5a0eec9686f77402ac5c39f2",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "de53dc2746df3b52a6af9f98",
								"_tpl": "5a13f46386f7741dd7384b04",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0b55ff79ad9599ac0c156004",
								"_tpl": "5a0eff2986f7741fd654e684",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c5e92405dbb83d1d30465f01",
								"_tpl": "5a0eecf686f7740350630097",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6cdffcc905f27fd64f6774dc",
								"_tpl": "5a145ebb86f77458f1796f05",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8e2acf36650eca594aa6c0cb",
								"_tpl": "591382d986f774465a6413a7",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "580f9e7a3268b42ccb47737e",
								"_tpl": "5780cf7f2459777de4559322",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1f1cdddce92f2f2b44b8d82f",
								"_tpl": "59148c8a86f774197930e983",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b282c376b0b0d8f2a9ff3b7b",
								"_tpl": "5780d0652459777df90dcb74",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b2947a5e31d6c626a38bf026",
								"_tpl": "5913877a86f774432f15d444",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "989510b5a06cc37093882f00",
								"_tpl": "5a0f045e86f7745b0f0d0e42",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7bca3772728527f0aa48765a",
								"_tpl": "59387a4986f77401cc236e62",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "02d147754e0384a3b63ed3c6",
								"_tpl": "5448ba0b4bdc2d02308b456c",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ac39fb11fd7e838f0906bd98",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a2d3e036139a48ab06e03619",
								"_tpl": "5780cf942459777df90dcb72",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b7afa3d02c2589bc3d75a5eb",
								"_tpl": "5ad5d7d286f77450166e0a89",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "88fd974874140b1df3f51df1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8965e945a96e9fcfa0b73d10",
								"_tpl": "5addaffe86f77470b455f900",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "88fd974874140b1df3f51df1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a40c5963105df97621b395fa",
								"_tpl": "5ad5cfbd86f7742c825d6104",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "88fd974874140b1df3f51df1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "131f55d24267654fc0287bf0",
								"_tpl": "5ad5db3786f7743568421cce",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "88fd974874140b1df3f51df1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "84b1f6dab28f4cb390925c73",
								"_tpl": "5ad7247386f7747487619dc3",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "88fd974874140b1df3f51df1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8886931b5daec121aa88ea7c",
								"_tpl": "5ad5d64486f774079b080af8",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "88fd974874140b1df3f51df1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5c5582fc4d2d090a74a5b0e6",
								"_tpl": "5c1d0f4986f7744bb01837fa",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0ab18b0f74552b30dce25273",
								"_tpl": "5c1d0c5f86f7744bb2683cf0",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "dff741673c098381e007fbfe",
								"_tpl": "5efde6b4f5448336730dbd61",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b176da258c2ba5c95683432c",
								"_tpl": "5eff09cd30a7dc22fd1ddfed",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7f9c0dceb3951640fb67ab7c",
								"_tpl": "5c1d0dc586f7744baf2e7b79",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d5bf90ab86ac485af39bc721",
								"_tpl": "5c1d0efb86f7744baf2e7b7b",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6c3165cbd3212bfaf0f2211c",
								"_tpl": "5c1f79a086f7746ed066fb8f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c55021500a33f91b71be5c5e",
								"_tpl": "5c1e2d1f86f77431e9280bee",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "08baa94b3ea456904dde2990",
								"_tpl": "5c1e2a1e86f77431ea0ea84c",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "791cf7a991ba67aae7ad81ef",
								"_tpl": "5d80cb3886f77440556dbf09",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a88eaad59e11b43b8e76079e",
								"_tpl": "5d95d6fa86f77424484aa5e9",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c5a0bb0fa16a9f130f7caf2f",
								"_tpl": "5d80c62a86f7744036212b3f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9692eaa3bb42c0c50fd867b4",
								"_tpl": "5d80c60f86f77440373c4ece",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9b74d64f690e74d8d52f835f",
								"_tpl": "5d8e0e0e86f774321140eb56",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0a4da330e04aefee521041b6",
								"_tpl": "5d947d4e86f774447b415895",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "df82a0b1bdeec3714e43617d",
								"_tpl": "5d80c6c586f77440351beef1",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "31f06963f8afd9458a95ffc5",
								"_tpl": "5d80ccac86f77470841ff452",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6bc2e0526866931c18f25127",
								"_tpl": "5d80ccdd86f77474f7575e02",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6c9ce8c8c95111f215b84a2c",
								"_tpl": "5d80cd1a86f77402aa362f42",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6fe2bdd75373f0bc821bfcfa",
								"_tpl": "5d947d3886f774447b415893",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "87b557496369960aad4a2f48",
								"_tpl": "5d9f1fa686f774726974a992",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7d4c5a0b3a1aa896863a5bf0",
								"_tpl": "591afe0186f77431bd616a11",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ac39fb11fd7e838f0906bd98",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b93123909be3e0fcb9435d5c",
								"_tpl": "62987c658081af308d7558c6",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e6e3db327e732e0e6f6e1a5",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "474601c5b6eaecf46c097d6c",
								"_tpl": "62987da96188c076bc0d8c51",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e6e3db327e732e0e6f6e1a5",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8bb42b0696c8aa87bf83833f",
								"_tpl": "62987dfc402c7f69bf010923",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e6e3db327e732e0e6f6e1a5",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "97bd12ba3fa7e629697b7c02",
								"_tpl": "5448ba0b4bdc2d02308b456c",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6e6e3db327e732e0e6f6e1a5",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "3",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Lighthouse"
									}
								}
							},
							{
								"_id": "a4842b5e3961422bd8acbd72",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "1",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Shoreline"
									}
								}
							},
							{
								"_id": "88fd974874140b1df3f51df1",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "2",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Interchange"
									}
								}
							},
							{
								"_id": "e24de543182a4c82e7ad17b2",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "4",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Labs"
									}
								}
							},
							{
								"_id": "478d50784d1624e0c6ea025b",
								"_tpl": "5c94bbff86f7747ee735c08f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b2f22e3b6e8d959c4dd8bcce",
								"_tpl": "5c94bbff86f7747ee735c08f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9abd067eae867b52c54ca24b",
								"_tpl": "5c94bbff86f7747ee735c08f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "51ddc35570670b417b69c94b",
								"_tpl": "5c94bbff86f7747ee735c08f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bb25a063d9350ac5a2271d08",
								"_tpl": "5c94bbff86f7747ee735c08f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ae739c40213c1aa034d94d00",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "5",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Streets"
									}
								}
							},
							{
								"_id": "ac39fb11fd7e838f0906bd98",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "6",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Other"
									}
								}
							},
							{
								"_id": "2c9bf00b11854cbc165b2264",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "1",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Customs"
									}
								}
							},
							{
								"_id": "9ebe7b2d496ce22c63be8525",
								"_tpl": "5e9db13186f7742f845ee9d3",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "98dcde79bc426a2b045ae19c",
								"_tpl": "59fb016586f7746d0d4b423a",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 2,
									"y": 0,
									"r": 1
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "acdf382a7b0a4aaf4bdf58a4",
								"_tpl": "5c093db286f7740a1b2617e3",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": "Food"
									}
								}
							},
							{
								"_id": "866565f1635d3afdefbe487b",
								"_tpl": "5aafbcd986f7745e590fff23",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 7,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0,
									"Tag": {
										"Color": 0,
										"Name": "Misc"
									}
								}
							},
							{
								"_id": "51023c6a29c60e2fbdaffaa7",
								"_tpl": "59fb016586f7746d0d4b423a",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "94d293b2ab205cab3214e294",
								"_tpl": "59fb016586f7746d0d4b423a",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "5b4da63a79e4b589697dc405",
								"_tpl": "59fb023c86f7746d0d4b423c",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 19,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "eef1491a8278785ca583f724",
								"_tpl": "59fb023c86f7746d0d4b423c",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 24,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "86c755f233755987a7c9e08e",
								"_tpl": "5b0bbe4e5acfc40dc528a72d",
								"parentId": "e16dee62f9d7483fd0beb908",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "1e84939d3c617732e95517be",
								"_tpl": "5b7bedd75acfc43d825283f9",
								"parentId": "86c755f233755987a7c9e08e",
								"slotId": "mod_handguard",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "2b95508afe52bdeaada794d9",
								"_tpl": "5cf78720d7f00c06595bc93e",
								"parentId": "13461f18b080cb706587eedb",
								"slotId": "mod_muzzle_001",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "5b0211fca1c5227a07ad1314",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "cc44adadd9cc93d4a06fd9b1",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "630fbf12d011d67a339eff5c",
								"_tpl": "5b7d679f5acfc4001a5c4024",
								"parentId": "86c755f233755987a7c9e08e",
								"slotId": "mod_pistol_grip",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "c3b22d97167740c9135fb15c",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "f27397deeda98ceba571c783",
								"slotId": "mod_tactical",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "13461f18b080cb706587eedb",
								"_tpl": "5cf78496d7f00c065703d6ca",
								"parentId": "aa259add23daa29cfd5277dd",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "aa259add23daa29cfd5277dd",
								"_tpl": "5b7be1265acfc400161d0798",
								"parentId": "86c755f233755987a7c9e08e",
								"slotId": "mod_barrel",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "cb385e1a736b372fc833ba40",
								"_tpl": "5c878e9d2e2216000f201903",
								"parentId": "13461f18b080cb706587eedb",
								"slotId": "mod_muzzle_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "cc44adadd9cc93d4a06fd9b1",
								"_tpl": "5b099bb25acfc400186331e8",
								"parentId": "86c755f233755987a7c9e08e",
								"slotId": "mod_reciever",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "f27397deeda98ceba571c783",
								"_tpl": "5b7be4575acfc400161d0832",
								"parentId": "1e84939d3c617732e95517be",
								"slotId": "mod_mount_001",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 8,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "a2177dbca83c1eca0be882ed",
								"_tpl": "5c1cd46f2e22164bef5cfedb",
								"parentId": "3d99f271f3637fb65014d95b",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "3d99f271f3637fb65014d95b",
								"_tpl": "5b7be46e5acfc400170e2dcf",
								"parentId": "1e84939d3c617732e95517be",
								"slotId": "mod_mount_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 6,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "a433ea0a16c0f7f996f1e50e",
								"_tpl": "5b7d37845acfc400170e2f87",
								"parentId": "86c755f233755987a7c9e08e",
								"slotId": "mod_magazine",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "db1d6cf49e973022b79ef237",
								"_tpl": "5b099bf25acfc4001637e683",
								"parentId": "86c755f233755987a7c9e08e",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "5b6e9ef196f62767c62c48d4",
								"_tpl": "58d2947e86f77447aa070d53",
								"parentId": "0cac2dd889e34f46bccad70c",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "37cf9e19ed04f32785e64492",
								"_tpl": "58d2912286f7744e27117493",
								"parentId": "5b6e9ef196f62767c62c48d4",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "0cac2dd889e34f46bccad70c",
								"_tpl": "5c793fb92e221644f31bfb64",
								"parentId": "db1d6cf49e973022b79ef237",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "00eb4b8817192d411b9b9bb0",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "a433ea0a16c0f7f996f1e50e",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 29
								}
							},
							{
								"_id": "7ff6d96b9019e7a213ca41ce",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "86c755f233755987a7c9e08e",
								"slotId": "patron_in_weapon",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "513134ef4a80321a48a9ff3f",
								"_tpl": "5fc3e272f8b6a877a729eac5",
								"parentId": "af06df24bdba4fffafc713b4",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 8,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "919a5003861c3333895d09f0",
								"_tpl": "5fc3e466187fea44d52eda90",
								"parentId": "513134ef4a80321a48a9ff3f",
								"slotId": "mod_magazine",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "ecf8fa76cc591130c9608fce",
								"_tpl": "5fc3e4ee7283c4046c5814af",
								"parentId": "513134ef4a80321a48a9ff3f",
								"slotId": "mod_stock",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "1944b2a3400c117e2f64e10d",
								"_tpl": "5fc3e4a27283c4046c5814ab",
								"parentId": "513134ef4a80321a48a9ff3f",
								"slotId": "mod_barrel",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "9ec803ce8802521c32ef4e71",
								"_tpl": "5fc53954f8b6a877a729eaeb",
								"parentId": "513134ef4a80321a48a9ff3f",
								"slotId": "mod_mount_000",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "5b4e2b44b001e838c2e87c45",
								"_tpl": "5fc5396e900b1d5091531e72",
								"parentId": "513134ef4a80321a48a9ff3f",
								"slotId": "mod_mount_001",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "58664a86f17750b9e1a907e3",
								"_tpl": "5fc5396e900b1d5091531e72",
								"parentId": "513134ef4a80321a48a9ff3f",
								"slotId": "mod_mount_002",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "b19333fc0405959b05d1ea5c",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "513134ef4a80321a48a9ff3f",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "ea510733b6e9310350910b40",
								"_tpl": "6130c4d51cb55961fa0fd49f",
								"parentId": "1944b2a3400c117e2f64e10d",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "eede16ed3bf87f7db13661b6",
								"_tpl": "5fc3e466187fea44d52eda90",
								"parentId": "af06df24bdba4fffafc713b4",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 8,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "99f5a50699b88fffff717687",
								"_tpl": "59fc48e086f77463b1118392",
								"parentId": "9ec803ce8802521c32ef4e71",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "11edf84e0ca64936c0a7db05",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "58664a86f17750b9e1a907e3",
								"slotId": "mod_tactical",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "8e96c506ca0e65758993143b",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "942b0f56f35810da8a7e9dd9",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "a07aea4b525330d56dcab71d",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "919a5003861c3333895d09f0",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "51ca478099c1e8f7a0badd63",
								"_tpl": "6176aca650224f204c1da3fb",
								"parentId": "e16dee62f9d7483fd0beb908",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "3692dc1b327926663454781a",
								"_tpl": "617153016c780c1e710c9a2f",
								"parentId": "51ca478099c1e8f7a0badd63",
								"slotId": "mod_stock",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "797d7226f87864904a169422",
								"_tpl": "61713a8fd92c473c770214a4",
								"parentId": "51ca478099c1e8f7a0badd63",
								"slotId": "mod_reciever",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "4cb3935362481bbb8e138b00",
								"_tpl": "61702d8a67085e45ef140b24",
								"parentId": "51ca478099c1e8f7a0badd63",
								"slotId": "mod_charge",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "e6c32b6dcd2b4a06fa652952",
								"_tpl": "617155ee50224f204c1da3cd",
								"parentId": "3692dc1b327926663454781a",
								"slotId": "mod_stock_000",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "39989044856e02adc050886e",
								"_tpl": "61702be9faa1272e431522c3",
								"parentId": "797d7226f87864904a169422",
								"slotId": "mod_barrel",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "670c31afb9b4f22848ba3d2f",
								"_tpl": "61703001d92c473c77021497",
								"parentId": "797d7226f87864904a169422",
								"slotId": "mod_handguard",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "9d28a1cd930b6d8adf9e7160",
								"_tpl": "61715e7e67085e45ef140b33",
								"parentId": "e6c32b6dcd2b4a06fa652952",
								"slotId": "mod_stock_000",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "1cf4c042a0784d1875972f6b",
								"_tpl": "61702f1b67085e45ef140b26",
								"parentId": "39989044856e02adc050886e",
								"slotId": "mod_gas_block",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "241d844efffc8afccf6d4a55",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "797d7226f87864904a169422",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "c8a28348d79ea684f3a4225d",
								"_tpl": "617131a4568c120fdd29482d",
								"parentId": "51ca478099c1e8f7a0badd63",
								"slotId": "mod_magazine",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 6,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "772b316aec43b9e228195fcb",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "670c31afb9b4f22848ba3d2f",
								"slotId": "mod_tactical_002",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "12f899ec5d05cf0bf0d5a84c",
								"_tpl": "5a7dbfc1159bd40016548fde",
								"parentId": "670c31afb9b4f22848ba3d2f",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "7d9d35a5bf9b25bd7f17ce14",
								"_tpl": "5dfa3d2b0dee1b22f862eade",
								"parentId": "fd33f8dd3723b4a8539aaf85",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 2,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "fd33f8dd3723b4a8539aaf85",
								"_tpl": "5dfa3cd1b33c0951220c079b",
								"parentId": "39989044856e02adc050886e",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "c9d758f02aceed4d62b96962",
								"_tpl": "5d025cc1d7ad1a53845279ef",
								"parentId": "51ca478099c1e8f7a0badd63",
								"slotId": "mod_pistol_grip",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "106790b5609041ef98fa580f",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "c8a28348d79ea684f3a4225d",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "0be31ed826ad2f2bfcba189f",
								"_tpl": "5cc82d76e24e8d00134b4b83",
								"parentId": "af06df24bdba4fffafc713b4",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "003149cf9537de0a37b1c14c",
								"_tpl": "5cc70093e4a949033c734312",
								"parentId": "0be31ed826ad2f2bfcba189f",
								"slotId": "mod_magazine",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "3fb789d7d96c40de93179738",
								"_tpl": "5cc700b9e4a949000f0f0f25",
								"parentId": "0be31ed826ad2f2bfcba189f",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8248bb57735dc65270c907ca",
								"_tpl": "5cc701aae4a949000e1ea45c",
								"parentId": "0be31ed826ad2f2bfcba189f",
								"slotId": "mod_barrel",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "1ce38d3e171980cf9507893f",
								"_tpl": "5cc700cae4a949035e43ba72",
								"parentId": "3fb789d7d96c40de93179738",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "4e9c72b2efd65d3ba9cc53f6",
								"_tpl": "5cc82796e24e8d000f5859a8",
								"parentId": "8248bb57735dc65270c907ca",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "38578370e1499764cdf93dfb",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "d21c57fe03b66c4804602635",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "7c3163b853ce3566443f797f",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "bf4ff5349a5e938b65c538dd",
								"slotId": "mod_tactical",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "d21c57fe03b66c4804602635",
								"_tpl": "5cc700ede4a949033c734315",
								"parentId": "0be31ed826ad2f2bfcba189f",
								"slotId": "mod_reciever",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "bf4ff5349a5e938b65c538dd",
								"_tpl": "5cc7012ae4a949001252b43e",
								"parentId": "d21c57fe03b66c4804602635",
								"slotId": "mod_mount_001",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "ce60cdc1afbd345745fd25b2",
								"_tpl": "5cebec00d7f00c065c53522a",
								"parentId": "4e9c72b2efd65d3ba9cc53f6",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 66,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "b575e8ebda01199564b72997",
								"_tpl": "5cc6ea85e4a949000e1ea3c3",
								"parentId": "0be31ed826ad2f2bfcba189f",
								"slotId": "mod_charge",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "7e2a281d27d2398ff042dfd9",
								"_tpl": "5fb64bc92b1b027b1f50bcf2",
								"parentId": "af06df24bdba4fffafc713b4",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									},
									"FireMode": {
										"FireMode": "single"
									},
									"Foldable": {
										"Folded": false
									}
								}
							},
							{
								"_id": "d4b6b0aeca990084f87bc2a8",
								"_tpl": "5fb6567747ce63734e3fa1dc",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_sight_front",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "6bf4b42bb79d87d945eb2850",
								"_tpl": "5fb6564947ce63734e3fa1da",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_sight_rear",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "09043d358210a49b5c43e68d",
								"_tpl": "5fb65363d1409e5ca04b54f5",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_barrel",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "d59a9ce74b1f104f16cdbd48",
								"_tpl": "5fbb976df9986c4cff3fe5f2",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_mount",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "67640f774af35005959871f5",
								"_tpl": "5fce0f9b55375d18a253eff2",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_mount_001",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8a8c0f4bf2d8e723ce988a5a",
								"_tpl": "5fce0f9b55375d18a253eff2",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_mount_002",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "cfecdc3746b973df1771a002",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "0cf32c79b348e009fd7d3f7a",
								"_tpl": "5fc4b9b17283c4046c5814d7",
								"parentId": "4c6e58850a3bd3e923f5acf8",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 73,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "4c6e58850a3bd3e923f5acf8",
								"_tpl": "5fc4b992187fea44d52edaa9",
								"parentId": "09043d358210a49b5c43e68d",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "0089fe03a9b07b568364b2db",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "8a8c0f4bf2d8e723ce988a5a",
								"slotId": "mod_tactical",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "264f6d468fc88adf45b84916",
								"_tpl": "5b057b4f5acfc4771e1bd3e9",
								"parentId": "d59a9ce74b1f104f16cdbd48",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "942b0f56f35810da8a7e9dd9",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"parentId": "af06df24bdba4fffafc713b4",
								"slotId": "main",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 8,
									"BuyRestrictionCurrent": 0
								},
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "b3e481989e0f02fe388f0db3",
								"_tpl": "5fb655b748c711690e3a8d5a",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "3c798da24da24a4604bddb10",
								"_tpl": "58d2947e86f77447aa070d53",
								"parentId": "9b11b2ee10327c7181a4ac3c",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "6e57a4f1f982f5ded323ccc9",
								"_tpl": "58d2912286f7744e27117493",
								"parentId": "3c798da24da24a4604bddb10",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "9b11b2ee10327c7181a4ac3c",
								"_tpl": "5c793fb92e221644f31bfb64",
								"parentId": "b3e481989e0f02fe388f0db3",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "c5b6d0b9042c106f2d0459fa",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d774e764a1961e590e5fed47",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ff9b101c98078bf266c018a5",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c3347c84bdc62a30b59e7c73",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "038902c3eb5fc1ac35188a15",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fb908f48923e5da819362b13",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b8a6f790ffa69e2a0a71cb28",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "178d256b09c2d73dccb4c6e2",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0405a4a69d1184de7c2ca9ed",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bfda5d29ae4c8c0a5500a06c",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8b8c224965fde64b3ddcd321",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "740cd23efcb3396dd942878a",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1b6f31895429e2cfc8bf77b8",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4c00a58840d6b3f2fcd4795b",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1df979d065ed9bb9d539346a",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d62f42a4d09de4ec9084feea",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a37490b34ee507e847579dca",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "980a2fec6de08edfa027eb5a",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "daa8b187b59abbbd2485d2e0",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5a85d921b6cc0fe390c8a15c",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b7b42528d1175607153ce25b",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2383348ab36f7cb7b5df8d23",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5f8a80f5e54be2c700e24273",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ab36bd9e029a9ed96540222b",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3671c839e90dba63a6e45f2d",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "054919f9a17903c10a6f842b",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ffb7de0b3161adb7081ecbe3",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "22e1006c6f119cb186b674a8",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f9083dfe9949aac35e0459ef",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0abbdf35544b18d8509c3be5",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b75aecb16220d519634d8f09",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6552eb3d0b306503cf3e486e",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "804f9f2258f3ab6b5889dbc9",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "02d5eaf052465eeeaf7019aa",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9ef5bf3f1e6a0b58df468221",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a16fb561d6279ad0bd016853",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0f0608a522ba737ee2313127",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a167b405fb0cbda850f0a394",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e630dff58ade09ee6287846e",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "15a247b55fe981c8c56ba2e4",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b2c57e40d81e54f469935da2",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c8eae24f73d34c2f086ae426",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "86fc6a6caf89e1e9a0c4f066",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4d5a4b3173de759d98c07aaf",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "200832956cc85c7c570f39b5",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ca1ff31c5726c97ec9049bf0",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0088c0bdef4535e7cc199e9e",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e49fad64d8c4080eb19a8d98",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9c8b62df18ebec51e5e257fe",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8c0b649a32be8632cf81f021",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e309868e479883b565b4dccd",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7855e5c8e0e5ed6b42f6ed0e",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "baa685903ca0e95a9868d623",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "06b25651eefa825dcdbe15fb",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "af84d103f6f79471e3d6634b",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1270e58b729d573ef41f2430",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "815b828953df9e1f13534040",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"parentId": "88fd974874140b1df3f51df1",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 400000
								}
							},
							{
								"_id": "30572f69372791fabb7746f2",
								"_tpl": "59136e1e86f774432f15d133",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bf7a58b3046013dfbe718604",
								"_tpl": "5a0ea79b86f7741d4a35298e",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ab695e3f81f6e2d878dace29",
								"_tpl": "5a13ef0686f7746e5a411744",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cfc16fc9b0a03993183bf092",
								"_tpl": "5a0ec70e86f7742c0b518fba",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "767b92563790de6f28777cfd",
								"_tpl": "5a145d7b86f7744cbb6f4a13",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4b8ea6571c775df38f56a43c",
								"_tpl": "5648a69d4bdc2ded0b8b457b",
								"slotId": "main",
								"location": {
									"x": 10,
									"y": 3,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "979e27b5aa3427cc8984d69a",
								"_tpl": "5b40e1525acfc4771e1c6611",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d63359b7f41577ead058f003",
								"_tpl": "5b40e1525acfc4771e1c6611",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "199a5f490feb3398be7c6fc4",
								"_tpl": "5f5e467b0bc58666c37e7821",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b37d2af121d07432c2d38106",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2fb10a1587cdcaeba6dd8e3f",
								"_tpl": "5ac66cb05acfc40198510a10",
								"slotId": "main",
								"parentId": "e16dee62f9d7483fd0beb908",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "c2d092a9f07d6393edc2f3cf",
								"_tpl": "5b4736a986f774040571e998",
								"slotId": "mod_mount_000",
								"parentId": "b7ca953e41fa8dff2e5d489f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "24828d515e2869c479b6cbfe",
								"_tpl": "5b4736b986f77405cb415c10",
								"slotId": "mod_mount_002",
								"parentId": "b7ca953e41fa8dff2e5d489f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "44b7c25105682af12a8828f2",
								"_tpl": "5e21ca18e4d47f0da15e77dd",
								"slotId": "mod_muzzle",
								"parentId": "2fb10a1587cdcaeba6dd8e3f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fc379dbdf3c7ee8a867bf87e",
								"_tpl": "5ac78eaf5acfc4001926317a",
								"slotId": "mod_stock",
								"parentId": "2fb10a1587cdcaeba6dd8e3f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0a32cf7b28e143772693cae5",
								"_tpl": "6130ca3fd92c473c77020dbd",
								"slotId": "mod_charge",
								"parentId": "2fb10a1587cdcaeba6dd8e3f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "df1fb050b9285817e9700f05",
								"_tpl": "5d2c76ed48f03532f2136169",
								"slotId": "mod_reciever",
								"parentId": "2fb10a1587cdcaeba6dd8e3f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "31ab861fd3c99085d43c0bb4",
								"_tpl": "6087e663132d4d12c81fd96b",
								"slotId": "mod_pistol_grip",
								"parentId": "2fb10a1587cdcaeba6dd8e3f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b7ca953e41fa8dff2e5d489f",
								"_tpl": "5b237e425acfc4771e1be0b6",
								"slotId": "mod_gas_block",
								"parentId": "2fb10a1587cdcaeba6dd8e3f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ee07e6de224ca8ae92b05c07",
								"_tpl": "59ecc3dd86f7746dc827481c",
								"slotId": "mod_stock",
								"parentId": "fc379dbdf3c7ee8a867bf87e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8b114af4218f7e7ff711e1c1",
								"_tpl": "5c1bc5af2e221602b412949b",
								"slotId": "mod_foregrip",
								"parentId": "24828d515e2869c479b6cbfe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "639a0a1f7eba26980187d335",
								"_tpl": "58491f3324597764bc48fa02",
								"slotId": "mod_scope",
								"parentId": "df1fb050b9285817e9700f05",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "315c40e0d8a94328b451064d",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "mod_magazine",
								"parentId": "2fb10a1587cdcaeba6dd8e3f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a15c2005d0962aa97331ebf4",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bea74dce35d55294d38c8b5c",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "924cc749a4bc2c62311ce7c8",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5d15ea62bf4819c05583611e",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f731ec19f1715095d8c0429c",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7c6bd2a68707c7fb51af6fc3",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b8a55a4aed9133f391b55741",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f315433b2fec7a0d148ada18",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7bd69dcb7fee4e07a22c1a3a",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "658901eddd7c8862913de043",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f1a6d9644920dcd2433892ae",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "7c6bd2a68707c7fb51af6fc3",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5aff16d149517ace61c7b6ce",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "924cc749a4bc2c62311ce7c8",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2b68cca398c198dcfc6bc5ac",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "b8a55a4aed9133f391b55741",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "804519bcbba1fd95de043c65",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "f731ec19f1715095d8c0429c",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4768c73c1fccf744698024ba",
								"_tpl": "54527ac44bdc2d36668b4567",
								"parentId": "5d15ea62bf4819c05583611e",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "cdb33bf5f661c4bee21a73b9",
								"_tpl": "54527ac44bdc2d36668b4567",
								"parentId": "a15c2005d0962aa97331ebf4",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "b70e8a0d3378b4f560c4d032",
								"_tpl": "54527ac44bdc2d36668b4567",
								"parentId": "bea74dce35d55294d38c8b5c",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "33b6f225b6924db61c9a76cd",
								"_tpl": "54527ac44bdc2d36668b4567",
								"parentId": "315c40e0d8a94328b451064d",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "5935ef4834f1abfb60a147ba",
								"_tpl": "5648a69d4bdc2ded0b8b457b",
								"slotId": "main",
								"location": {
									"x": 10,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "eedcfde2c39877b6ed6d17a1",
								"_tpl": "60926df0132d4d12c81fd9df",
								"slotId": "mod_muzzle",
								"parentId": "e57c6f5557c0aba6e87f0c27",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e57c6f5557c0aba6e87f0c27",
								"_tpl": "609269c3b0e443224b421cc1",
								"slotId": "mod_muzzle",
								"parentId": "44b7c25105682af12a8828f2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7d9579fb592a8a0dbcddecd6",
								"_tpl": "5d2369418abbc306c62e0c80",
								"slotId": "mod_tactical",
								"parentId": "c2d092a9f07d6393edc2f3cf",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e715062470ff6c2cdd3c2abb",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "98e7b8f3c5e69dbde992010c",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c8c621bb87f9ca82d95ca399",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "24089a4110309c71bf1e0c7d",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2faffa8b0745f2f60f9b302e",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "09e8a523442b447c7e3fc5f6",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "66565279723c6ee13451b40f",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b8156dcda5653996e2f59662",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c34c2ef46ce52654d9ce4900",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ab5547a00a29770397dd3ab0",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8d56f5400232ca1d13a245dc",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d50556c8f279cae2e5a1964b",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "421e000b4425b497416fdbf0",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0ab55bc1b15564a64735f562",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d21de40d9c6c01ca5cac3c45",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c120cf481ccf17f25fafa9d5",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ba7f25fe5bde3755069c90d1",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b6127ff409f2745b51d13fcb",
								"_tpl": "606587252535c57a13424cfd",
								"slotId": "main",
								"parentId": "e16dee62f9d7483fd0beb908",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "8193f8b69a6db37a8684c91a",
								"_tpl": "5a329052c4a28200741e22d3",
								"slotId": "mod_handguard",
								"parentId": "cc2dd099d9dcf2759ef4ede0",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9e9c967d3269f395b967bf1d",
								"_tpl": "6065878ac9cf8012264142fd",
								"slotId": "mod_barrel",
								"parentId": "cc2dd099d9dcf2759ef4ede0",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "22346bdabb9eb637a5367ccc",
								"_tpl": "5b3b99475acfc432ff4dcbee",
								"slotId": "mod_scope",
								"parentId": "2b9227fd81c1d710fc3401e9",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2b9227fd81c1d710fc3401e9",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"slotId": "mod_scope",
								"parentId": "cc2dd099d9dcf2759ef4ede0",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5a6ae24f4d454eda80d6e881",
								"_tpl": "5d443f8fa4b93678dd4a01aa",
								"slotId": "mod_muzzle",
								"parentId": "9e9c967d3269f395b967bf1d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c6e226573acdb6cf5a2e64f2",
								"_tpl": "5d44064fa4b9361e4f6eb8b5",
								"slotId": "mod_muzzle",
								"parentId": "5a6ae24f4d454eda80d6e881",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "217ade4f2a521b4a7e71d4d5",
								"_tpl": "6065dc8a132d4d12c81fd8e3",
								"slotId": "mod_gas_block",
								"parentId": "9e9c967d3269f395b967bf1d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "69c4dd098c15bd5b133231ee",
								"_tpl": "5c0102aa0db834001b734ba1",
								"slotId": "mod_mount_004",
								"parentId": "8193f8b69a6db37a8684c91a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7c2b751fa9724e17c9112d70",
								"_tpl": "5c0102b20db834001d23eebc",
								"slotId": "mod_foregrip",
								"parentId": "8193f8b69a6db37a8684c91a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a70b6ed64a38c44ce25d58d3",
								"_tpl": "5d2369418abbc306c62e0c80",
								"slotId": "mod_tactical",
								"parentId": "69c4dd098c15bd5b133231ee",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ebca72b8470a93f1dd099bdc",
								"_tpl": "5c1cd46f2e22164bef5cfedb",
								"slotId": "mod_foregrip",
								"parentId": "7c2b751fa9724e17c9112d70",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cc2dd099d9dcf2759ef4ede0",
								"_tpl": "606587a88900dc2d9a55b659",
								"slotId": "mod_reciever",
								"parentId": "b6127ff409f2745b51d13fcb",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4a185d872503af49b47db236",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "a727810ff601d42329e67986",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c5018b6641f3e2373de419f4",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "mod_magazine",
								"parentId": "b6127ff409f2745b51d13fcb",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "63e27c35d118e07a6c943159",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7e1b64f562ba34cf4c2cd678",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d11e59c01cfccd0e33edb7b1",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "999b7d2c1af0fc38591750bc",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fa198b547ea80f19425e0879",
								"_tpl": "59db3a1d86f77429e05b4e92",
								"slotId": "mod_pistol_grip",
								"parentId": "b6127ff409f2745b51d13fcb",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0361b46f119f3452069282f4",
								"_tpl": "58d2912286f7744e27117493",
								"slotId": "mod_stock",
								"parentId": "1aa0472022c8c2a7c1e199d8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1aa0472022c8c2a7c1e199d8",
								"_tpl": "58d2946386f774496974c37e",
								"slotId": "mod_stock_000",
								"parentId": "a357385164ec9936acbd3fba",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a357385164ec9936acbd3fba",
								"_tpl": "5c793fb92e221644f31bfb64",
								"slotId": "mod_stock_001",
								"parentId": "b6127ff409f2745b51d13fcb",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "72b90406723001830e229e66",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5ec3300f1b3d2ca43b537fd8",
								"_tpl": "606587bd6d0bd7580617bacc",
								"slotId": "mod_charge",
								"parentId": "b6127ff409f2745b51d13fcb",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d1513c0e212da71586e507d9",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "046fdd724fe1cb8284cc8644",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "556f72f696d5ed6806b944bd",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d0ed52fe169f1287cb5b52f8",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "52b708b6732fc0bfef9e5555",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "88f81f5192e896620d6d2f91",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fc25c856f0d368055e3c6064",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "afe137f9463e4ff028c8cac6",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "dfac5096a7f1849857f3a42d",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4f4e0c35227efeaaf5d50943",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8c26dad3a000df3e8dcff6f0",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "a727810ff601d42329e67986",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "19f1b3dfcc17f072059cd8f2",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b495bbf25a0d34a2ec6999a6",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "10111f3849470d1b88968067",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "63e27c35d118e07a6c943159",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2d23848e4eb2e9c35f9baddf",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "86daf5290051137306fefaac",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "c5018b6641f3e2373de419f4",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "f027ddcbd83b497108a8fdaf",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "4a185d872503af49b47db236",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "f39dd24b5e97c86272f6f94c",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "999b7d2c1af0fc38591750bc",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "975b10c24993371ae7daa952",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "d11e59c01cfccd0e33edb7b1",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "42f028a624ecf83e9f35e4d4",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "7e1b64f562ba34cf4c2cd678",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "a23f98242f7caad498f14c5a",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "72b90406723001830e229e66",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "abb6ea654017be84c18ebac8",
								"_tpl": "5fd4c474dd870108a754b241",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "73e6df8bbbbe970390563bb5",
								"_tpl": "5fd4c474dd870108a754b241",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "320974503e8a1d947dcbdd18",
								"_tpl": "609e860ebd219504d8507525",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4b762646aa5025480bd9353b",
								"_tpl": "609e860ebd219504d8507525",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2022b1b806f0e68cf804f6f7",
								"_tpl": "5aa7e276e5b5b000171d0647",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4987fa84292dc62971a5445b",
								"_tpl": "5aa7e276e5b5b000171d0647",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a2d11d43de379f457c7cf59c",
								"_tpl": "5aa7e373e5b5b000137b76f0",
								"slotId": "mod_equipment",
								"parentId": "2022b1b806f0e68cf804f6f7",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ed48a8abffededf60b8c1a67",
								"_tpl": "5aa7e373e5b5b000137b76f0",
								"slotId": "mod_equipment",
								"parentId": "4987fa84292dc62971a5445b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a69722ce1c4448837d5b2076",
								"_tpl": "5f60c74e3b85f6263c145586",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cbf686bf7990374fffcb3f39",
								"_tpl": "5f60c74e3b85f6263c145586",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d73efc078172c47b50c023f3",
								"_tpl": "5f60c85b58eff926626a60f7",
								"slotId": "mod_equipment",
								"parentId": "a69722ce1c4448837d5b2076",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0443acbde13736d59819efb5",
								"_tpl": "5f60c85b58eff926626a60f7",
								"slotId": "mod_equipment",
								"parentId": "cbf686bf7990374fffcb3f39",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "238dbf58c8497405ab29711b",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "af06df24bdba4fffafc713b4",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9cd4d9b30dc0921d77d47405",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c8cd013deba68fb88a2390dd",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "019f8b97903e8aee71bd822a",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6364875b4c7280679f708a9a",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "da480a931afe703da3e823d1",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cbd932313570f400f7eb791d",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6e57505fcdd0771cc6e28692",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "88a752cd7113f30fb7c9111a",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4d464a8e0a1679159e6f201b",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "18c312f1aeac2eb06d56f1b9",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "894afae6188926dcaa4d2db0",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f1704875ba85fcb681f2422c",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2bd5d5d56e7f04b805755c99",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5ff2b6e0b6c748e1fa28e851",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8651732e0b3b14ef9a269f66",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ff6d3c1fe07039b04c79ff36",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0ccd2962f4f5a2d43dbff26a",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3e76aa33c73e0fadf48938a9",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "cbd932313570f400f7eb791d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6fd8050735941f0fbd0eeb71",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "238dbf58c8497405ab29711b",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e510ea7813559f24e52158e8",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "9cd4d9b30dc0921d77d47405",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d69c029f25fbe04c042c407f",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "019f8b97903e8aee71bd822a",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d8a6c67bdf987f44ff980e84",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "6364875b4c7280679f708a9a",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5073a60e1f35ad00322cc389",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "c8cd013deba68fb88a2390dd",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1c6e83e7643b3242b316a667",
								"_tpl": "5cc80f38e4a949001152b560",
								"parentId": "da480a931afe703da3e823d1",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 50
								}
							},
							{
								"_id": "b77b23bcb676e263ac0b826d",
								"_tpl": "606dae0ab0e443224b421bb7",
								"slotId": "main",
								"parentId": "af06df24bdba4fffafc713b4",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "51eac739b7bb9a0761a16607",
								"_tpl": "6076c1b9f2cb2e02a42acedc",
								"slotId": "mod_barrel",
								"parentId": "b77b23bcb676e263ac0b826d"
							},
							{
								"_id": "ef39c818d861eeff74c4bdb9",
								"_tpl": "606ee5c81246154cad35d65e",
								"slotId": "mod_handguard",
								"parentId": "b77b23bcb676e263ac0b826d"
							},
							{
								"_id": "fbdc868de51ddd52e9268ded",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "mod_magazine",
								"parentId": "b77b23bcb676e263ac0b826d"
							},
							{
								"_id": "2a0948354b0ef717b105fe4a",
								"_tpl": "606eef46232e5a31c233d500",
								"slotId": "mod_stock",
								"parentId": "b77b23bcb676e263ac0b826d"
							},
							{
								"_id": "c7f890a216d2db42f74137ee",
								"_tpl": "606eef756d0bd7580617baf8",
								"slotId": "mod_stock",
								"parentId": "2a0948354b0ef717b105fe4a"
							},
							{
								"_id": "edda2f650f3bb6dd4ca915bd",
								"_tpl": "606f2696f2cb2e02a42aceb1",
								"slotId": "mod_tactical",
								"parentId": "c7f890a216d2db42f74137ee"
							},
							{
								"_id": "eba82f802e527e6a4546e191",
								"_tpl": "60785ce5132d4d12c81fd918",
								"slotId": "mod_mount",
								"parentId": "b77b23bcb676e263ac0b826d"
							},
							{
								"_id": "c0d9a1db0a46ebdc104886c3",
								"_tpl": "607ea812232e5a31c233d53c",
								"slotId": "mod_mount_000",
								"parentId": "ef39c818d861eeff74c4bdb9",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2440bb1b8a50294055b1e885",
								"_tpl": "606f262c6d0bd7580617bafa",
								"slotId": "mod_stock",
								"parentId": "c7f890a216d2db42f74137ee",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2a13cae9ae4b58c827819eb2",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b2c66bb17434f3849eb0ba44",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c95baabc29638a3905340111",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "da085870e25c2eed3b5ee8b7",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7c4fbaf746a74ec7a262ad69",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "986950dada74db617353741c",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c0669dbbe4573d81b6c7ba6a",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8e112f433f2f4f751acdbc37",
								"_tpl": "5c0111ab0db834001966914d",
								"slotId": "mod_muzzle",
								"parentId": "51eac739b7bb9a0761a16607",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "881d0a1f7492e3a24cc9a01a",
								"_tpl": "59c0ec5b86f77435b128bfca",
								"slotId": "mod_muzzle",
								"parentId": "8e112f433f2f4f751acdbc37",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0bd902e2218883ea02c876ba",
								"_tpl": "56def37dd2720bec348b456a",
								"slotId": "mod_tactical",
								"parentId": "c0d9a1db0a46ebdc104886c3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f4bd58874ab1432e62047b09",
								"_tpl": "570fd6c2d2720bc6458b457f",
								"slotId": "mod_scope",
								"parentId": "eba82f802e527e6a4546e191",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "545be962b40f22aaa7de841b",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "da085870e25c2eed3b5ee8b7",
								"upd": {
									"StackObjectsCount": 6,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "360bbc34bea571aa97562864",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "983322bf998cee4ec7ecbe37",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5190aa036de6e96d15453558",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1e928ba5a038b34461d15396",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "82b1bb5725e37eceafaea97f",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0e3971e1fd057bc898c25d9f",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "42f10dc844dac12bab3c8ddb",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b9bae35b7e9aa5daa576ff61",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "02e7acf6a3cdbf2712e7c076",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ac6961f079a7730d098c63ed",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "590c6a289fe29ecbb27fceb2",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5defad7b2a1c4f306d002eb7",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "93473068bbd1450d6ee2edf2",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4485ff4c70db316c70dd7ec1",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "79b1e571b7974d3230854f2b",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b3fd54e305f510d57423056c",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c1c4ff2b4e2cd6e3066fa4d0",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "986950dada74db617353741c",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "b6b63d78c60ffd3689f2aa6f",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "b77b23bcb676e263ac0b826d",
								"slotId": "patron_in_weapon",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "a5c993df209147dbdc6f3528",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "fbdc868de51ddd52e9268ded",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "3254a555f8194f731c9f5217",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "2a13cae9ae4b58c827819eb2",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "5995b193ce112162c7778edc",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "b2c66bb17434f3849eb0ba44",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "e94ebc56f3118b4d973561cd",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "c95baabc29638a3905340111",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "ed8ab80edf4491f2536760d7",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "7c4fbaf746a74ec7a262ad69",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "a7e5d27c62f20da8ebd597be",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "c0669dbbe4573d81b6c7ba6a",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "e60b2938cfcc056196206150",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7bc5c92a35bbc555f70e1b49",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "e60b2938cfcc056196206150",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2e5611a229adc44c10a326d9",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1bc82cfb7107900e3d573e0e",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "eb00e37ac516297cc083871b",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f3bee7b05d0c7961b808ccb7",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8fa25a8cf6c3537513590f80",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ac0e34878e7213e44ccaf001",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "89e22919f636c310f9b467a1",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a428a6a6ee2fb438be63649f",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "1bc82cfb7107900e3d573e0e",
								"upd": {
									"StackObjectsCount": 25,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7275660d302a197f125a1c05",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "89e22919f636c310f9b467a1",
								"upd": {
									"StackObjectsCount": 25,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c1a4d471b4de32059c099779",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "8fa25a8cf6c3537513590f80",
								"upd": {
									"StackObjectsCount": 25,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d686cfa21fd3e9feca6c2f8b",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "4b647c6b1decc2247c88b9fc",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c35c46633437c683fab2b230",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "d55fc010431d4e6529238c16",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bcbf5f551d232e4304660533",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "13171ff4cca4806636e1dfea",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3e3b409212bfdf739854dc02",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "d4fa4140bed049693b456f23",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8db003f6852f7f899b5b8dc7",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 10,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6313ff40332c362f18dfb101",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "638e60fc5e9f975d1197e0d9",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "332249091424d2ca789ed6c0",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2c5ffc291077d5ec5d6501e3",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "080217ee209d2bfd8c178b07",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9f2cf37e5b2c3533a252cc69",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "438ce9a4a78622a6ff578b02",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "35f85c9235057906e5012296",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6980154b18c720f34f504f4c",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c67f169a4ba235c30b5a4c29",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d059c5e8453b20c3bab6db4b",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bf5aa7c59981291d19b385a4",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d55fc010431d4e6529238c16",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "148d8d96de541ff985014dae",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4b647c6b1decc2247c88b9fc",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "688bee3bb8da8994c48a79a3",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e79e8f8413dcc4f34775d9b6",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d4fa4140bed049693b456f23",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "13171ff4cca4806636e1dfea",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bcab2d1dd76c8ce11b56d8f9",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a0242724c267510ad050bf51",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1e96865fdf238afcd2e4217d",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "81b3b85f464fad6d9c2644d5",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0a26d538d16e627e00b3dbfa",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fef1394ba4eb9e18e5a77953",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "dcd07cec62b5042e2d16c0ad",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cff8b27fd87d3dd28f791340",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fdd7ed486e23cb7bcb48715d",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5462118c48617cee835068e2",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "afc97c968d08a46d09d5bec1",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e0f560f918464ce6db6bcc26",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8fac788111ed0d2ec955c29f",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fc8a16ec4df66790af0bb271",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0cd10b9cf2b828786e96a8d7",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "12cf937e18df197284756541",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "eb70abb56ed926a1e13ce932",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f85b2eb6a4a2cafceb5bd10a",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "82e3c950717d581fb15fb0dc",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e1ea72658080c0058439e99e",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "43ae5902d72269d0ee4a4ba8",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "85652ddf9afe39e90629aff8",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0adc1083d2f1dd1579ec4083",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "18851e716462c9428e73f475",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f8eb95a6400ddf135434a5d2",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bc679a844f3447e7992733e3",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c73f91c521cacc72471585b4",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f752389faacf90a60721bff8",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 10,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "749e3ee1639f17330afebd8b",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f15922ad033c3d99c8253811",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bb6c8bc08f889f855943b4dd",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a15a2bc3f592f07835cb4762",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b1cd212d4e47841c01d6fbf9",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9a15d7554d11b36297d21c34",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b905aef18911e21c20655592",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a746bbadd63f29cafb70e25c",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "36c747f54869fda8e871eabf",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b6409bd8701b6d6db75378ac",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "101ecc90889a1c0ffe913b92",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "70f6f7cf2ee6ee22014507b8",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f9254f3fb49554dc035e85a5",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6db9fda272bfee2862e9256c",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "40c841ccbda2e42347259021",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6d86db677e0246d65953f487",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "358e65bfb1b2f23fb94b250e",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "43ae5902d72269d0ee4a4ba8",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "154439772bb8ff764408533e",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "85652ddf9afe39e90629aff8",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "17496d77d16cae74d852b8ee",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "0adc1083d2f1dd1579ec4083",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f6fc684321bbefec6ab54aae",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "bc679a844f3447e7992733e3",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2fcd6447d3be57a752abc45e",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "4ae6ae45258e08ef2756d9b2",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "dd675f1f6e0f74f2157c6d36",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "d8e1940caaa2c0431882f24a",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1bff3862696b4f91299a09b7",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "247cf536626d007ed49979f5",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "924831e37b3fd028e23f8143",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "247cf536626d007ed49979f5",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b357ef6757675abac92fb5cf",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d8e1940caaa2c0431882f24a",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b5d1b9db74edbfc833751fff",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4ae6ae45258e08ef2756d9b2",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d63b140026f7f88bff54dce8",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3ac72ce9a85245d09b9a333c",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "2e5611a229adc44c10a326d9",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "4034001036bc5bb158eb3eb4",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "eb00e37ac516297cc083871b",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "67836819865cdbafcf0983a1",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "ac0e34878e7213e44ccaf001",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "bcd7a6699ebebabee9f1c233",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "f3bee7b05d0c7961b808ccb7",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "269438aef5d6dd4ef5ea90cd",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "924831e37b3fd028e23f8143",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "b7e7a047c604e758771afcd8",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "b357ef6757675abac92fb5cf",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "030cd1513a2ebcc94a4ca6c5",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "b5d1b9db74edbfc833751fff",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "7833e5e0fa0e11c23bafb4c0",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "d63b140026f7f88bff54dce8",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "dbf05c9fa9c42c001ab74687",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "f8eb95a6400ddf135434a5d2",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "3ca0816e4925474637f8801d",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "18851e716462c9428e73f475",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "71871eda23ad74978596595b",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "c73f91c521cacc72471585b4",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "2df0a3806b13430cdfd791d0",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "148d8d96de541ff985014dae",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "a044222e8c46c4585513b63a",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "688bee3bb8da8994c48a79a3",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "f2a749160bdcb343af88120a",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "e79e8f8413dcc4f34775d9b6",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "a3daa17039c4158e1f57bb31",
								"_tpl": "5d02797c86f774203f38e30a",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "27e840cbb7f1349ac2644f75",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5387ef1d1260cbfafd28570f",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3d1320c44793fe2a1e7b0c44",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "56fa2c1b41ed71145f014cce",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b89d668500b5a243723b6405",
								"_tpl": "58d3db5386f77426186285a0",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4d424bda397716a4b58d2fc3",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d21aba2e33b6ebd0bca2db76",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "e72c6690206147077755c39c",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "938f8b1c2a43a04233b215c9",
								"_tpl": "5447a9cd4bdc2dbd208b4567",
								"slotId": "main",
								"parentId": "e16dee62f9d7483fd0beb908",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 0,
									"y": 8,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "c53916f0f482569d4b365ddd",
								"_tpl": "5b7be4895acfc400170e2dd5",
								"slotId": "mod_foregrip",
								"parentId": "cb3e7825f6b022de9e2ecb91",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0c60d3095682ff2d8d609012",
								"_tpl": "5b2240bf5acfc40dc528af69",
								"slotId": "mod_charge",
								"parentId": "938f8b1c2a43a04233b215c9",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "990c598777889fd4a8953a6d",
								"_tpl": "5d00ec68d7ad1a04a067e5be",
								"slotId": "mod_gas_block",
								"parentId": "e221479cfffda89c87354da3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "97c078f7ba435233c6f1d65e",
								"_tpl": "609269c3b0e443224b421cc1",
								"slotId": "mod_muzzle",
								"parentId": "e221479cfffda89c87354da3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3b08c3d23cbfbc0cd35e7367",
								"_tpl": "5c793fb92e221644f31bfb64",
								"slotId": "mod_stock",
								"parentId": "938f8b1c2a43a04233b215c9",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "483a8a2de05f1f675d08b107",
								"_tpl": "56def37dd2720bec348b456a",
								"slotId": "mod_tactical_003",
								"parentId": "cb3e7825f6b022de9e2ecb91",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "02d2064152f3f86728122146",
								"_tpl": "59db3a1d86f77429e05b4e92",
								"slotId": "mod_pistol_grip",
								"parentId": "938f8b1c2a43a04233b215c9",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e221479cfffda89c87354da3",
								"_tpl": "55d3632e4bdc2d972f8b4569",
								"slotId": "mod_barrel",
								"parentId": "23c8286bc2f3d1c373139a11",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "23c8286bc2f3d1c373139a11",
								"_tpl": "59bfe68886f7746004266202",
								"slotId": "mod_reciever",
								"parentId": "938f8b1c2a43a04233b215c9",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cb3e7825f6b022de9e2ecb91",
								"_tpl": "5c78f2492e221600114c9f04",
								"slotId": "mod_handguard",
								"parentId": "23c8286bc2f3d1c373139a11",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8ddcb806521e32b69cd2773a",
								"_tpl": "618ba27d9008e4636a67f61d",
								"slotId": "mod_scope",
								"parentId": "17da4ca1fd305e4d3c357175",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "17da4ca1fd305e4d3c357175",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"slotId": "mod_scope",
								"parentId": "23c8286bc2f3d1c373139a11",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "04643e541d0242a3ebb69be9",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f77ce22cb29ed8cd303d847a",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ff524531dbef35b2de9193b3",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8985df52fabb29070578396b",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c9997263f091c501684b859f",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "83db092d30a7dafb0dafca86",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "433b306f437213117aa04d29",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9acdb89f3668c143ddb78882",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "35e9656df950795271fdbb53",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b4efa99f16deadcca2709e38",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "18ad7d3b384e407b6b919935",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7d7b44e153c03b6201a7edb1",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1f0f915fa6487d8c1cf0f55c",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a6f8bd64824dc802b34f873b",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e0ac6081276308cb3325765f",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4adb802ab3607be1093be95a",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "407e9ee5177bb61f3a03b0bf",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8e8ec24d8ae3df031d0ffad4",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4f1aa59002b9203fc8e9d7a0",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "37cdfb46cb92d373754c8711",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9afd70f095f626ea97856e57",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4c2136fe652cffd4b86464f8",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "06a3e730203b0d5b19513b12",
								"_tpl": "58d2947e86f77447aa070d53",
								"slotId": "mod_stock_000",
								"parentId": "3b08c3d23cbfbc0cd35e7367",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "13bee01cfc5cdb4b9794bd7e",
								"_tpl": "58d2912286f7744e27117493",
								"slotId": "mod_stock",
								"parentId": "06a3e730203b0d5b19513b12",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0e7f2048aa3b0eea8892bff6",
								"_tpl": "60926df0132d4d12c81fd9df",
								"slotId": "mod_muzzle",
								"parentId": "97c078f7ba435233c6f1d65e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "60a86f8b2602bbf5d2709e4f",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "779e12368f757878f62b37b4",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4304ed4b1982d43afbf5899f",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b8d7c20a7b10c18ea3257dbb",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b3817180d0976803c2a0d4c2",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b47f2fa450897da6950fbdb5",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "10b204ea1a8083c5bbea50ef",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "110d4eab955ceb83d0b2fd54",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "be477ba8bde1ffb1224a774d",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "20614bec3a1e254021ede07a",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2aab10be26d4d640c9df6b17",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fc97b37cd962f0402664fb0a",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "56bb67d313499b1ac467898a",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5b58538c86734e4561b77079",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3ed781ed64dd3f94e11b7d8b",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5b533b50bfc272ee58a937a4",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7d89122c5b49736ad0668775",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "35d2b03ec966a8f9bb46016c",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ff2ddd872cf8abae66aadf9f",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f33f0334df47120884b210da",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "60a86f8b2602bbf5d2709e4f",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ef829d43994f001e3afc329a",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "779e12368f757878f62b37b4",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "15093b4b53ebd288593aa6d9",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "4304ed4b1982d43afbf5899f",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e987d91dbace279ac4a4e26e",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "b8d7c20a7b10c18ea3257dbb",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e8779eb6789fffd3ee7b5c50",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "b3817180d0976803c2a0d4c2",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "921b4d48034ac51beb2a71f5",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "b47f2fa450897da6950fbdb5",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b99e8e72f1c4f48f0c9a40da",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "10b204ea1a8083c5bbea50ef",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f5738567a1198b86d3152da9",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bea0a72819a506961a2ea7b9",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bc1c0c25ab0e2805fb5e991a",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "deca2f2adc0139071415d1b7",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ca67cd2df696919cab612f49",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "28e6588a34931ba5731cfb1a",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1d62ea3543231dce414fb30e",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5605ae0c86ac9652762985ed",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cae20ed3fe7cb0aa69ca1ea7",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "be477ba8bde1ffb1224a774d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "38460229220f39f448e2e564",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "20614bec3a1e254021ede07a",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "49f9ce20c3aca6017c9839ae",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "2aab10be26d4d640c9df6b17",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5ea5f755a600795d28e96e20",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "fc97b37cd962f0402664fb0a",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f6b7681b474f7c060c194ef4",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "56bb67d313499b1ac467898a",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "67f1ed35726738bc01ecbfa8",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "5b58538c86734e4561b77079",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b1854cd4555381dd51d5e944",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "3ed781ed64dd3f94e11b7d8b",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ce17b8a1f3a9fbfa18120f8f",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c4793f3210a32080ced0d345",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b27c3f17dd9864bba5d92374",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "871867f871da672253552afa",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "90bedd147f08bf58de83624a",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e9350b07a5e04b16a5beeab6",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c3dea30c199e8dc2f77b3771",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8bd92a455f3230c47d99cdd7",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1d34365fdfa097845114d598",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7b7ce58c916ba12363798149",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3f9b226517c5afab87de81ba",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d940d16d1cb9bfcf889e53df",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e0a80487a988e17fbf6c71b0",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a9c2ff72fcd5a8476b07b6a5",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "48ba5060958568ac772ccde3",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "12b3a5d2e390aa91ab1e3205",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "144ca1d2c772b191aa73dc55",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a2be82383b43fac949d9777f",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4b1a67ca2246ef6dc3be2166",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8c611eb2cc3f4b5aa0cef88e",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fb488c81a8f9535691bedaf5",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "916ef9b67b0a62906774e73d",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0efae8fdf2ffa79237c7332a",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "448c4abff203106d4cba7f40",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9cabec84becb71b0babbef79",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "45daafb738379d46de228e86",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c81f86f5d9a3bda9f3ec5c48",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b2110fa2325b44b96c5402b5",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "292dc8a697a0db6f0457753f",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c008755e774ef99037b29758",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b9d1831be4a2aa948517744d",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bd97f8b0c608da7fd3cff726",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "23348efcf2a5e9b192e0ad10",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ea920f2f2f1bb6c5112c1290",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4a51a05e834bbc84030d6ef4",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f83083c9986bf88389aaaed3",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fa52ad299b75fb4d04a00d6a",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0343c45cd7ad3599cd1c6d31",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "eede16ed3bf87f7db13661b6",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "49c3966cb1992c65475bf027",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "204cb82ea69b0e1895f97c37",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b9ad34cf99a53281d5a11b27",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3f8c6314a3b53d19dd561944",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4e4f8c80bea5b26d07ade25a",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bf56ba1687fadbf7df0699af",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3d35c17d38629ba30e7cb19e",
								"_tpl": "628a60ae6b1d481ff772e9c8",
								"slotId": "main",
								"parentId": "e16dee62f9d7483fd0beb908",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 1,
									"y": 10,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "9e1baaed659df2e3fe88eeda",
								"_tpl": "628a83c29179c324ed269508",
								"slotId": "mod_gas_block",
								"parentId": "3d35c17d38629ba30e7cb19e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9ec2a211faa8bee8c5925271",
								"_tpl": "6130c43c67085e45ef1405a1",
								"slotId": "mod_muzzle",
								"parentId": "3d35c17d38629ba30e7cb19e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2b17540a2fbf0e1fb10d2799",
								"_tpl": "5dfa3d2b0dee1b22f862eade",
								"slotId": "mod_muzzle",
								"parentId": "9ec2a211faa8bee8c5925271",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ddf7bc0cee5bdda793bf287a",
								"_tpl": "56def37dd2720bec348b456a",
								"slotId": "mod_tactical",
								"parentId": "dcf7b5226e44c659ab377f4b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "dcf7b5226e44c659ab377f4b",
								"_tpl": "5b7be47f5acfc400170e2dd2",
								"slotId": "mod_mount_001",
								"parentId": "9e1baaed659df2e3fe88eeda",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c60610c7288d7789610694d7",
								"_tpl": "5b7be4895acfc400170e2dd5",
								"slotId": "mod_foregrip",
								"parentId": "9e1baaed659df2e3fe88eeda",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "77e10f999fda57be9dc096d8",
								"_tpl": "5b057b4f5acfc4771e1bd3e9",
								"slotId": "mod_foregrip",
								"parentId": "c60610c7288d7789610694d7",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ccb88c0166ae5d49dad0416f",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e95f848c539349d25fcb7ebf",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "97cb2e2dc28627186e38399f",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6fe96859c4d3372a6c04a985",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6f8efd9e340ad2d0585cdc1d",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a1efaf637cd1af1f6dcb3535",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0cb2e71285024b535a15bbc6",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7bb86b8491e87cc68cf1d7aa",
								"_tpl": "628c9ab845c59e5b80768a81",
								"slotId": "mod_pistol_grip",
								"parentId": "3d35c17d38629ba30e7cb19e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8ac5f282e1fea314f2b437c3",
								"_tpl": "5b0e794b5acfc47a877359b2",
								"slotId": "mod_stock_000",
								"parentId": "3d35c17d38629ba30e7cb19e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fb8c15ac30d420e995460f8f",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"slotId": "mod_scope",
								"parentId": "6bc6aeb0db4dd49932a876d3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4e439a81dc94f7cae23c413c",
								"_tpl": "618ba27d9008e4636a67f61d",
								"slotId": "mod_scope",
								"parentId": "fb8c15ac30d420e995460f8f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6bc6aeb0db4dd49932a876d3",
								"_tpl": "5d2c772c48f0355d95672c25",
								"slotId": "mod_reciever",
								"parentId": "3d35c17d38629ba30e7cb19e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "da5b2ffcc0de3adb88c38a75",
								"_tpl": "6130ca3fd92c473c77020dbd",
								"slotId": "mod_charge",
								"parentId": "3d35c17d38629ba30e7cb19e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "edbd3a7a9fff0d5bdd4e064f",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0e92fe90d08ce1b1a24515c1",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "eff3c273ef4840c6a14a2762",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "35878840f4b5a3324f42e2a6",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "260d2e6c2fac010497826905",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a6733322424a407547f32482",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9a471abbfe2ffba410c42bae",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "49e71c1a6b39b0881f294c0a",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "mod_magazine",
								"parentId": "3d35c17d38629ba30e7cb19e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1daf0c2f10bc615192d36c8d",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "9a471abbfe2ffba410c42bae",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1961401d2cc1166ad867a33f",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "a6733322424a407547f32482",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "267188848a24f7bbb8d615a7",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "260d2e6c2fac010497826905",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bc3b874fcf7e32956573c2b5",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "35878840f4b5a3324f42e2a6",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2a6412f405a342f4e7b20a2c",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "eff3c273ef4840c6a14a2762",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "37a0f2d9a20aeb94723dd329",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a8abfa83c140a376e401c37f",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d1c82620676668f818e379c1",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3625c95c896e2632eb425143",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d0a6bead7bc72d1d58421c84",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7452ae54ef52bb842d594419",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7f8ef0e0f3b60805297276ae",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ea8941d7a00bdceff34fa429",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fafd0a6fbf40babf9f493c34",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "341e4d31559a4227a389683b",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b066c855180d3e2090b2f62a",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "edbd3a7a9fff0d5bdd4e064f",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c9df86189198d30bc3a08ae1",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "0e92fe90d08ce1b1a24515c1",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7a2df51f950220de8467ccb8",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"parentId": "49e71c1a6b39b0881f294c0a",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 50
								}
							},
							{
								"_id": "997089bd97448535cefef632",
								"_tpl": "5a154d5cfcdbcb001a3b00da",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0c3d3c1c0079b609c9311fe2",
								"_tpl": "5a16b7e1fcdbcb00165aa6c9",
								"slotId": "mod_equipment_000",
								"parentId": "997089bd97448535cefef632",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b6d210314851d4876094b088",
								"_tpl": "5a16b7e1fcdbcb00165aa6c9",
								"slotId": "mod_equipment_000",
								"parentId": "9c398a22cefd2103a9cbff5b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9c398a22cefd2103a9cbff5b",
								"_tpl": "5a154d5cfcdbcb001a3b00da",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "51a1ca6a946c86938574382a",
								"_tpl": "5c0e655586f774045612eeb2",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bf47027ec9f4fade27c39cea",
								"_tpl": "5c0e655586f774045612eeb2",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c7e120f64e5748b5f10fd41b",
								"_tpl": "5e4ac41886f77406a511c9a8",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9f180942e6ea3ce882cd2d2c",
								"_tpl": "5e4ac41886f77406a511c9a8",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e8f38ac80be50ecc9718981f",
								"_tpl": "5c0e746986f7741453628fe5",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e30df73c4e9d188fec204256",
								"_tpl": "5c0e746986f7741453628fe5",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0209a8b9ebec3c27d64b3b77",
								"_tpl": "5aa2ba71e5b5b000137b758f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "292420adff9ce66f7033f7ef",
								"_tpl": "5aa2ba71e5b5b000137b758f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cee7dfc929753c6245471c71",
								"_tpl": "545cdae64bdc2d39198b4568",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b37d2af121d07432c2d38106",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c03f5702053c3eaa99bc2756",
								"_tpl": "545cdae64bdc2d39198b4568",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cee7dfc929753c6245471c71",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "377fabcb04ddd4a035a5bcce",
								"_tpl": "5df8a4d786f77412672a1e3b",
								"slotId": "main",
								"location": {
									"x": 8,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b37d2af121d07432c2d38106",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3d92d511255b7631dbac55b7",
								"_tpl": "5df8a4d786f77412672a1e3b",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "377fabcb04ddd4a035a5bcce",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0397feab6408d8a36caad322",
								"_tpl": "5c093e3486f77430cb02e593",
								"slotId": "8",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f1ba1460534dbc420ebaf47e",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3d3af1571375b4c0abfe771a",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5b95b08361ea8c67624d9f1f",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "02ac0d5a05051e6b0e736fbe",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c03f6f9e178409e75986ff65",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "25870226a23fb4b81ce0d797",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bf8189367ae2bba041f98ed3",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2a259ff819ce93daea987a9a",
								"_tpl": "5d1b36a186f7742523398433",
								"parentId": "294e09e971ddf3e4e255218e",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "48a202ac7a1ae4d16456320d",
								"_tpl": "5d1b36a186f7742523398433",
								"parentId": "294e09e971ddf3e4e255218e",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "63c2814159d4513432317ac8",
								"_tpl": "5d1b36a186f7742523398433",
								"parentId": "294e09e971ddf3e4e255218e",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "6d7e79ba3d733254c03ee4a1",
								"_tpl": "5d1b36a186f7742523398433",
								"parentId": "294e09e971ddf3e4e255218e",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "bf732905f7a5b01e203f883e",
								"_tpl": "63a399193901f439517cafb6",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "bd2299692d89e70ec36bfb92",
								"_tpl": "63a397d3af870e651d58e65b",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "b5321a2fe3da61821ff2246c",
								"_tpl": "63a39f6e64283b5e9c56b289",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "28f15a571836bbaad185aa3d",
								"_tpl": "63a3a93f8a56922e82001f5d",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "2eef19f536d6bc6786a2fdcb",
								"_tpl": "63a39c7964283b5e9c56b280",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "5df63763beae15220cfd7487",
								"_tpl": "63a39f18c2d53c2c6839c1d3",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "b118a87b34c6702e17a656fd",
								"_tpl": "63a39f08cd6db0635c197600",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "44c350cd6e31ba6f3f00a205",
								"_tpl": "63a39fc0af870e651d58e6ae",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "aeb1bba8cb369c29b0978bb6",
								"_tpl": "63a39e1d234195315d4020bd",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "5173ce0ad9da0c2fb6b63c55",
								"_tpl": "6398fd8ad3de3849057f5128",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "269e2c7dfe7b4900a913eef7",
								"_tpl": "63a71ed21031ac76fe773c7f",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "b59f1b64f5e90bd4b9b89fef",
								"_tpl": "63a39c69af870e651d58e6aa",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "90c5728a75e8ac835413cf86",
								"_tpl": "63a39fdf1e21260da44a0256",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "ae9ea822c5df275bcaafbb10",
								"_tpl": "63a39cb1c9b3aa4b61683ee2",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "ed7ef975ea23817d282a6b71",
								"_tpl": "63a39667c9b3aa4b61683e98",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "3905c12101ee344a3a5f860b",
								"_tpl": "63a39ce4cd6db0635c1975fa",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "e5bec7018c7c0059afa1832e",
								"_tpl": "63a39e49cd6db0635c1975fc",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "78bf70cb58485291b16683ae",
								"_tpl": "63a39fd1c9b3aa4b61683efb",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "fa8b74099388c071f24cabcb",
								"_tpl": "63a71e781031ac76fe773c7d",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "9579b43eb6731bf2240f761a",
								"_tpl": "63a71e922b25f7513905ca20",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "5e0c844c572ba08441d62b02",
								"_tpl": "63a71e86b7f4570d3a293169",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "97d073235e2ae143fbf29ae1",
								"_tpl": "63a71eb5b7f4570d3a29316b",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "029dadf5af46b49ab6ed265c",
								"_tpl": "63a39df18a56922e82001f25",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "7687fbcae2127855452a328a",
								"_tpl": "63a39dfe3901f439517cafba",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "9a045c757b47fdcfc3bae6be",
								"_tpl": "64381b6e44b37a080d0245b9"
							},
							{
								"_id": "4def02c5f448ae5b3841c051",
								"_tpl": "64381b6e44b37a080d0245b9"
							},
							{
								"_id": "849abeadb3f674f3d0150f8c",
								"_tpl": "64381b6e44b37a080d0245b9"
							},
							{
								"_id": "b1f644f258e1cf89d255a50d",
								"_tpl": "64381b6e44b37a080d0245b9"
							},
							{
								"_id": "bd0846135a51277898f95977",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "82b6f2edbcc846f8fc77108d",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 3
								}
							},
							{
								"_id": "63db64cbf9963741dc0d741f",
								"_tpl": "64381b6e44b37a080d0245b9"
							},
							{
								"_id": "640b2d867f4185aa520d08ba",
								"_tpl": "64381b6e44b37a080d0245b9"
							},
							{
								"_id": "531debbc2805b55a806a8c70",
								"_tpl": "5839a40f24597726f856b511",
								"parentId": "e16dee62f9d7483fd0beb908",
								"slotId": "main",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"Foldable": {
										"Folded": false
									},
									"StackObjectsCount": 1
								},
								"location": {
									"x": 1,
									"y": 12,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "26b7153267d090c7e38da092",
								"_tpl": "5839a7742459773cf9693481",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "mod_reciever",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"Foldable": {
										"Folded": false
									},
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "4eca657b0330534b397ab5d3",
								"_tpl": "59d36a0086f7747e673f3946",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "mod_gas_block",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"Foldable": {
										"Folded": false
									},
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "e551bdc819b3b94b68b22796",
								"_tpl": "57ffa9f4245977728561e844",
								"parentId": "4eca657b0330534b397ab5d3",
								"slotId": "mod_handguard",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "28501e0555771b4dea9ceded",
								"_tpl": "56def37dd2720bec348b456a",
								"parentId": "e551bdc819b3b94b68b22796",
								"slotId": "mod_tactical_001",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "6c6783dd4d7e30c40a934762",
								"_tpl": "615d8f5dd92c473c770212ef",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "28fbe8303f9774eb6ea107e1",
								"_tpl": "615d8f8567085e45ef1409ca",
								"parentId": "6c6783dd4d7e30c40a934762",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "3f7cfcabeb87e2ec9d350aaa",
								"_tpl": "5b057b4f5acfc4771e1bd3e9",
								"parentId": "e551bdc819b3b94b68b22796",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "53de56e6dacd903fc7a4d8b9",
								"_tpl": "6087e663132d4d12c81fd96b",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "mod_pistol_grip",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8fe85ad1777ad5b12bca0910",
								"_tpl": "63d114019e35b334d82302f7",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "mod_mount_000",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "4097b09529da60d8a6e37104",
								"_tpl": "5b3b99475acfc432ff4dcbee",
								"parentId": "4a57fdf38fc3548f779fa5de",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "b72f13283e5a1c197b05bd4d",
								"_tpl": "59ecc3dd86f7746dc827481c",
								"parentId": "2c9d874904537de3a306b167",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "2c9d874904537de3a306b167",
								"_tpl": "59ecc28286f7746d7a68aa8c",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "4a57fdf38fc3548f779fa5de",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"parentId": "8fe85ad1777ad5b12bca0910",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "2c440af16ad3ed23fc552915",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "e6704482ae7d525391049c02",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "7525ef6df0776b6b440f9a63",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "e7e734d07cfee8a4b125b9b3",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "6526113201000001e5644d74",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "patron_in_weapon",
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "e6704482ae7d525391049c02",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "mod_magazine",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "47d5f68778d80f2597826f09",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "b330c2a8b154d6401ab7afa1",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "051874615cf6010119a08cf4",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "b330c2a8b154d6401ab7afa1",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "e7e734d07cfee8a4b125b9b3",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "b330c2a8b154d6401ab7afa1",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "bfcc02567f33805f61b44268",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "b330c2a8b154d6401ab7afa1",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "3f0a1facbc4add3fb5bd232d",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "b330c2a8b154d6401ab7afa1",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "7ffc7f0b047adf425ef5b2fd",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "b330c2a8b154d6401ab7afa1",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "c1eb090bf8687bdcbe6b785c",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "b330c2a8b154d6401ab7afa1",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "f550ccd2829a2f37c8df26dd",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "051874615cf6010119a08cf4",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "eb5ae315c8f0d295387f14de",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "47d5f68778d80f2597826f09",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "652616bc01000001e5c18556",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"parentId": "bb363db77d34926599d768f0",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "329d48449efda15c3028935c",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8fe931ed90d3455d3e957c1a",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8aa03b00aa7e9489a42f3919",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "3aa4200bd3c1b8473c35332b",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "3a55db74db148e8583be05c5",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "9bbea0c26839b44a6d90c75e",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "4e665ae1eb48f2fa2990fa35",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "e6f0ac6f2e2e3e5b732e4039",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "b3dcd360d9ce9bf2a3e25019",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "c974759cdd69cafef76212dc",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "9c4e69fe204d8b1626be9db3",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "a357c9db137c2d8eebde7d35",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "a04a2790d2655d0c9a122598",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "13b52004e7fffcf3d1b00cd2",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "a6d1d46a236769ad641bc40e",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "9b57bd41428132f88f756c31",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "65261b8e01000001e5da70ad",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "3f0a1facbc4add3fb5bd232d",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "65261bb401000001e564e251",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "c1eb090bf8687bdcbe6b785c",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "65261bb801000001e5237ce6",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "7ffc7f0b047adf425ef5b2fd",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "65261bc201000001e5a412af",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "bfcc02567f33805f61b44268",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "65261c9201000001e59f76da",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "65261cd801000001e598f029",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 250000
								}
							}
						],
						"equipment": "5fe49444ae6628187a2e77b8",
						"stash": "5fe49444ae6628187a2e78b8",
						"sortingTable": "60dca3da42ad9b706b369aca",
						"questRaidItems": "5fe49444ae6628187a2e78b9",
						"questStashItems": "5fe49444ae6628187a2e78ba",
						"fastPanel": {},
						"hideoutAreaStashes": {
							"24": "63db64cbf9963741dc0d741f",
							"25": "640b2d867f4185aa520d08ba"
						}
					},
					"Skills": {
						"Common": [{
								"Id": "BotReload",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "BotSound",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "Endurance",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Strength",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Vitality",
								"Progress": 3400,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Health",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "StressResistance",
								"Progress": 2500,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Metabolism",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Immunity",
								"Progress": 300,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Perception",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Intellect",
								"Progress": 50,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Attention",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Charisma",
								"Progress": 2200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Memory",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Pistol",
								"Progress": 150,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Revolver",
								"Progress": 50,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "SMG",
								"Progress": 900,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Assault",
								"Progress": 1200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Shotgun",
								"Progress": 800,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Sniper",
								"Progress": 600,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "LMG",
								"Progress": 120,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "HMG",
								"Progress": 20,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Launcher",
								"Progress": 20,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "AttachedLauncher",
								"Progress": 20,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Throwing",
								"Progress": 200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Melee",
								"Progress": 20,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "DMR",
								"Progress": 900,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "RecoilControl",
								"Progress": 2100,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "AimDrills",
								"Progress": 1100,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "Surgery",
								"Progress": 900,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "CovertMovement",
								"Progress": 2500,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Search",
								"Progress": 2600,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "MagDrills",
								"Progress": 700,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "Sniping",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "ProneMovement",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "FieldMedicine",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "FirstAid",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "LightVests",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "HeavyVests",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "WeaponModding",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "AdvancedModding",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "NightOps",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "SilentOps",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Lockpicking",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "WeaponTreatment",
								"Progress": 900,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Freetrading",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Auctions",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Cleanoperations",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Barter",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Shadowconnections",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Taskperformance",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Crafting",
								"Progress": 500,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "HideoutManagement",
								"Progress": 700,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}
						],
						"Mastering": [],
						"Points": 0
					},
					"Stats": {
						"SessionCounters": null,
						"OverallCounters": {
							"Items": []
						},
						"SessionExperienceMult": 0,
						"ExperienceBonusMult": 0,
						"TotalSessionExperience": 0,
						"LastSessionDate": 0,
						"Aggressor": null,
						"DroppedItems": [],
						"FoundInRaidItems": [],
						"Victims": [],
						"CarriedQuestItems": [],
						"DamageHistory": {
							"LethalDamagePart": "Head",
							"LethalDamage": null,
							"BodyParts": []
						},
						"LastPlayerState": null,
						"TotalInGameTime": 0,
						"SurvivorClass": "Unknown"
					},
					"Encyclopedia": {
						"56dfef82d2720bbd668b4567": true,
						"57dc324a24597759501edc20": true,
						"57dc334d245977597164366f": true,
						"59d36a0086f7747e673f3946": true,
						"58864a4f2459770fcc257101": true,
						"5448be9a4bdc2dfd2f8b456a": true,
						"544fb45d4bdc2dee738b4568": true,
						"545cdae64bdc2d39198b4568": true,
						"545cdb794bdc2d3a198b456a": true,
						"590c678286f77426c9660122": true,
						"5645bc214bdc2d363b8b4571": true,
						"584984812459776a704a82a6": true,
						"59ccfdba86f7747f2109a587": true,
						"544fb3f34bdc2d03748b456a": true,
						"590c657e86f77412b013051d": true,
						"592c2d1a86f7746dbe2af32a": true,
						"567143bf4bdc2d1a0f8b4567": true,
						"59bffbb386f77435b379b9c2": true,
						"59bffc1f86f77435b128b872": true,
						"595cf16b86f77427440c32e2": true,
						"5644bd2b4bdc2d3b4c8b4572": true,
						"59c6633186f7740cf0493bb9": true,
						"5649b0544bdc2d1b2b8b458a": true,
						"576a581d2459771e7b1bc4f1": true,
						"576a7c512459771e796e0e17": true,
						"59984ab886f7743e98271174": true,
						"59985a8086f77414ec448d1a": true,
						"599860e986f7743bb57573a6": true,
						"59ccd11386f77428f24a488f": true,
						"55801eed4bdc2d89578b4588": true,
						"559ba5b34bdc2d1f1a8b4582": true,
						"5887431f2459777e1612938f": true,
						"56083e1b4bdc2dc8488b4572": true,
						"56083eab4bdc2d26448b456a": true,
						"560e620e4bdc2d724b8b456b": true,
						"56ea8222d2720b69698b4567": true,
						"58948c8e86f77409493f7266": true,
						"5894a51286f77426d13baf02": true,
						"5894a5b586f77426d2590767": true,
						"5894a2c386f77427140b8342": true,
						"58949dea86f77409483e16a8": true,
						"5894a42086f77426d2590762": true,
						"5894a73486f77426d259076c": true,
						"5894a81786f77427140b8347": true,
						"5894a13e86f7742405482982": true,
						"58949edd86f77409483e16a9": true,
						"55d7217a4bdc2d86028b456d": true,
						"557ffd194bdc2d28148b457f": true,
						"544a5cde4bdc2d39388b456b": true,
						"5857a8bc2459772bad15db29": true,
						"5ca20abf86f77418567a43f2": true,
						"564ca99c4bdc2d16268b4589": true,
						"57cd379a24597778e7682ecf": true,
						"57dc2fa62459775949412633": true,
						"57dc32dc245977596d4ef3d3": true,
						"57dc347d245977596754e7a1": true,
						"5649ad3f4bdc2df8348b4585": true,
						"5811ce772459770e9e5f9532": true,
						"5894a05586f774094708ef75": true,
						"5648b1504bdc2d9d488b4584": true,
						"5998597786f77414ea6da093": true,
						"599860ac86f77436b225ed1a": true,
						"599851db86f77467372f0a18": true,
						"5998517986f7746017232f7e": true,
						"576a63cd2459771e796e0e11": true,
						"576a5ed62459771e9c2096cb": true,
						"56d59d3ad2720bdb418b4577": true,
						"5448bd6b4bdc2dfc2f8b4569": true,
						"5448c12b4bdc2d02308b456f": true,
						"573718ba2459775a75491131": true,
						"5649b1c04bdc2d16268b457c": true,
						"5649af094bdc2df8348b4586": true,
						"5649aa744bdc2ded0b8b457e": true,
						"5648b0744bdc2d363b8b4578": true,
						"5696686a4bdc2da3298b456a": true,
						"5449016a4bdc2d6f028b456f": true,
						"57347d7224597744596b4e72": true,
						"544fb25a4bdc2dfb738b4567": true,
						"5448fee04bdc2dbc018b4567": true,
						"544fb3364bdc2d34748b456a": true,
						"5755356824597772cb798962": true,
						"5645bcc04bdc2d363b8b4572": true,
						"5751a25924597722c463c472": true,
						"544fb37f4bdc2dee738b4567": true,
						"5e831507ea0a7c419c2f9bd9": true,
						"5648a7494bdc2d9d488b4583": true,
						"544a11ac4bdc2d470e8b456a": true,
						"55d480c04bdc2d1d4e8b456a": true,
						"56dff3afd2720bba668b4567": true,
						"5aa2b87de5b5b00016327c25": true,
						"5bffdc370db834001d23eca8": true,
						"5ac4cd105acfc40016339859": true,
						"5ac50c185acfc400163398d4": true,
						"5ac72e475acfc400180ae6fe": true,
						"5ac50da15acfc4001718d287": true,
						"5649ade84bdc2d1b2b8b4587": true,
						"5ac7655e5acfc40016339a19": true,
						"5af0454c86f7746bf20992e8": true,
						"569668774bdc2da2298b4568": true,
						"5ab8f39486f7745cd93a1cca": true,
						"5aa7cfc0e5b5b00015693143": true,
						"5d02778e86f774203e7dedbe": true,
						"557ff21e4bdc2d89578b4586": true,
						"5710c24ad2720bc3458b45a3": true,
						"5d0a29fed7ad1a002769ad08": true,
						"5d0a3e8cd7ad1a6f6a3d35bd": true,
						"5d1b371186f774253763a656": true,
						"5ca20d5986f774331e7c9602": true,
						"590c5d4b86f774784e1b9c45": true,
						"5c0e53c886f7747fa54205c7": true,
						"5e870397991fd70db46995c8": true,
						"560d5e524bdc2d25448b4571": true,
						"5e87114fe2db31558c75a120": true,
						"5e87116b81c4ed43e83cefdd": true,
						"5e87080c81c4ed43e83cefda": true,
						"5e87076ce2db31558c75a11d": true,
						"5e87071478f43e51ca2de5e1": true,
						"5e8708d4ae379e67d22e0102": true,
						"590c695186f7741e566b64a2": true,
						"57347da92459774491567cf5": true,
						"5a0c27731526d80618476ac4": true,
						"5755383e24597772cb798966": true,
						"590c661e86f7741e566b646a": true,
						"5b432b965acfc47a8774094e": true,
						"5d40407c86f774318526545a": true,
						"56e294cdd2720b603a8b4575": true,
						"5c488a752e221602b412af63": true,
						"5c48a2852e221602b21d5923": true,
						"5c48a2a42e221602b66d1e07": true,
						"5c48a14f2e2216152006edd7": true,
						"55802d5f4bdc2dac148b458e": true,
						"5c48a2c22e221602b313fb6c": true,
						"55d4887d4bdc2d962f8b4570": true,
						"570fd6c2d2720bc6458b457f": true,
						"54527a984bdc2d4e668b4567": true,
						"5e8488fa988a8701445df1e4": true,
						"5c0e530286f7747fa1419862": true,
						"5f4f9eb969cdc30ff33f09db": true,
						"59e770b986f7742cbd762754": true,
						"5d02797c86f774203f38e30a": true,
						"5d5e9c74a4b9364855191c40": true,
						"5aafbde786f774389d0cbc0f": true,
						"544a5caa4bdc2d1a388b4568": true,
						"5d5d85c586f774279a21cbdb": true,
						"5d5d940f86f7742797262046": true,
						"5beed0f50db834001c062b12": true,
						"5beec1bd0db834001e6006f3": true,
						"5beec3420db834001b095429": true,
						"5beec3e30db8340019619424": true,
						"5beecbb80db834001d2c465e": true,
						"5beec8b20db834001961942a": true,
						"5beec8c20db834001d2c465c": true,
						"5bed625c0db834001c062946": true,
						"5beec91a0db834001961942d": true,
						"5beec9450db83400970084fd": true,
						"5bf3f59f0db834001a6fa060": true,
						"5beec8ea0db834001a6f9dbf": true,
						"5c0505e00db834001b735073": true,
						"5b432d215acfc4771e1c6624": true,
						"5c0e722886f7740458316a57": true,
						"5e2af4a786f7746d3f3c3400": true,
						"5e2af47786f7746d404f3aaa": true,
						"5b40e5e25acfc4001a599bea": true,
						"5d1b36a186f7742523398433": true,
						"5ed51652f6c34d2cc26336a1": true,
						"601aa3d2b2bcb34913271e6d": true,
						"609e860ebd219504d8507525": true
					},
					"ConditionCounters": {
						"Counters": []
					},
					"BackendCounters": {},
					"InsuredItems": [],
					"Hideout": {
					  "Areas": [
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 0
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 1
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 2
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 4,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 3
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [
							{
								"locationIndex": 0,
								"item": [
									{
										"_id": "4470522e79af690954d01d5f",
										"_tpl": "5d1b36a186f7742523398433",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 1,
								"item": [
									{
										"_id": "d1fdebc6941bc9a245fde51e",
										"_tpl": "5d1b36a186f7742523398433",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 2,
								"item": [
									{
										"_id": "dd35490a7b5b88afd1ea488f",
										"_tpl": "5d1b36a186f7742523398433",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 3,
								"item": [
									{
										"_id": "2e9e972b1f9d5161d794bbd1",
										"_tpl": "5d1b36a186f7742523398433",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 4,
								"item": [
									{
										"_id": "1c2b6e4825bb2ee68caa2a0c",
										"_tpl": "5d1b36a186f7742523398433",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 5,
								"item": [
									{
										"_id": "1c2b6e4825bb2ee68caa2a0d",
										"_tpl": "5d1b36a186f7742523398433",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 6
							},
							{
								"locationIndex": 7
							}
						  ],
						  "type": 4
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 5
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 6
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 7
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 8
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 9
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 10
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 11
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 12
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 1,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 13
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 1,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 14
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 15
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 0,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 16
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 1,
						  "passiveBonusesEnabled": false,
						"slots": [
							{
								"locationIndex": 0,
								"item": [
									{
										"_id": "aa83590c14a0e7d086cd21e9",
										"_tpl": "5d1b2f3f86f774252167a52c",
										"upd": {
											"StackObjectsCount": 1,
											"Resource": {
												"Value": 299.4528,
												"UnitsConsumed": 0.5472
											}
										}
									}
								]
							},
							{
								"locationIndex": 1,
								"item": [
									{
										"_id": "a16cab64ec8a2459367330d3",
										"_tpl": "5d1b2f3f86f774252167a52c",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 2,
								"item": [
									{
										"_id": "d04d42114f2d3f11173347d0",
										"_tpl": "5d1b2f3f86f774252167a52c",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 3
							},
							{
								"locationIndex": 4
							}
						],
						  "type": 17
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 1,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 18
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 1,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 19
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 20
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 0,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 21
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 6,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 22
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 1,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 23
						},
						{
							"type": 24,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						},
						{
							"type": 25,
							"level": 0,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}
					  ],
					  "Improvement": {},
					  "Production": {}
					},
					"Bonuses": [{
							"type": "StashSize",
							"templateId": "566abbc34bdc2d92178b4576"
						}, {
							"type": "StashSize",
							"templateId": "5811ce572459770cba1a34ea"
						}, {
							"type": "StashSize",
							"templateId": "5811ce662459770f6f490f32"
						}, {
							"type": "StashSize",
							"templateId": "5811ce772459770e9e5f9532"
						}
					],
					"Notes": {
						"Notes": []
					},
					"Quests": [],
					"TradersInfo": {},
					"RagfairInfo": {
						"rating": 2.0,
						"isRatingGrowing": true,
						"offers": []
					},
					"WishList": []
				},
				"suits": ["5cd946231388ce000d572fe3", "5cd945d71388ce000a659dfb"],
				"dialogues": {},
				"userbuilds": {
					"equipmentBuilds": [],
					"weaponbuilds": [
						{
							"id": "3b3df48a5189033240cbc490",
							"name": "SA58",
							"root": "268a56c49239447e1ceaf2f0",
							"items": [
								{
									"_id": "268a56c49239447e1ceaf2f0",
									"_tpl": "5b0bbe4e5acfc40dc528a72d",
									"upd": {
										"Repairable": {
											"MaxDurability": 100,
											"Durability": 100
										},
										"FireMode": {
											"FireMode": "single"
										}
									}
								},
								{
									"_id": "14e6c51cadf00ff41da0d5e4",
									"_tpl": "5b7d679f5acfc4001a5c4024",
									"parentId": "268a56c49239447e1ceaf2f0",
									"slotId": "mod_pistol_grip"
								},
								{
									"_id": "a0bf32a90791e34cf55c8889",
									"_tpl": "5b7d37845acfc400170e2f87",
									"parentId": "268a56c49239447e1ceaf2f0",
									"slotId": "mod_magazine"
								},
								{
									"_id": "f9f958bc2a535f5a2a5994c4",
									"_tpl": "5b7bedd75acfc43d825283f9",
									"parentId": "268a56c49239447e1ceaf2f0",
									"slotId": "mod_handguard"
								},
								{
									"_id": "2ca0e76f55698024d1608210",
									"_tpl": "5b7be1265acfc400161d0798",
									"parentId": "268a56c49239447e1ceaf2f0",
									"slotId": "mod_barrel"
								},
								{
									"_id": "49593fe441ed1bb418a23d70",
									"_tpl": "5b099bb25acfc400186331e8",
									"parentId": "268a56c49239447e1ceaf2f0",
									"slotId": "mod_reciever"
								},
								{
									"_id": "122f645f02ac5070d40ec012",
									"_tpl": "5b099bf25acfc4001637e683",
									"parentId": "268a56c49239447e1ceaf2f0",
									"slotId": "mod_stock"
								},
								{
									"_id": "0018dc299ec4e233f1111802",
									"_tpl": "58dd3ad986f77403051cba8f",
									"parentId": "268a56c49239447e1ceaf2f0",
									"slotId": "patron_in_weapon"
								},
								{
									"_id": "329780b1a5b0191b5493ab71",
									"_tpl": "58dd3ad986f77403051cba8f",
									"parentId": "a0bf32a90791e34cf55c8889",
									"slotId": "cartridges",
									"location": 0,
									"upd": {
										"StackObjectsCount": 29
									}
								},
								{
									"_id": "d772eac3df81c4173afd95a0",
									"_tpl": "5b7be46e5acfc400170e2dcf",
									"parentId": "f9f958bc2a535f5a2a5994c4",
									"slotId": "mod_mount_000"
								},
								{
									"_id": "c27a2b62eb2f6e3d56f1ea5e",
									"_tpl": "5b7be4575acfc400161d0832",
									"parentId": "f9f958bc2a535f5a2a5994c4",
									"slotId": "mod_mount_001"
								},
								{
									"_id": "44a111b0eb1c5088212616d9",
									"_tpl": "5cf78496d7f00c065703d6ca",
									"parentId": "2ca0e76f55698024d1608210",
									"slotId": "mod_muzzle"
								},
								{
									"_id": "e636adccbab8d85117da2291",
									"_tpl": "58491f3324597764bc48fa02",
									"parentId": "49593fe441ed1bb418a23d70",
									"slotId": "mod_scope",
									"upd": {
										"Sight": {
											"ScopesCurrentCalibPointIndexes": [
												0
											],
											"ScopesSelectedModes": [
												0
											],
											"SelectedScope": 0
										}
									}
								},
								{
									"_id": "a0d5cfad2d04e990c35cab5e",
									"_tpl": "5c793fb92e221644f31bfb64",
									"parentId": "122f645f02ac5070d40ec012",
									"slotId": "mod_stock_000"
								},
								{
									"_id": "5bc87d6ae3ebd09560912f67",
									"_tpl": "5c1cd46f2e22164bef5cfedb",
									"parentId": "d772eac3df81c4173afd95a0",
									"slotId": "mod_foregrip"
								},
								{
									"_id": "317417c865aaab8c69f76cdb",
									"_tpl": "5d2369418abbc306c62e0c80",
									"parentId": "c27a2b62eb2f6e3d56f1ea5e",
									"slotId": "mod_tactical",
									"upd": {
										"Light": {
											"IsActive": true,
											"SelectedMode": 0
										}
									}
								},
								{
									"_id": "64d2d540509a3d24c4595371",
									"_tpl": "5c878e9d2e2216000f201903",
									"parentId": "44a111b0eb1c5088212616d9",
									"slotId": "mod_muzzle_000"
								},
								{
									"_id": "450d68919c5ed85dc1d54db8",
									"_tpl": "5cf78720d7f00c06595bc93e",
									"parentId": "44a111b0eb1c5088212616d9",
									"slotId": "mod_muzzle_001"
								},
								{
									"_id": "4e55d882dada542c26d2f75c",
									"_tpl": "58d2947e86f77447aa070d53",
									"parentId": "a0d5cfad2d04e990c35cab5e",
									"slotId": "mod_stock_000"
								},
								{
									"_id": "5f7bac2b1e9b653ee1f74e61",
									"_tpl": "58d2912286f7744e27117493",
									"parentId": "4e55d882dada542c26d2f75c",
									"slotId": "mod_stock"
								}
								],
							"type": "weapon"
						},
						{
							"id": "562ebd1be9d329672e3618a0",
							"name": "G28",
							"root": "d81fce1f645deecd57ad52c6",
							"items": [
									{
										"_id": "d81fce1f645deecd57ad52c6",
										"_tpl": "6176aca650224f204c1da3fb",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "11655d5299e66de5d8cd0047",
										"_tpl": "5d025cc1d7ad1a53845279ef",
										"parentId": "d81fce1f645deecd57ad52c6",
										"slotId": "mod_pistol_grip"
									},
									{
										"_id": "47d753f952516b52152a5bec",
										"_tpl": "617131a4568c120fdd29482d",
										"parentId": "d81fce1f645deecd57ad52c6",
										"slotId": "mod_magazine"
									},
									{
										"_id": "d62d733470663b8eb70a281f",
										"_tpl": "617153016c780c1e710c9a2f",
										"parentId": "d81fce1f645deecd57ad52c6",
										"slotId": "mod_stock"
									},
									{
										"_id": "b60a02a394910dcd0b4bf3e1",
										"_tpl": "61713a8fd92c473c770214a4",
										"parentId": "d81fce1f645deecd57ad52c6",
										"slotId": "mod_reciever"
									},
									{
										"_id": "3f9a13303a52a4eeaeb3b3ca",
										"_tpl": "61702d8a67085e45ef140b24",
										"parentId": "d81fce1f645deecd57ad52c6",
										"slotId": "mod_charge"
									},
									{
										"_id": "d59692183de00bcd9e6e638c",
										"_tpl": "58dd3ad986f77403051cba8f",
										"parentId": "47d753f952516b52152a5bec",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 20
										}
									},
									{
										"_id": "521f5023b7318a4d5f40ea69",
										"_tpl": "617155ee50224f204c1da3cd",
										"parentId": "d62d733470663b8eb70a281f",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "09d27aa2822322aa602e92a0",
										"_tpl": "58491f3324597764bc48fa02",
										"parentId": "b60a02a394910dcd0b4bf3e1",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "cd3c784f37487a915c0a642f",
										"_tpl": "61702be9faa1272e431522c3",
										"parentId": "b60a02a394910dcd0b4bf3e1",
										"slotId": "mod_barrel"
									},
									{
										"_id": "89cff2adb72d2e19710be96d",
										"_tpl": "61703001d92c473c77021497",
										"parentId": "b60a02a394910dcd0b4bf3e1",
										"slotId": "mod_handguard"
									},
									{
										"_id": "58863afa5ed39c7dcf3a4491",
										"_tpl": "61715e7e67085e45ef140b33",
										"parentId": "521f5023b7318a4d5f40ea69",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "03f3887a0b0917503585f376",
										"_tpl": "5dfa3cd1b33c0951220c079b",
										"parentId": "cd3c784f37487a915c0a642f",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "8e4f4f6e5760b3162633c045",
										"_tpl": "61702f1b67085e45ef140b26",
										"parentId": "cd3c784f37487a915c0a642f",
										"slotId": "mod_gas_block"
									},
									{
										"_id": "ee6982f8894d41d2fdab6c59",
										"_tpl": "5a7dbfc1159bd40016548fde",
										"parentId": "89cff2adb72d2e19710be96d",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "f18c528e2ec002eebd066a24",
										"_tpl": "5d2369418abbc306c62e0c80",
										"parentId": "89cff2adb72d2e19710be96d",
										"slotId": "mod_tactical_002",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "1329ef0df744ea775dde3f57",
										"_tpl": "5dfa3d2b0dee1b22f862eade",
										"parentId": "03f3887a0b0917503585f376",
										"slotId": "mod_muzzle"
									}
								],
							"type": "weapon"
						},
						{
							"id": "f0f1c4f6ad973e4cdd31b3cc",
							"name": "UMP45",
							"root": "56b49630d8e5ae8fedb77c5d",
							"items": [
									{
										"_id": "56b49630d8e5ae8fedb77c5d",
										"_tpl": "5fc3e272f8b6a877a729eac5",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"Foldable": {
												"Folded": false
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "7d0032474bbf714d1239d64f",
										"_tpl": "5fc3e466187fea44d52eda90",
										"parentId": "56b49630d8e5ae8fedb77c5d",
										"slotId": "mod_magazine"
									},
									{
										"_id": "72ea143157ef48971bf4227d",
										"_tpl": "58491f3324597764bc48fa02",
										"parentId": "56b49630d8e5ae8fedb77c5d",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "c7119bf70d33862058766b91",
										"_tpl": "5fc3e4ee7283c4046c5814af",
										"parentId": "56b49630d8e5ae8fedb77c5d",
										"slotId": "mod_stock"
									},
									{
										"_id": "b5dddb73fb25280c4cd51bd9",
										"_tpl": "5fc3e4a27283c4046c5814ab",
										"parentId": "56b49630d8e5ae8fedb77c5d",
										"slotId": "mod_barrel"
									},
									{
										"_id": "dc6c6ec13c454eb4ecc36413",
										"_tpl": "5fc53954f8b6a877a729eaeb",
										"parentId": "56b49630d8e5ae8fedb77c5d",
										"slotId": "mod_mount_000"
									},
									{
										"_id": "ba308a3ba9dccf96b8a71923",
										"_tpl": "5fc5396e900b1d5091531e72",
										"parentId": "56b49630d8e5ae8fedb77c5d",
										"slotId": "mod_mount_001"
									},
									{
										"_id": "5272b636536f56867b7bf5bd",
										"_tpl": "5fc5396e900b1d5091531e72",
										"parentId": "56b49630d8e5ae8fedb77c5d",
										"slotId": "mod_mount_002"
									},
									{
										"_id": "640711061389e5c422dceac4",
										"_tpl": "5efb0fc6aeb21837e749c801",
										"parentId": "7d0032474bbf714d1239d64f",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 25
										}
									},
									{
										"_id": "d99e728e7ba0fcaa16facda7",
										"_tpl": "6130c4d51cb55961fa0fd49f",
										"parentId": "b5dddb73fb25280c4cd51bd9",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "292112a8a313f2c2bc8f6198",
										"_tpl": "59fc48e086f77463b1118392",
										"parentId": "dc6c6ec13c454eb4ecc36413",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "a1697b641d14d98854e2fbfc",
										"_tpl": "5d2369418abbc306c62e0c80",
										"parentId": "5272b636536f56867b7bf5bd",
										"slotId": "mod_tactical",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									}
								],
							"type": "weapon"
						},
						{
							"id": "07d3fa2df5541b17d8b3746d",
							"name": "Ash12",
							"root": "b0492383acd5a4b53301f849",
							"items": [
									{
										"_id": "b0492383acd5a4b53301f849",
										"_tpl": "5cadfbf7ae92152ac412eeef",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "06f729e3ec2cc7c2e007cf34",
										"_tpl": "5caf187cae92157c28402e43",
										"parentId": "b0492383acd5a4b53301f849",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "4a80df247da70a49478eddcd",
										"_tpl": "5caf1109ae9215753c44119f",
										"parentId": "b0492383acd5a4b53301f849",
										"slotId": "mod_magazine"
									},
									{
										"_id": "644659c1d1c295468af6fe8d",
										"_tpl": "5cdaa99dd7f00c002412d0b2",
										"parentId": "b0492383acd5a4b53301f849",
										"slotId": "mod_handguard"
									},
									{
										"_id": "e40feedc3242e1eb1f4b339c",
										"_tpl": "6171407e50224f204c1da3c5",
										"parentId": "b0492383acd5a4b53301f849",
										"slotId": "mod_scope"
									},
									{
										"_id": "2a41911ee1c30cc5ce2aac69",
										"_tpl": "5d2369418abbc306c62e0c80",
										"parentId": "b0492383acd5a4b53301f849",
										"slotId": "mod_tactical_002",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "ef23097795755cbfed95e6f4",
										"_tpl": "5cadf6eeae921500134b2799",
										"parentId": "4a80df247da70a49478eddcd",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 20
										}
									},
									{
										"_id": "f55f09db6d5707cb79e981e0",
										"_tpl": "5a7dbfc1159bd40016548fde",
										"parentId": "644659c1d1c295468af6fe8d",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "2661b729eaef9f43453b04b5",
										"_tpl": "5b3b99475acfc432ff4dcbee",
										"parentId": "e40feedc3242e1eb1f4b339c",
										"slotId": "mod_scope_000",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "a7e59cd2bf174ac63bfd3acc",
										"_tpl": "577d128124597739d65d0e56",
										"parentId": "e40feedc3242e1eb1f4b339c",
										"slotId": "mod_scope_001"
									},
									{
										"_id": "41517e6587a5a32db092babd",
										"_tpl": "577d141e24597739c5255e01",
										"parentId": "a7e59cd2bf174ac63bfd3acc",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									}
								],
							"type": "weapon"
						},
						{
							"id": "34efc571d0cec8ccf403549d",
							"name": "P90",
							"root": "dd843713676f27335a2e1cf2",
							"items": [
									{
										"_id": "dd843713676f27335a2e1cf2",
										"_tpl": "5cc82d76e24e8d00134b4b83",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "3176bde7a4b120c881e8548f",
										"_tpl": "5cc70093e4a949033c734312",
										"parentId": "dd843713676f27335a2e1cf2",
										"slotId": "mod_magazine"
									},
									{
										"_id": "fe8c9fbfba45b0c6cdff5c5a",
										"_tpl": "5cc700b9e4a949000f0f0f25",
										"parentId": "dd843713676f27335a2e1cf2",
										"slotId": "mod_stock"
									},
									{
										"_id": "ba4fd3a338a84993ae240496",
										"_tpl": "5cc700ede4a949033c734315",
										"parentId": "dd843713676f27335a2e1cf2",
										"slotId": "mod_reciever"
									},
									{
										"_id": "bf6e9893ab3007b659dc4b82",
										"_tpl": "5cc701aae4a949000e1ea45c",
										"parentId": "dd843713676f27335a2e1cf2",
										"slotId": "mod_barrel"
									},
									{
										"_id": "b42303c6a17eacea5ec94840",
										"_tpl": "5cc6ea85e4a949000e1ea3c3",
										"parentId": "dd843713676f27335a2e1cf2",
										"slotId": "mod_charge"
									},
									{
										"_id": "019781e3a852d7c1b317ced9",
										"_tpl": "5cc700cae4a949035e43ba72",
										"parentId": "fe8c9fbfba45b0c6cdff5c5a",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "a9bc42064c0a3fade8bfc145",
										"_tpl": "5cc7012ae4a949001252b43e",
										"parentId": "ba4fd3a338a84993ae240496",
										"slotId": "mod_mount_001"
									},
									{
										"_id": "1005b7f0273f44c276ab6e33",
										"_tpl": "58491f3324597764bc48fa02",
										"parentId": "ba4fd3a338a84993ae240496",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "630bc500ddeb1d8696b8f869",
										"_tpl": "5cc82796e24e8d000f5859a8",
										"parentId": "bf6e9893ab3007b659dc4b82",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "1bcab9783bcfcbafc084afd7",
										"_tpl": "5d2369418abbc306c62e0c80",
										"parentId": "a9bc42064c0a3fade8bfc145",
										"slotId": "mod_tactical",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "776dab288b2f085945d070df",
										"_tpl": "5cebec00d7f00c065c53522a",
										"parentId": "630bc500ddeb1d8696b8f869",
										"slotId": "mod_muzzle"
									}
								],
							"type": "weapon"
						},
						{
							"id": "7f23489af05b4840f3fb9f3a",
							"name": "Vector45",
							"root": "ee55b56a73c2c664ef3c70f1",
							"items": [
									{
										"_id": "ee55b56a73c2c664ef3c70f1",
										"_tpl": "5fb64bc92b1b027b1f50bcf2",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"Foldable": {
												"Folded": false
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "23d55299ee384a653e76bcc3",
										"_tpl": "5fb651dc85f90547f674b6f4",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_magazine"
									},
									{
										"_id": "ea34495c42869be39a9e703b",
										"_tpl": "5fb6567747ce63734e3fa1dc",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_sight_front",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "c73c714b24f597298304c6ae",
										"_tpl": "5fb6564947ce63734e3fa1da",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_sight_rear",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "5ddf0a2cbe6136ba90115046",
										"_tpl": "58491f3324597764bc48fa02",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "a937fddce820f072049dcfa0",
										"_tpl": "5fb655b748c711690e3a8d5a",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_stock"
									},
									{
										"_id": "939f445c327cf8e61e19d8ab",
										"_tpl": "5fb65363d1409e5ca04b54f5",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_barrel"
									},
									{
										"_id": "bcd026f643914c6ae8c99670",
										"_tpl": "5fbb976df9986c4cff3fe5f2",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_mount"
									},
									{
										"_id": "1e937b23ef67265a4d334be0",
										"_tpl": "5fce0f9b55375d18a253eff2",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_mount_001"
									},
									{
										"_id": "3ee1559ebae1365fbb2ec723",
										"_tpl": "5fce0f9b55375d18a253eff2",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_mount_002"
									},
									{
										"_id": "aab0b288f526f173ff41733f",
										"_tpl": "5efb0fc6aeb21837e749c801",
										"parentId": "23d55299ee384a653e76bcc3",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 30
										}
									},
									{
										"_id": "09243bb027055ed7a9ed9efb",
										"_tpl": "5c793fb92e221644f31bfb64",
										"parentId": "a937fddce820f072049dcfa0",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "26bbb6be4454334beffc5c09",
										"_tpl": "5fc4b992187fea44d52edaa9",
										"parentId": "939f445c327cf8e61e19d8ab",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "4bda6f829f0eb4e7334c0435",
										"_tpl": "5b057b4f5acfc4771e1bd3e9",
										"parentId": "bcd026f643914c6ae8c99670",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "d0c0c653d66374773df79818",
										"_tpl": "5d2369418abbc306c62e0c80",
										"parentId": "3ee1559ebae1365fbb2ec723",
										"slotId": "mod_tactical",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "521b09ae4e2cf9535d0d892e",
										"_tpl": "58d2947e86f77447aa070d53",
										"parentId": "09243bb027055ed7a9ed9efb",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "9c3d84ea579b955b330a92cb",
										"_tpl": "58d2912286f7744e27117493",
										"parentId": "521b09ae4e2cf9535d0d892e",
										"slotId": "mod_stock"
									},
									{
										"_id": "36f02a4e6c1572d218497142",
										"_tpl": "5fc4b9b17283c4046c5814d7",
										"parentId": "26bbb6be4454334beffc5c09",
										"slotId": "mod_muzzle"
									}
								],
							"type": "weapon"
						},
						{
							"id": "4ff8c007e93f82b11a9a5fa9",
							"name": "AK101",
							"root": "8894267b5447d86491e6b076",
							"items": [
									{
										"_id": "8894267b5447d86491e6b076",
										"_tpl": "5ac66cb05acfc40198510a10",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"Foldable": {
												"Folded": false
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "19dcb0cfd6c6da0d1fb4cb8b",
										"_tpl": "5b237e425acfc4771e1be0b6",
										"parentId": "8894267b5447d86491e6b076",
										"slotId": "mod_gas_block"
									},
									{
										"_id": "2c28dd603993e80e2d6c6bec",
										"_tpl": "5e21ca18e4d47f0da15e77dd",
										"parentId": "8894267b5447d86491e6b076",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "0533700f94cf6b7b314ddca7",
										"_tpl": "6087e663132d4d12c81fd96b",
										"parentId": "8894267b5447d86491e6b076",
										"slotId": "mod_pistol_grip"
									},
									{
										"_id": "6f85ed916c5bdf457ed62d80",
										"_tpl": "5d2c76ed48f03532f2136169",
										"parentId": "8894267b5447d86491e6b076",
										"slotId": "mod_reciever"
									},
									{
										"_id": "21094b0bd304cc739f39cf59",
										"_tpl": "5ac78eaf5acfc4001926317a",
										"parentId": "8894267b5447d86491e6b076",
										"slotId": "mod_stock"
									},
									{
										"_id": "40bbd7458ba10589bb458737",
										"_tpl": "5ac66c5d5acfc4001718d314",
										"parentId": "8894267b5447d86491e6b076",
										"slotId": "mod_magazine"
									},
									{
										"_id": "ab8def21f939c08cdc1bda02",
										"_tpl": "6130ca3fd92c473c77020dbd",
										"parentId": "8894267b5447d86491e6b076",
										"slotId": "mod_charge"
									},
									{
										"_id": "3f28ec4b3059d31ab70844b4",
										"_tpl": "5b4736a986f774040571e998",
										"parentId": "19dcb0cfd6c6da0d1fb4cb8b",
										"slotId": "mod_mount_000"
									},
									{
										"_id": "55a83285019e7405a9978701",
										"_tpl": "5b4736b986f77405cb415c10",
										"parentId": "19dcb0cfd6c6da0d1fb4cb8b",
										"slotId": "mod_mount_002"
									},
									{
										"_id": "626400a160d3c33527c3ddd8",
										"_tpl": "609269c3b0e443224b421cc1",
										"parentId": "2c28dd603993e80e2d6c6bec",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "814df26855e7ca7a943ead17",
										"_tpl": "58491f3324597764bc48fa02",
										"parentId": "6f85ed916c5bdf457ed62d80",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "51df4e5c437ee573050cd322",
										"_tpl": "59ecc3dd86f7746dc827481c",
										"parentId": "21094b0bd304cc739f39cf59",
										"slotId": "mod_stock"
									},
									{
										"_id": "6e8d128e68946dbf26ae6ad3",
										"_tpl": "54527ac44bdc2d36668b4567",
										"parentId": "40bbd7458ba10589bb458737",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 30
										}
									},
									{
										"_id": "2b078e87b6314b6c5608d67d",
										"_tpl": "5d2369418abbc306c62e0c80",
										"parentId": "3f28ec4b3059d31ab70844b4",
										"slotId": "mod_tactical",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "e5ca59760ba4d61f6c383b13",
										"_tpl": "5c1bc5af2e221602b412949b",
										"parentId": "55a83285019e7405a9978701",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "b9b422525155e731567bb439",
										"_tpl": "60926df0132d4d12c81fd9df",
										"parentId": "626400a160d3c33527c3ddd8",
										"slotId": "mod_muzzle"
									}
								],
							"type": "weapon"
						},
						{
							"id": "11c87363cd19eceabe638159",
							"name": "Mk47",
							"root": "bf8980bc113ec4791a7578ec",
							"items": [
									{
										"_id": "bf8980bc113ec4791a7578ec",
										"_tpl": "606587252535c57a13424cfd",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "800c1dd42086186db9b27e47",
										"_tpl": "59db3a1d86f77429e05b4e92",
										"parentId": "bf8980bc113ec4791a7578ec",
										"slotId": "mod_pistol_grip"
									},
									{
										"_id": "30009c25831bf560ba42e264",
										"_tpl": "59fafc5086f7740dbe19f6c3",
										"parentId": "bf8980bc113ec4791a7578ec",
										"slotId": "mod_magazine"
									},
									{
										"_id": "ed6f89a2665a153c678da0df",
										"_tpl": "606587a88900dc2d9a55b659",
										"parentId": "bf8980bc113ec4791a7578ec",
										"slotId": "mod_reciever"
									},
									{
										"_id": "7f9e10a098e98c2dafdb2755",
										"_tpl": "5c793fb92e221644f31bfb64",
										"parentId": "bf8980bc113ec4791a7578ec",
										"slotId": "mod_stock_001"
									},
									{
										"_id": "f02b0ec14947868d59cace71",
										"_tpl": "606587bd6d0bd7580617bacc",
										"parentId": "bf8980bc113ec4791a7578ec",
										"slotId": "mod_charge"
									},
									{
										"_id": "8a07795bcdcc997ea6db46aa",
										"_tpl": "59e0d99486f7744a32234762",
										"parentId": "30009c25831bf560ba42e264",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 30
										}
									},
									{
										"_id": "baaa1a1146ca63822a626fb3",
										"_tpl": "5b3b99265acfc4704b4a1afb",
										"parentId": "ed6f89a2665a153c678da0df",
										"slotId": "mod_scope"
									},
									{
										"_id": "ad94ba4220d7d98465df6a11",
										"_tpl": "6065878ac9cf8012264142fd",
										"parentId": "ed6f89a2665a153c678da0df",
										"slotId": "mod_barrel"
									},
									{
										"_id": "625a15f090de1fff4967a8a4",
										"_tpl": "5a329052c4a28200741e22d3",
										"parentId": "ed6f89a2665a153c678da0df",
										"slotId": "mod_handguard"
									},
									{
										"_id": "0c6fe1ea8b7794378d198839",
										"_tpl": "58d2946386f774496974c37e",
										"parentId": "7f9e10a098e98c2dafdb2755",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "45fba130ee5eb063bb60e62f",
										"_tpl": "5b3b99475acfc432ff4dcbee",
										"parentId": "baaa1a1146ca63822a626fb3",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "95ba5b45b2570067817da764",
										"_tpl": "5d443f8fa4b93678dd4a01aa",
										"parentId": "ad94ba4220d7d98465df6a11",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "1be56cb228a9f44041570ef5",
										"_tpl": "6065dc8a132d4d12c81fd8e3",
										"parentId": "ad94ba4220d7d98465df6a11",
										"slotId": "mod_gas_block"
									},
									{
										"_id": "e997b199a647951099030c27",
										"_tpl": "5c0102b20db834001d23eebc",
										"parentId": "625a15f090de1fff4967a8a4",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "3727df95f0a0c38c6c50c6ff",
										"_tpl": "5c0102aa0db834001b734ba1",
										"parentId": "625a15f090de1fff4967a8a4",
										"slotId": "mod_mount_004"
									},
									{
										"_id": "4919c86d0fc5d7e30fb1c28a",
										"_tpl": "5d44064fa4b9361e4f6eb8b5",
										"parentId": "95ba5b45b2570067817da764",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "9a70db3a18a4723d6ff6cea6",
										"_tpl": "5c1cd46f2e22164bef5cfedb",
										"parentId": "e997b199a647951099030c27",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "977d9b9caddfe67418330481",
										"_tpl": "5d2369418abbc306c62e0c80",
										"parentId": "3727df95f0a0c38c6c50c6ff",
										"slotId": "mod_tactical",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "25fdeeec5ab96a7be5598b02",
										"_tpl": "58d2912286f7744e27117493",
										"parentId": "0c6fe1ea8b7794378d198839",
										"slotId": "mod_stock"
									}
								],
							"type": "weapon"
						},
						{
							"id": "29ab50dd9de4109922143b4d",
							"name": "MP155",
							"root": "09c8416ab3b626d0bb9c4203",
							"items": [
									{
										"_id": "09c8416ab3b626d0bb9c4203",
										"_tpl": "606dae0ab0e443224b421bb7",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "0c3aa16f7d7826260f2dea1b",
										"_tpl": "6076c1b9f2cb2e02a42acedc",
										"parentId": "09c8416ab3b626d0bb9c4203",
										"slotId": "mod_barrel"
									},
									{
										"_id": "6c77ab9eac7260b91e5e4dd6",
										"_tpl": "606ee5c81246154cad35d65e",
										"parentId": "09c8416ab3b626d0bb9c4203",
										"slotId": "mod_handguard"
									},
									{
										"_id": "5cddb46707a40f7d55a2b246",
										"_tpl": "6076c87f232e5a31c233d50e",
										"parentId": "09c8416ab3b626d0bb9c4203",
										"slotId": "mod_magazine"
									},
									{
										"_id": "b7548e57ce7aeb68a05567b2",
										"_tpl": "606eef46232e5a31c233d500",
										"parentId": "09c8416ab3b626d0bb9c4203",
										"slotId": "mod_stock"
									},
									{
										"_id": "e31af76495fac565713a7eb7",
										"_tpl": "60785ce5132d4d12c81fd918",
										"parentId": "09c8416ab3b626d0bb9c4203",
										"slotId": "mod_mount"
									},
									{
										"_id": "93d4c7c2bca28b15fae6ddc7",
										"_tpl": "5d6e6911a4b9361bd5780d52",
										"parentId": "09c8416ab3b626d0bb9c4203",
										"slotId": "patron_in_weapon"
									},
									{
										"_id": "d33a81fee5d1c8ec8c3a295f",
										"_tpl": "5c0111ab0db834001966914d",
										"parentId": "0c3aa16f7d7826260f2dea1b",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "3a61ccabd0bf24e2a7aca587",
										"_tpl": "607ea812232e5a31c233d53c",
										"parentId": "6c77ab9eac7260b91e5e4dd6",
										"slotId": "mod_mount_000"
									},
									{
										"_id": "aa742043879d660821d21e69",
										"_tpl": "5d6e6911a4b9361bd5780d52",
										"parentId": "5cddb46707a40f7d55a2b246",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 6
										}
									},
									{
										"_id": "5a66fce868a726cb6f6b2533",
										"_tpl": "606eef756d0bd7580617baf8",
										"parentId": "b7548e57ce7aeb68a05567b2",
										"slotId": "mod_stock"
									},
									{
										"_id": "9e29e86421bb8d7cecea9347",
										"_tpl": "570fd6c2d2720bc6458b457f",
										"parentId": "e31af76495fac565713a7eb7",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "05ef173908038174012f7723",
										"_tpl": "59c0ec5b86f77435b128bfca",
										"parentId": "d33a81fee5d1c8ec8c3a295f",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "0a8cd85c07d8b5b1da1f93fa",
										"_tpl": "56def37dd2720bec348b456a",
										"parentId": "3a61ccabd0bf24e2a7aca587",
										"slotId": "mod_tactical",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "3072a88ea2d551681b4585f3",
										"_tpl": "606f262c6d0bd7580617bafa",
										"parentId": "5a66fce868a726cb6f6b2533",
										"slotId": "mod_stock"
									},
									{
										"_id": "fe3b24c20ddebf7fcbaaabe3",
										"_tpl": "606f2696f2cb2e02a42aceb1",
										"parentId": "5a66fce868a726cb6f6b2533",
										"slotId": "mod_tactical",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									}
								],
							"type": "weapon"
						},
						{
							"id": "e7936630a2c0d64112788602",
							"name": "M4A1",
							"root": "a480cb04e8a1b3c03862fe07",
							"items": [
									{
										"_id": "a480cb04e8a1b3c03862fe07",
										"_tpl": "5447a9cd4bdc2dbd208b4567",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "96527a4d089c2c18dceb3f0c",
										"_tpl": "59db3a1d86f77429e05b4e92",
										"parentId": "a480cb04e8a1b3c03862fe07",
										"slotId": "mod_pistol_grip"
									},
									{
										"_id": "4e51c8127df4928348601c51",
										"_tpl": "59bfe68886f7746004266202",
										"parentId": "a480cb04e8a1b3c03862fe07",
										"slotId": "mod_reciever"
									},
									{
										"_id": "495e0c756611d7f78c09316f",
										"_tpl": "5c793fb92e221644f31bfb64",
										"parentId": "a480cb04e8a1b3c03862fe07",
										"slotId": "mod_stock"
									},
									{
										"_id": "7d4c825194094be438766b93",
										"_tpl": "5b2240bf5acfc40dc528af69",
										"parentId": "a480cb04e8a1b3c03862fe07",
										"slotId": "mod_charge"
									},
									{
										"_id": "bb24af9074b5381f25076b61",
										"_tpl": "5b3b99265acfc4704b4a1afb",
										"parentId": "4e51c8127df4928348601c51",
										"slotId": "mod_scope"
									},
									{
										"_id": "146ff2e06ae76487ee013faf",
										"_tpl": "55d3632e4bdc2d972f8b4569",
										"parentId": "4e51c8127df4928348601c51",
										"slotId": "mod_barrel"
									},
									{
										"_id": "9980bcc79fc7ed2c77c17fa3",
										"_tpl": "5c78f2492e221600114c9f04",
										"parentId": "4e51c8127df4928348601c51",
										"slotId": "mod_handguard"
									},
									{
										"_id": "f355f3cd68c31215acf4deda",
										"_tpl": "58d2947e86f77447aa070d53",
										"parentId": "495e0c756611d7f78c09316f",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "4713eb2e0312ec140cb5a229",
										"_tpl": "618ba27d9008e4636a67f61d",
										"parentId": "bb24af9074b5381f25076b61",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "39cc988aa9e78e471813ef3f",
										"_tpl": "609269c3b0e443224b421cc1",
										"parentId": "146ff2e06ae76487ee013faf",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "1dea65169749146969e81937",
										"_tpl": "5d00ec68d7ad1a04a067e5be",
										"parentId": "146ff2e06ae76487ee013faf",
										"slotId": "mod_gas_block"
									},
									{
										"_id": "1da200de64995349172abf37",
										"_tpl": "5b7be4895acfc400170e2dd5",
										"parentId": "9980bcc79fc7ed2c77c17fa3",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "be720edc664af932932f3788",
										"_tpl": "56def37dd2720bec348b456a",
										"parentId": "9980bcc79fc7ed2c77c17fa3",
										"slotId": "mod_tactical_003",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "f1f3f0f0cab7992d9bf29d7a",
										"_tpl": "60926df0132d4d12c81fd9df",
										"parentId": "39cc988aa9e78e471813ef3f",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "2747648813a2ecae05b81a42",
										"_tpl": "58d2912286f7744e27117493",
										"parentId": "f355f3cd68c31215acf4deda",
										"slotId": "mod_stock"
									}
								],
							"type": "weapon"
						},
						{
							"id": "efa26b788869e44e1aba2b26",
							"name": "RD704",
							"root": "44e5329adcc29bd81bff85fc",
							"items": [
									{
										"_id": "44e5329adcc29bd81bff85fc",
										"_tpl": "628a60ae6b1d481ff772e9c8",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "2dc061942241070991bfab9b",
										"_tpl": "628a83c29179c324ed269508",
										"parentId": "44e5329adcc29bd81bff85fc",
										"slotId": "mod_gas_block"
									},
									{
										"_id": "d51608fb1de72820d5f10c97",
										"_tpl": "6130c43c67085e45ef1405a1",
										"parentId": "44e5329adcc29bd81bff85fc",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "a96c305883f093ae74bd5424",
										"_tpl": "628c9ab845c59e5b80768a81",
										"parentId": "44e5329adcc29bd81bff85fc",
										"slotId": "mod_pistol_grip"
									},
									{
										"_id": "64bc890dbd65cafbe592218f",
										"_tpl": "5d2c772c48f0355d95672c25",
										"parentId": "44e5329adcc29bd81bff85fc",
										"slotId": "mod_reciever"
									},
									{
										"_id": "7e8845a9b18030a1c0de32be",
										"_tpl": "5b0e794b5acfc47a877359b2",
										"parentId": "44e5329adcc29bd81bff85fc",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "763f09c02bffc9aca1a8f4de",
										"_tpl": "5cfe8010d7ad1a59283b14c6",
										"parentId": "44e5329adcc29bd81bff85fc",
										"slotId": "mod_magazine"
									},
									{
										"_id": "5449e333954dbdfd9f958c66",
										"_tpl": "6130ca3fd92c473c77020dbd",
										"parentId": "44e5329adcc29bd81bff85fc",
										"slotId": "mod_charge"
									},
									{
										"_id": "c37c96576051f4d23e4ea2db",
										"_tpl": "5b7be47f5acfc400170e2dd2",
										"parentId": "2dc061942241070991bfab9b",
										"slotId": "mod_mount_001"
									},
									{
										"_id": "c9e15cddb62d39dc65b50734",
										"_tpl": "5b7be4895acfc400170e2dd5",
										"parentId": "2dc061942241070991bfab9b",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "7d11292f9e8628dc4c59ed7d",
										"_tpl": "5dfa3d2b0dee1b22f862eade",
										"parentId": "d51608fb1de72820d5f10c97",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "1265b311600dd9dca3899141",
										"_tpl": "5b3b99265acfc4704b4a1afb",
										"parentId": "64bc890dbd65cafbe592218f",
										"slotId": "mod_scope"
									},
									{
										"_id": "f73ae9db60fca0dcfa6bd0eb",
										"_tpl": "601aa3d2b2bcb34913271e6d",
										"parentId": "763f09c02bffc9aca1a8f4de",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 50
										}
									},
									{
										"_id": "147ebcb14d43d9b3441de5aa",
										"_tpl": "56def37dd2720bec348b456a",
										"parentId": "c37c96576051f4d23e4ea2db",
										"slotId": "mod_tactical",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "30191c0ea06acb1487748514",
										"_tpl": "5b057b4f5acfc4771e1bd3e9",
										"parentId": "c9e15cddb62d39dc65b50734",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "94808546f03f64c618ffb670",
										"_tpl": "618ba27d9008e4636a67f61d",
										"parentId": "1265b311600dd9dca3899141",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									}
								]
							"type": "weapon"
							}
						],
				},				
				"trader": {
					"initialLoyaltyLevel": 4,
					"initialStanding": 6.5,
					"initialSalesSum": 10000000,
					"jaegerUnlocked": true
				}
			},
			"usec": {
				"character": {
					"_id": "__REPLACEME__",
					"aid": "__REPLACEME__",
					"savage": "__REPLACEME__",
					"Info": {
						"Nickname": "__REPLACEME__",
						"LowerNickname": "__REPLACEME__",
						"Side": "Usec",
						"Voice": "__REPLACEME__",
						"Level": 50,
						"Experience": 5000000,
						"RegistrationDate": "__REPLACEME__",
						"GameVersion": "edge_of_darkness",
						"AccountType": 0,
						"MemberCategory": 0,
						"lockedMoveCommands": false,
						"SavageLockTime": 0,
						"LastTimePlayedAsSavage": 0,
						"Settings": {
							"Role": "assault",
							"BotDifficulty": "easy",
							"Experience": -1
						},
						"NicknameChangeDate": 0,
						"IsStreamerModeAvailable": false,
						"Bans": [],
						"BannedState": false,
						"BannedUntil": 0
					},
					"Customization": {
						"Head": "__REPLACEME__",
						"Body": "5cde95d97d6c8b647a3769b0",
						"Feet": "5cde95ef7d6c8b04713c4f2d",
						"Hands": "5cde95fa7d6c8b04737c2d13"
					},
					"Health": {
						"Hydration": {
							"Current": 100,
							"Maximum": 100
						},
						"Energy": {
							"Current": 100,
							"Maximum": 100
						},
						"Temperature": {
							"Current": 36.6,
							"Maximum": 40
						},
						"BodyParts": {
							"Head": {
								"Health": {
									"Current": 35,
									"Maximum": 35
								}
							},
							"Chest": {
								"Health": {
									"Current": 85,
									"Maximum": 85
								}
							},
							"Stomach": {
								"Health": {
									"Current": 70,
									"Maximum": 70
								}
							},
							"LeftArm": {
								"Health": {
									"Current": 60,
									"Maximum": 60
								}
							},
							"RightArm": {
								"Health": {
									"Current": 60,
									"Maximum": 60
								}
							},
							"LeftLeg": {
								"Health": {
									"Current": 65,
									"Maximum": 65
								}
							},
							"RightLeg": {
								"Health": {
									"Current": 65,
									"Maximum": 65
								}
							}
						},
						"UpdateTime": 1608815684
					},
					"Inventory": {
						"items": [
							{
								"_id": "5fe49444ae6628187a2e77b8",
								"_tpl": "55d7217a4bdc2d86028b456d"
							},
							{
								"_id": "5fe49444ae6628187a2e78b9",
								"_tpl": "5963866286f7747bf429b572"
							},
							{
								"_id": "60dca3da42ad9b706b369aca",
								"_tpl": "602543c13fee350cd564d032"
							},
							{
								"_id": "5daff21fb5c244a4688fefac",
								"_tpl": "5cadfbf7ae92152ac412eeef",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "FirstPrimaryWeapon",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 97.80438
									},
									"FireMode": {
										"FireMode": "fullauto"
									}
								}
							},
							{
								"_id": "085fd238df0f6b8cb523b015",
								"_tpl": "576165642459773c7a400233",
								"parentId": "af06df24bdba4fffafc713b4",
								"slotId": "main",
								"upd": {
									"Repairable": {
										"MaxDurability": 100,
										"Durability": 98.8364258
									},
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									}
								},
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "08c303bb789e0195ab0709f1",
								"_tpl": "5c0126f40db834002a125382",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "Scabbard",
								"upd": {
									"Repairable": {
										"MaxDurability": 85,
										"Durability": 85
									}
								}
							},
							{
								"_id": "8df328f95424ab99fddd463f",
								"_tpl": "5e00c1ad86f774747333222c",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "Headwear",
								"upd": {
									"Repairable": {
										"MaxDurability": 45,
										"Durability": 45
									}
								}
							},
							{
								"_id": "72f360237fe8ee1284961d95",
								"_tpl": "5648a69d4bdc2ded0b8b457b",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "TacticalVest"
							},
							{
								"_id": "cdd348f89973bce51ac19dc1",
								"_tpl": "5857a8bc2459772bad15db29",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "SecuredContainer"
							},
							{
								"_id": "b59e12548a20f3bff9c1786f",
								"_tpl": "5f5e467b0bc58666c37e7821",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "Backpack"
							},
							{
								"_id": "f9cdbb89ef373b56e9dda9ae",
								"_tpl": "5ab8e79e86f7742d8b372e78",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "ArmorVest",
								"upd": {
									"Repairable": {
										"MaxDurability": 65,
										"Durability": 65
									}
								}
							},
							{
								"_id": "f0df421189d216fd315fea3e",
								"_tpl": "627a4e6b255f7527fb05a0f6",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "Pockets"
							},
							{
								"_id": "e67d133484516735789c8467",
								"_tpl": "6033fa48ffd42c541047f728",
								"parentId": "5fe49444ae6628187a2e77b8",
								"slotId": "Earpiece"
							},
							{
								"_id": "0bfc981e9527cae6e288fc8f",
								"_tpl": "5caf187cae92157c28402e43",
								"parentId": "5daff21fb5c244a4688fefac",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "ba2ebd13f9e44ad3aa9c8de1",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "5daff21fb5c244a4688fefac",
								"slotId": "mod_magazine"
							},
							{
								"_id": "4b3a46e451e32854c42f98d5",
								"_tpl": "5cdaa99dd7f00c002412d0b2",
								"parentId": "5daff21fb5c244a4688fefac",
								"slotId": "mod_handguard"
							},
							{
								"_id": "f5a6a2a4344bfbb748ab894a",
								"_tpl": "6171407e50224f204c1da3c5",
								"parentId": "5daff21fb5c244a4688fefac",
								"slotId": "mod_scope"
							},
							{
								"_id": "dd53750403b430f7be3ec626",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "5daff21fb5c244a4688fefac",
								"slotId": "mod_tactical_002",
								"upd": {
									"Light": {
										"IsActive": false,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "6d181309b9a353d7455f1c06",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "5daff21fb5c244a4688fefac",
								"slotId": "patron_in_weapon"
							},
							{
								"_id": "444029a202f5ce2ee2850b6d",
								"_tpl": "591ee00d86f774592f7b841e",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_mount_000"
							},
							{
								"_id": "94b6249b17f352924d2979f0",
								"_tpl": "5f63418ef5750b524b45f116",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_handguard"
							},
							{
								"_id": "293b574ded89301e7f1a8c29",
								"_tpl": "59fb137a86f7740adb646af1",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_muzzle"
							},
							{
								"_id": "8ffcafd0ad5663f289b1a427",
								"_tpl": "5649ade84bdc2d1b2b8b4587",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_pistol_grip"
							},
							{
								"_id": "df49f93ad674e36163bdc63c",
								"_tpl": "57616c112459773cce774d66",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_reciever"
							},
							{
								"_id": "7436ea794321e92041e377e6",
								"_tpl": "57a9b9ce2459770ee926038d",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_sight_rear",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "1d295f6767e5513ea792404d",
								"_tpl": "57616ca52459773c69055192",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_stock"
							},
							{
								"_id": "8feda48615b1586ce64e8736",
								"_tpl": "5cf8f3b0d7f00c00217872ef",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "mod_magazine"
							},
							{
								"_id": "76fe21224910d039b8c5eba0",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "085fd238df0f6b8cb523b015",
								"slotId": "patron_in_weapon"
							},
							{
								"_id": "05d7508cd30ca12d7e0bd12e",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "1",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "0fbefce31c5d8c749ddfa132",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "2",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "dfd0297db3b09e0037b147ba",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "3",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "c704ac1dcd0addd0dd6a8bbd",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "4",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "e835107b518e71f78cd058e2",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "5",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "660966aa5debb0e4c0b97d66",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "5",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "6e3eb18536bee2eaac687931",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "8",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "49dcb77c6d797cc1ed4d1480",
								"_tpl": "5e8488fa988a8701445df1e4",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "9",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"MedKit": {
										"HpResource": 3
									}
								}
							},
							{
								"_id": "e54403d5202f89f7e7df1c96",
								"_tpl": "5caf1109ae9215753c44119f",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "10",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "77512f3237c4e3970eda3889",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "72f360237fe8ee1284961d95",
								"slotId": "11",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "2ce1f3af873078bee3041b48",
								"_tpl": "619cbf7d23893217ec30b689",
								"parentId": "cdd348f89973bce51ac19dc1",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "30af2f339c3d9e5fbab39e33",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "cdd348f89973bce51ac19dc1",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "4fc414af7fd108a5ccbe0ef7",
								"_tpl": "5755383e24597772cb798966",
								"parentId": "cdd348f89973bce51ac19dc1",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"MedKit": {
										"HpResource": 6
									}
								}
							},
							{
								"_id": "a10a45ccc990feb252b2cbab",
								"_tpl": "5af0454c86f7746bf20992e8",
								"parentId": "cdd348f89973bce51ac19dc1",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"MedKit": {
										"HpResource": 5
									}
								}
							},
							{
								"_id": "78e18bb2725891a10d8a5d4d",
								"_tpl": "61605e13ffa6e502ac5e7eef",
								"parentId": "f0df421189d216fd315fea3e",
								"slotId": "SpecialSlot1"
							},
							{
								"_id": "f3e702352faef0766f9e20de",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "f0df421189d216fd315fea3e",
								"slotId": "pocket4",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "e35e53b553b2280edde8863c",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "ba2ebd13f9e44ad3aa9c8de1",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "9195da2e7fbfea3568a5eeae",
								"_tpl": "5a7dbfc1159bd40016548fde",
								"parentId": "4b3a46e451e32854c42f98d5",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "fbe85aa90576f3840f013f8c",
								"_tpl": "5b3b99475acfc432ff4dcbee",
								"parentId": "f5a6a2a4344bfbb748ab894a",
								"slotId": "mod_scope_000",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											1
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "a215128785324188a73f22dc",
								"_tpl": "577d128124597739d65d0e56",
								"parentId": "f5a6a2a4344bfbb748ab894a",
								"slotId": "mod_scope_001"
							},
							{
								"_id": "45ccf52a98d105feb25f4d84",
								"_tpl": "577d141e24597739c5255e01",
								"parentId": "a215128785324188a73f22dc",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "9d8377f2fb367a23b7763172",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "444029a202f5ce2ee2850b6d",
								"slotId": "mod_scope",
								"upd": {
									"Sight": {
										"ScopesCurrentCalibPointIndexes": [
											0
										],
										"ScopesSelectedModes": [
											0
										],
										"SelectedScope": 0
									}
								}
							},
							{
								"_id": "8281584f2068a24a33a18c9c",
								"_tpl": "5b3a337e5acfc4704b4a19a0",
								"parentId": "444029a202f5ce2ee2850b6d",
								"slotId": "mod_tactical",
								"upd": {
									"Light": {
										"IsActive": false,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "235a1e6f37825bef846e9e55",
								"_tpl": "5b057b4f5acfc4771e1bd3e9",
								"parentId": "94b6249b17f352924d2979f0",
								"slotId": "mod_foregrip"
							},
							{
								"_id": "4b28243b6ce791043e27e8a2",
								"_tpl": "5a7b483fe899ef0016170d15",
								"parentId": "94b6249b17f352924d2979f0",
								"slotId": "mod_tactical_000",
								"upd": {
									"Light": {
										"IsActive": false,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "a0b15568257164f43ea7070d",
								"_tpl": "5b3a337e5acfc4704b4a19a0",
								"parentId": "94b6249b17f352924d2979f0",
								"slotId": "mod_tactical_001",
								"upd": {
									"Light": {
										"IsActive": false,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "7d08c8e95553d6023af32681",
								"_tpl": "5b3a337e5acfc4704b4a19a0",
								"parentId": "94b6249b17f352924d2979f0",
								"slotId": "mod_tactical_002",
								"upd": {
									"Light": {
										"IsActive": false,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "784c6c1d5d7c8dd3454ea202",
								"_tpl": "5b3a337e5acfc4704b4a19a0",
								"parentId": "94b6249b17f352924d2979f0",
								"slotId": "mod_tactical_003",
								"upd": {
									"Light": {
										"IsActive": false,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "f6b6b12ff839e61d0b9a1815",
								"_tpl": "5b3a337e5acfc4704b4a19a0",
								"parentId": "94b6249b17f352924d2979f0",
								"slotId": "mod_tactical_004",
								"upd": {
									"Light": {
										"IsActive": false,
										"SelectedMode": 0
									}
								}
							},
							{
								"_id": "1e57b3031fcc41cf18af2e90",
								"_tpl": "5a0c59791526d8dba737bba7",
								"parentId": "1d295f6767e5513ea792404d",
								"slotId": "mod_stock"
							},
							{
								"_id": "512808e2bc2d4633357096e7",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "8feda48615b1586ce64e8736",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "158d907ed0c1105a983da9ec",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "05d7508cd30ca12d7e0bd12e",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "1c0149ab91859bf35d4fcb28",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "0fbefce31c5d8c749ddfa132",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "e2622d13948df3c7c768038e",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "dfd0297db3b09e0037b147ba",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 13
								}
							},
							{
								"_id": "85179f750a46bd93a0667a14",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "c704ac1dcd0addd0dd6a8bbd",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "9c5cd6884592a977b363c6f3",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "e835107b518e71f78cd058e2",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "1aa6da43bbf54f963ae6b6ce",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "660966aa5debb0e4c0b97d66",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "91d2c8150051434785e982db",
								"_tpl": "5cadf6eeae921500134b2799",
								"parentId": "e54403d5202f89f7e7df1c96",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "cb6f8ade13378d9a7ca47817",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "13a93f7bc96a997bf801fc39",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "14aefc59dee7d96071424479",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "ef10316d461c00fb0ec23fb4",
								"_tpl": "5c0e531d86f7747fa23f4d42",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "da83962bcca7a6ce00fd64e3",
								"_tpl": "5c0e530286f7747fa1419862",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "8541fb08db69fe8b1b7ac4fa",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "add48490272037e6cbef57cc",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "8fbe2d99c247ba6b55adf2c8",
								"_tpl": "5c0e534186f7747fa1419867",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "7a4f54d3a4b38ffc942816b6",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"parentId": "2ce1f3af873078bee3041b48",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "5fe49444ae6628187a2e78b8",
								"_tpl": "5811ce772459770e9e5f9532"
							},
							{
								"_id": "5fe49444ae6628187a2e78ba",
								"_tpl": "5963866b86f7747bfa1c4462"
							},
							{
								"_id": "5696e09b3448d14b8ad1f3e9",
								"_tpl": "569668774bdc2da2298b4568",
								"parentId": "98dcde79bc426a2b045ae19c",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 50000
								}
							},
							{
								"_id": "bb363db77d34926599d768f0",
								"_tpl": "59fb016586f7746d0d4b423a",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "b20df6cea32bf80c0001b99e",
								"_tpl": "5d235bb686f77443f4331278",
								"parentId": "9ebe7b2d496ce22c63be8525",
								"slotId": "2",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": "Reserve"
									}
								}
							},
							{
								"_id": "294e09e971ddf3e4e255218e",
								"_tpl": "59fb042886f7746c5005a7b2",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 19,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": ""
									}
								}
							},
							{
								"_id": "bbc30f508bed374aa0fe4d9e",
								"_tpl": "59fb042886f7746c5005a7b2",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 19,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": "Head gear"
									}
								}
							},
							{
								"_id": "d58bf4cc06ff1c1e56c804fe",
								"_tpl": "5aafbcd986f7745e590fff23",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": "Kits"
									}
								}
							},
							{
								"_id": "f320a05e44b55f269a28d835",
								"_tpl": "5c093db286f7740a1b2617e3",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": "Drinks"
									}
								}
							},
							{
								"_id": "b5394050928646602c4428fb",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "7412803b2647102af46de246",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "f48af07392c06188bbe67ceb",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "5532d43fdecaf4edce0edce9",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "54b42ca4e1c09091153b2779",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "6459b766b9422e3dc8906110",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "2e1b4f7c47ce7b50f1e6c38f",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "cd1d9f78e48931e91a9da9df",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "0175e00a717f38c307044b0e",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "68eb83d2ce59457b1bf031ab",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "eb297d821b714a2b22c03e20",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "2b0540a456546e39c383a429",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "d6c706e6d66e8749b05f9156",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "72648cfbc90c377f0e0fa4b0",
								"_tpl": "590c5f0d86f77413997acfab",
								"parentId": "acdf382a7b0a4aaf4bdf58a4",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "2ef955a3de47d821879d802a",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "aebecf23b4841fe34208f525",
								"_tpl": "5c0fa877d174af02a012e1cf",
								"parentId": "f320a05e44b55f269a28d835",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8ece6624620faa5ebcc895c7",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 334
									}
								}
							},
							{
								"_id": "616b287cb731842d736e3a6f",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "bc0d3ae634568fd321db38ca",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "795fb2352d6f2d5a3f5f8ab4",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "f7dfb944a241fc31a4d066dd",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "a0f715e41811cf297561211c",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "95eb87e5574eae56aefe55d4",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "3f9ad7b4c8e69da081c2bbb9",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "221a865e8819ca5bf8000a87",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "747fec673e985457853f6169",
								"_tpl": "5d02797c86f774203f38e30a",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 15
									}
								}
							},
							{
								"_id": "abfeac2975d9fa076ad748ec",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "93766b5b020dae6ad0c2be14",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d45b47ee5d34a052189fc0dd",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "01614a0ad8f3ec40038019d0",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5077a50e85fcf5fc8dd6ca0c",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "685bee94d717ac6cb841645d",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0f3a01265fce96742b2fc2f4",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5728340149abb8be258098d2",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0fe374cf705e8f39c995a5f9",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ec56f17fc492b727b6eab5f3",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e7c0f9563f6b37f6d8c31a07",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "91e8fa35eaa0135136d7879b",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7952fb3ff929a545d4ea1f29",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2534720351a8316536183a1e",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "93ba38305ab2576eddcf0da8",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b2a367cbb17d04ebe2ed21f1",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f73a89a4d554d77adf39adfc",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4a2ad8f851785baf08912635",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "995382bfbc38d7a83b77ae8d",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7ac2908181192977e25c5043",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2cf68d7ae9130b486a75ba8f",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c6b37c914ccb7d6ae3402a22",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0604d70ae224692bde23a43f",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d17f3eafb09c0febad7c000a",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "24b94e795ecd81ee06069b1e",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f6347c5d41377af39b164481",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "75c385eb78c5f502c55b1852",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "090333ae995362b8351a4d63",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f497279f27742e7d85f6d32d",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "963970562c716ebfb37560e8",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c845614e52eb9f62eaf8185c",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a7b3a8eb864d17ab103555a7",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1cedc365cb47abab2a815d5f",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "072c601499b7cb51ef2f320a",
								"_tpl": "628e4e576d783146b124c64d",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "395e577551fc114e3bd7f6a0",
								"_tpl": "628e4e576d783146b124c64d",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2bbe9b21e5453d236e8ac2c8",
								"_tpl": "6033fa48ffd42c541047f728",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9d3545f74260002ba99f281c",
								"_tpl": "6033fa48ffd42c541047f728",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "da24e3d047f2f2ca7482f705",
								"_tpl": "5e00c1ad86f774747333222c",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e82614e65846a38e6d775e26",
								"_tpl": "5e00c1ad86f774747333222c",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9065104db0dd85f3db288ea8",
								"_tpl": "5ab8e79e86f7742d8b372e78",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "63692f1e268d06fcbd1375e2",
								"_tpl": "5ab8e79e86f7742d8b372e78",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cf70e23b122d7f020293a126",
								"_tpl": "5e2af55f86f7746d4159f07c",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "7fb3e6cf4b3f9139a2a8628d",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "0ca979353cdd6966a43aae25",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "19eb30ae524641d49ac4ecba",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "222de4b3db5a9c2d330e6692",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "9ef27104d0a5f8b9a0216bf6",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "52c36b67c245273dcb08b343",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8a747ef284e2cb4c739dcfdc",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "6d9ed817307aceb6565534b9",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "c875176952b8743a0bd154e8",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "43339dab09d84ba540a280b1",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "3332239a9ffec32ef7c02000",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "69ebdc19c82e889dfc0e99be",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "eb1d63b6e9273e0759735eea",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "f5501a557a566f414e3dccef",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "553b62ddc696807e9033e8ae",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8034f52b196b776f29a9609b",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "13cb6f91112c93554ee01eda",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "29ebe7d2e0587c00d4ffe4c4",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "42955af40e8b919e0804cff6",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "cdfc5e830addbc66d9da57d4",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "cf3a9815171b5a303892d59c",
								"_tpl": "58d3db5386f77426186285a0",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "49635a941fe4f42d4da142ef",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "7256e25e1acea7caa43ac81a",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "5eac21b7df325aa5e1a9043d",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "1bc8b2c377942676a70fcc75",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "373a07dd99d53e717051a7d2",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8f27aca9a66685d3a9e6e924",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "2e989ccfc06b2ec231cc11e7",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8072e31d8940b7375573acdb",
								"_tpl": "5910968f86f77425cf569c32",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "81d6b0ba8d55d99ac1765d4a",
								"_tpl": "591094e086f7747caa7bb2ef",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "82b6f2edbcc846f8fc77108d",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Other"
									}
								}
							},
							{
								"_id": "8f1d8e5f96d933f306a79b5e",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 2,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "762x39"
									}
								}
							},
							{
								"_id": "38914e925722c0bd710283ba",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 6,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "762x51"
									}
								}
							},
							{
								"_id": "08616521e6794e5f812fe4b1",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "556x45"
									}
								}
							},
							{
								"_id": "1cb12514507b72446601028d",
								"_tpl": "5aafbde786f774389d0cbc0f",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": ".45"
									}
								}
							},
							{
								"_id": "e16dee62f9d7483fd0beb908",
								"_tpl": "5b6d9ce188a4501afc1b2b25",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 14,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Assault Rifles"
									}
								}
							},
							{
								"_id": "af06df24bdba4fffafc713b4",
								"_tpl": "5b6d9ce188a4501afc1b2b25",
								"slotId": "hideout",
								"location": {
									"x": 5,
									"y": 14,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Other"
									}
								}
							},
							{
								"_id": "984d6454f5797cb1e1060315",
								"_tpl": "5b7c710788a4506dec015957",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 23,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "37acef9c25cb283bf0313b0c",
								"_tpl": "5b7c710788a4506dec015957",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 23,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7d94997370b1fddae46da869",
								"_tpl": "5c093e3486f77430cb02e593",
								"slotId": "7",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "600951b8f6a2da6ae32c4424",
								"_tpl": "5c0a840b86f7742ffa4f2482",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 16,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Armor & Rigs"
									}
								}
							},
							{
								"_id": "b330c2a8b154d6401ab7afa1",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Other"
									}
								}
							},
							{
								"_id": "f5b916fc823e3f79bf4d82fc",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 2,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "762x39"
									}
								}
							},
							{
								"_id": "d82ef485d9095b4208e1147e",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "556x45"
									}
								}
							},
							{
								"_id": "b7af0761d04c91ff0bccea8d",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 6,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "762x51"
									}
								}
							},
							{
								"_id": "30305c344a2eaaf517de854a",
								"_tpl": "5c127c4486f7745625356c13",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 11,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": ".45"
									}
								}
							},
							{
								"_id": "24442780538965a0eec3ae85",
								"_tpl": "5696686a4bdc2da3298b456a",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "98dcde79bc426a2b045ae19c",
								"upd": {
									"StackObjectsCount": 50000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1ad7e8f05bcb7345a08da9f5",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "49f2afe2fc23ca45af6e7567",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "dee59a401920a88acc1d9727",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c8b5f2925c3a4a96a12e9bfd",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "840cd785b5b6f5b971907974",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "56d5ba5a34a72c31affbfca8",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "176ee840f2622896747e4fd5",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "134309998dcfbf8639698b26",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0a11e27909cbc5fcbd478fac",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"parentId": "2c9bf00b11854cbc165b2264",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 250000
								}
							},
							{
								"_id": "b37d2af121d07432c2d38106",
								"_tpl": "5c0a840b86f7742ffa4f2482",
								"slotId": "hideout",
								"location": {
									"x": 5,
									"y": 16,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Backpacks"
									}
								}
							},
							{
								"_id": "5d9901441bd6291b1ab9b5cc",
								"_tpl": "5a0dc45586f7742f6b0b73e3",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7d95c6290f56de04baa99a0b",
								"_tpl": "5a0dc95c86f77452440fc675",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8f55c8bb721609c7f6f09a0d",
								"_tpl": "5a0eb6ac86f7743124037a28",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0d72532894bcbf9f2827155d",
								"_tpl": "61a64428a8c6aa1b795f0ba1",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e6e3db327e732e0e6f6e1a5",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fc9b9d3b7a70b55270d8b782",
								"_tpl": "5a0ea64786f7741707720468",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b29c2695c6e86b420e4d2801",
								"_tpl": "5a144dfd86f77445cb5a0982",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6427507b3992ed3a585623ab",
								"_tpl": "5a0ee30786f774023b6ee08f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ca50f8e08ee8fe4ec6ed48a3",
								"_tpl": "5a13eebd86f7746fd639aa93",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2e770672b2a4a9a8916ee277",
								"_tpl": "5a0f0f5886f7741c4e32a472",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "89d546c9619e0cf1f45adb05",
								"_tpl": "5a0f08bc86f77478f33b84c2",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9e37d8bb6b7e47b01851113e",
								"_tpl": "5a144bdb86f7741d374bbde0",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "241bf167974f6b8b6370a0b9",
								"_tpl": "5a13f35286f77413ef1436b0",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a1a5c915a6470a3bfadef290",
								"_tpl": "5a0ee34586f774023b6ee092",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e42c0fca0b0eff6268d52fdc",
								"_tpl": "5a13ef7e86f7741290491063",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fe9109dad6d0d99407659b4e",
								"_tpl": "5a145d4786f7744cbb6f4a12",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0a4aedd1d53114e3536600d8",
								"_tpl": "5a0eec9686f77402ac5c39f2",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "de53dc2746df3b52a6af9f98",
								"_tpl": "5a13f46386f7741dd7384b04",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0b55ff79ad9599ac0c156004",
								"_tpl": "5a0eff2986f7741fd654e684",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c5e92405dbb83d1d30465f01",
								"_tpl": "5a0eecf686f7740350630097",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6cdffcc905f27fd64f6774dc",
								"_tpl": "5a145ebb86f77458f1796f05",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8e2acf36650eca594aa6c0cb",
								"_tpl": "591382d986f774465a6413a7",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "580f9e7a3268b42ccb47737e",
								"_tpl": "5780cf7f2459777de4559322",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1f1cdddce92f2f2b44b8d82f",
								"_tpl": "59148c8a86f774197930e983",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b282c376b0b0d8f2a9ff3b7b",
								"_tpl": "5780d0652459777df90dcb74",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b2947a5e31d6c626a38bf026",
								"_tpl": "5913877a86f774432f15d444",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "989510b5a06cc37093882f00",
								"_tpl": "5a0f045e86f7745b0f0d0e42",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7bca3772728527f0aa48765a",
								"_tpl": "59387a4986f77401cc236e62",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "02d147754e0384a3b63ed3c6",
								"_tpl": "5448ba0b4bdc2d02308b456c",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ac39fb11fd7e838f0906bd98",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a2d3e036139a48ab06e03619",
								"_tpl": "5780cf942459777df90dcb72",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b7afa3d02c2589bc3d75a5eb",
								"_tpl": "5ad5d7d286f77450166e0a89",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "88fd974874140b1df3f51df1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8965e945a96e9fcfa0b73d10",
								"_tpl": "5addaffe86f77470b455f900",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "88fd974874140b1df3f51df1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a40c5963105df97621b395fa",
								"_tpl": "5ad5cfbd86f7742c825d6104",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "88fd974874140b1df3f51df1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "131f55d24267654fc0287bf0",
								"_tpl": "5ad5db3786f7743568421cce",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "88fd974874140b1df3f51df1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "84b1f6dab28f4cb390925c73",
								"_tpl": "5ad7247386f7747487619dc3",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "88fd974874140b1df3f51df1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8886931b5daec121aa88ea7c",
								"_tpl": "5ad5d64486f774079b080af8",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "88fd974874140b1df3f51df1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5c5582fc4d2d090a74a5b0e6",
								"_tpl": "5c1d0f4986f7744bb01837fa",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0ab18b0f74552b30dce25273",
								"_tpl": "5c1d0c5f86f7744bb2683cf0",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "dff741673c098381e007fbfe",
								"_tpl": "5efde6b4f5448336730dbd61",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b176da258c2ba5c95683432c",
								"_tpl": "5eff09cd30a7dc22fd1ddfed",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7f9c0dceb3951640fb67ab7c",
								"_tpl": "5c1d0dc586f7744baf2e7b79",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d5bf90ab86ac485af39bc721",
								"_tpl": "5c1d0efb86f7744baf2e7b7b",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6c3165cbd3212bfaf0f2211c",
								"_tpl": "5c1f79a086f7746ed066fb8f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c55021500a33f91b71be5c5e",
								"_tpl": "5c1e2d1f86f77431e9280bee",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "08baa94b3ea456904dde2990",
								"_tpl": "5c1e2a1e86f77431ea0ea84c",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "791cf7a991ba67aae7ad81ef",
								"_tpl": "5d80cb3886f77440556dbf09",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a88eaad59e11b43b8e76079e",
								"_tpl": "5d95d6fa86f77424484aa5e9",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c5a0bb0fa16a9f130f7caf2f",
								"_tpl": "5d80c62a86f7744036212b3f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9692eaa3bb42c0c50fd867b4",
								"_tpl": "5d80c60f86f77440373c4ece",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9b74d64f690e74d8d52f835f",
								"_tpl": "5d8e0e0e86f774321140eb56",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0a4da330e04aefee521041b6",
								"_tpl": "5d947d4e86f774447b415895",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "df82a0b1bdeec3714e43617d",
								"_tpl": "5d80c6c586f77440351beef1",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "31f06963f8afd9458a95ffc5",
								"_tpl": "5d80ccac86f77470841ff452",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6bc2e0526866931c18f25127",
								"_tpl": "5d80ccdd86f77474f7575e02",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6c9ce8c8c95111f215b84a2c",
								"_tpl": "5d80cd1a86f77402aa362f42",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6fe2bdd75373f0bc821bfcfa",
								"_tpl": "5d947d3886f774447b415893",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "87b557496369960aad4a2f48",
								"_tpl": "5d9f1fa686f774726974a992",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b20df6cea32bf80c0001b99e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7d4c5a0b3a1aa896863a5bf0",
								"_tpl": "591afe0186f77431bd616a11",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "ac39fb11fd7e838f0906bd98",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b93123909be3e0fcb9435d5c",
								"_tpl": "62987c658081af308d7558c6",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e6e3db327e732e0e6f6e1a5",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "474601c5b6eaecf46c097d6c",
								"_tpl": "62987da96188c076bc0d8c51",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e6e3db327e732e0e6f6e1a5",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8bb42b0696c8aa87bf83833f",
								"_tpl": "62987dfc402c7f69bf010923",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "6e6e3db327e732e0e6f6e1a5",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "97bd12ba3fa7e629697b7c02",
								"_tpl": "5448ba0b4bdc2d02308b456c",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6e6e3db327e732e0e6f6e1a5",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "3",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Lighthouse"
									}
								}
							},
							{
								"_id": "a4842b5e3961422bd8acbd72",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "1",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Shoreline"
									}
								}
							},
							{
								"_id": "88fd974874140b1df3f51df1",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "2",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Interchange"
									}
								}
							},
							{
								"_id": "e24de543182a4c82e7ad17b2",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "4",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Labs"
									}
								}
							},
							{
								"_id": "478d50784d1624e0c6ea025b",
								"_tpl": "5c94bbff86f7747ee735c08f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b2f22e3b6e8d959c4dd8bcce",
								"_tpl": "5c94bbff86f7747ee735c08f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9abd067eae867b52c54ca24b",
								"_tpl": "5c94bbff86f7747ee735c08f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "51ddc35570670b417b69c94b",
								"_tpl": "5c94bbff86f7747ee735c08f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bb25a063d9350ac5a2271d08",
								"_tpl": "5c94bbff86f7747ee735c08f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "e24de543182a4c82e7ad17b2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ae739c40213c1aa034d94d00",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "5",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Streets"
									}
								}
							},
							{
								"_id": "ac39fb11fd7e838f0906bd98",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "6",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Other"
									}
								}
							},
							{
								"_id": "2c9bf00b11854cbc165b2264",
								"_tpl": "5d235bb686f77443f4331278",
								"slotId": "1",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false,
									"Tag": {
										"Color": 0,
										"Name": "Customs"
									}
								}
							},
							{
								"_id": "9ebe7b2d496ce22c63be8525",
								"_tpl": "5e9db13186f7742f845ee9d3",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "5fe49444ae6628187a2e78b8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "98dcde79bc426a2b045ae19c",
								"_tpl": "59fb016586f7746d0d4b423a",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 2,
									"y": 0,
									"r": 1
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "acdf382a7b0a4aaf4bdf58a4",
								"_tpl": "5c093db286f7740a1b2617e3",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Tag": {
										"Color": 0,
										"Name": "Food"
									}
								}
							},
							{
								"_id": "866565f1635d3afdefbe487b",
								"_tpl": "5aafbcd986f7745e590fff23",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 7,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0,
									"Tag": {
										"Color": 0,
										"Name": "Misc"
									}
								}
							},
							{
								"_id": "51023c6a29c60e2fbdaffaa7",
								"_tpl": "59fb016586f7746d0d4b423a",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "94d293b2ab205cab3214e294",
								"_tpl": "59fb016586f7746d0d4b423a",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "5b4da63a79e4b589697dc405",
								"_tpl": "59fb023c86f7746d0d4b423c",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 19,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "eef1491a8278785ca583f724",
								"_tpl": "59fb023c86f7746d0d4b423c",
								"parentId": "5fe49444ae6628187a2e78b8",
								"slotId": "hideout",
								"location": {
									"x": 8,
									"y": 24,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "86c755f233755987a7c9e08e",
								"_tpl": "5b0bbe4e5acfc40dc528a72d",
								"parentId": "e16dee62f9d7483fd0beb908",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "1e84939d3c617732e95517be",
								"_tpl": "5b7bedd75acfc43d825283f9",
								"parentId": "86c755f233755987a7c9e08e",
								"slotId": "mod_handguard",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "2b95508afe52bdeaada794d9",
								"_tpl": "5cf78720d7f00c06595bc93e",
								"parentId": "13461f18b080cb706587eedb",
								"slotId": "mod_muzzle_001",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "5b0211fca1c5227a07ad1314",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "cc44adadd9cc93d4a06fd9b1",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "630fbf12d011d67a339eff5c",
								"_tpl": "5b7d679f5acfc4001a5c4024",
								"parentId": "86c755f233755987a7c9e08e",
								"slotId": "mod_pistol_grip",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "c3b22d97167740c9135fb15c",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "f27397deeda98ceba571c783",
								"slotId": "mod_tactical",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "13461f18b080cb706587eedb",
								"_tpl": "5cf78496d7f00c065703d6ca",
								"parentId": "aa259add23daa29cfd5277dd",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "aa259add23daa29cfd5277dd",
								"_tpl": "5b7be1265acfc400161d0798",
								"parentId": "86c755f233755987a7c9e08e",
								"slotId": "mod_barrel",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "cb385e1a736b372fc833ba40",
								"_tpl": "5c878e9d2e2216000f201903",
								"parentId": "13461f18b080cb706587eedb",
								"slotId": "mod_muzzle_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "cc44adadd9cc93d4a06fd9b1",
								"_tpl": "5b099bb25acfc400186331e8",
								"parentId": "86c755f233755987a7c9e08e",
								"slotId": "mod_reciever",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "f27397deeda98ceba571c783",
								"_tpl": "5b7be4575acfc400161d0832",
								"parentId": "1e84939d3c617732e95517be",
								"slotId": "mod_mount_001",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 8,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "a2177dbca83c1eca0be882ed",
								"_tpl": "5c1cd46f2e22164bef5cfedb",
								"parentId": "3d99f271f3637fb65014d95b",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "3d99f271f3637fb65014d95b",
								"_tpl": "5b7be46e5acfc400170e2dcf",
								"parentId": "1e84939d3c617732e95517be",
								"slotId": "mod_mount_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 6,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "a433ea0a16c0f7f996f1e50e",
								"_tpl": "5b7d37845acfc400170e2f87",
								"parentId": "86c755f233755987a7c9e08e",
								"slotId": "mod_magazine",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "db1d6cf49e973022b79ef237",
								"_tpl": "5b099bf25acfc4001637e683",
								"parentId": "86c755f233755987a7c9e08e",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "5b6e9ef196f62767c62c48d4",
								"_tpl": "58d2947e86f77447aa070d53",
								"parentId": "0cac2dd889e34f46bccad70c",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "37cf9e19ed04f32785e64492",
								"_tpl": "58d2912286f7744e27117493",
								"parentId": "5b6e9ef196f62767c62c48d4",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "0cac2dd889e34f46bccad70c",
								"_tpl": "5c793fb92e221644f31bfb64",
								"parentId": "db1d6cf49e973022b79ef237",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "00eb4b8817192d411b9b9bb0",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "a433ea0a16c0f7f996f1e50e",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 29
								}
							},
							{
								"_id": "7ff6d96b9019e7a213ca41ce",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "86c755f233755987a7c9e08e",
								"slotId": "patron_in_weapon",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "513134ef4a80321a48a9ff3f",
								"_tpl": "5fc3e272f8b6a877a729eac5",
								"parentId": "af06df24bdba4fffafc713b4",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 8,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "919a5003861c3333895d09f0",
								"_tpl": "5fc3e466187fea44d52eda90",
								"parentId": "513134ef4a80321a48a9ff3f",
								"slotId": "mod_magazine",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "ecf8fa76cc591130c9608fce",
								"_tpl": "5fc3e4ee7283c4046c5814af",
								"parentId": "513134ef4a80321a48a9ff3f",
								"slotId": "mod_stock",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "1944b2a3400c117e2f64e10d",
								"_tpl": "5fc3e4a27283c4046c5814ab",
								"parentId": "513134ef4a80321a48a9ff3f",
								"slotId": "mod_barrel",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "9ec803ce8802521c32ef4e71",
								"_tpl": "5fc53954f8b6a877a729eaeb",
								"parentId": "513134ef4a80321a48a9ff3f",
								"slotId": "mod_mount_000",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "5b4e2b44b001e838c2e87c45",
								"_tpl": "5fc5396e900b1d5091531e72",
								"parentId": "513134ef4a80321a48a9ff3f",
								"slotId": "mod_mount_001",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "58664a86f17750b9e1a907e3",
								"_tpl": "5fc5396e900b1d5091531e72",
								"parentId": "513134ef4a80321a48a9ff3f",
								"slotId": "mod_mount_002",
								"upd": {
									"Foldable": {
										"Folded": false
									},
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "b19333fc0405959b05d1ea5c",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "513134ef4a80321a48a9ff3f",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "ea510733b6e9310350910b40",
								"_tpl": "6130c4d51cb55961fa0fd49f",
								"parentId": "1944b2a3400c117e2f64e10d",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "eede16ed3bf87f7db13661b6",
								"_tpl": "5fc3e466187fea44d52eda90",
								"parentId": "af06df24bdba4fffafc713b4",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 8,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "99f5a50699b88fffff717687",
								"_tpl": "59fc48e086f77463b1118392",
								"parentId": "9ec803ce8802521c32ef4e71",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "11edf84e0ca64936c0a7db05",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "58664a86f17750b9e1a907e3",
								"slotId": "mod_tactical",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "8e96c506ca0e65758993143b",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "942b0f56f35810da8a7e9dd9",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "a07aea4b525330d56dcab71d",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "919a5003861c3333895d09f0",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "51ca478099c1e8f7a0badd63",
								"_tpl": "6176aca650224f204c1da3fb",
								"parentId": "e16dee62f9d7483fd0beb908",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "3692dc1b327926663454781a",
								"_tpl": "617153016c780c1e710c9a2f",
								"parentId": "51ca478099c1e8f7a0badd63",
								"slotId": "mod_stock",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "797d7226f87864904a169422",
								"_tpl": "61713a8fd92c473c770214a4",
								"parentId": "51ca478099c1e8f7a0badd63",
								"slotId": "mod_reciever",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "4cb3935362481bbb8e138b00",
								"_tpl": "61702d8a67085e45ef140b24",
								"parentId": "51ca478099c1e8f7a0badd63",
								"slotId": "mod_charge",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "e6c32b6dcd2b4a06fa652952",
								"_tpl": "617155ee50224f204c1da3cd",
								"parentId": "3692dc1b327926663454781a",
								"slotId": "mod_stock_000",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "39989044856e02adc050886e",
								"_tpl": "61702be9faa1272e431522c3",
								"parentId": "797d7226f87864904a169422",
								"slotId": "mod_barrel",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "670c31afb9b4f22848ba3d2f",
								"_tpl": "61703001d92c473c77021497",
								"parentId": "797d7226f87864904a169422",
								"slotId": "mod_handguard",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "9d28a1cd930b6d8adf9e7160",
								"_tpl": "61715e7e67085e45ef140b33",
								"parentId": "e6c32b6dcd2b4a06fa652952",
								"slotId": "mod_stock_000",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "1cf4c042a0784d1875972f6b",
								"_tpl": "61702f1b67085e45ef140b26",
								"parentId": "39989044856e02adc050886e",
								"slotId": "mod_gas_block",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 1,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "241d844efffc8afccf6d4a55",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "797d7226f87864904a169422",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "c8a28348d79ea684f3a4225d",
								"_tpl": "617131a4568c120fdd29482d",
								"parentId": "51ca478099c1e8f7a0badd63",
								"slotId": "mod_magazine",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 6,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "772b316aec43b9e228195fcb",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "670c31afb9b4f22848ba3d2f",
								"slotId": "mod_tactical_002",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "12f899ec5d05cf0bf0d5a84c",
								"_tpl": "5a7dbfc1159bd40016548fde",
								"parentId": "670c31afb9b4f22848ba3d2f",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "7d9d35a5bf9b25bd7f17ce14",
								"_tpl": "5dfa3d2b0dee1b22f862eade",
								"parentId": "fd33f8dd3723b4a8539aaf85",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 2,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "fd33f8dd3723b4a8539aaf85",
								"_tpl": "5dfa3cd1b33c0951220c079b",
								"parentId": "39989044856e02adc050886e",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "c9d758f02aceed4d62b96962",
								"_tpl": "5d025cc1d7ad1a53845279ef",
								"parentId": "51ca478099c1e8f7a0badd63",
								"slotId": "mod_pistol_grip",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "106790b5609041ef98fa580f",
								"_tpl": "58dd3ad986f77403051cba8f",
								"parentId": "c8a28348d79ea684f3a4225d",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "0be31ed826ad2f2bfcba189f",
								"_tpl": "5cc82d76e24e8d00134b4b83",
								"parentId": "af06df24bdba4fffafc713b4",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									},
									"FireMode": {
										"FireMode": "single"
									}
								}
							},
							{
								"_id": "003149cf9537de0a37b1c14c",
								"_tpl": "5cc70093e4a949033c734312",
								"parentId": "0be31ed826ad2f2bfcba189f",
								"slotId": "mod_magazine",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "3fb789d7d96c40de93179738",
								"_tpl": "5cc700b9e4a949000f0f0f25",
								"parentId": "0be31ed826ad2f2bfcba189f",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8248bb57735dc65270c907ca",
								"_tpl": "5cc701aae4a949000e1ea45c",
								"parentId": "0be31ed826ad2f2bfcba189f",
								"slotId": "mod_barrel",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "1ce38d3e171980cf9507893f",
								"_tpl": "5cc700cae4a949035e43ba72",
								"parentId": "3fb789d7d96c40de93179738",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "4e9c72b2efd65d3ba9cc53f6",
								"_tpl": "5cc82796e24e8d000f5859a8",
								"parentId": "8248bb57735dc65270c907ca",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "38578370e1499764cdf93dfb",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "d21c57fe03b66c4804602635",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "7c3163b853ce3566443f797f",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "bf4ff5349a5e938b65c538dd",
								"slotId": "mod_tactical",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "d21c57fe03b66c4804602635",
								"_tpl": "5cc700ede4a949033c734315",
								"parentId": "0be31ed826ad2f2bfcba189f",
								"slotId": "mod_reciever",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "bf4ff5349a5e938b65c538dd",
								"_tpl": "5cc7012ae4a949001252b43e",
								"parentId": "d21c57fe03b66c4804602635",
								"slotId": "mod_mount_001",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "ce60cdc1afbd345745fd25b2",
								"_tpl": "5cebec00d7f00c065c53522a",
								"parentId": "4e9c72b2efd65d3ba9cc53f6",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 66,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "b575e8ebda01199564b72997",
								"_tpl": "5cc6ea85e4a949000e1ea3c3",
								"parentId": "0be31ed826ad2f2bfcba189f",
								"slotId": "mod_charge",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "7e2a281d27d2398ff042dfd9",
								"_tpl": "5fb64bc92b1b027b1f50bcf2",
								"parentId": "af06df24bdba4fffafc713b4",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									},
									"FireMode": {
										"FireMode": "single"
									},
									"Foldable": {
										"Folded": false
									}
								}
							},
							{
								"_id": "d4b6b0aeca990084f87bc2a8",
								"_tpl": "5fb6567747ce63734e3fa1dc",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_sight_front",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "6bf4b42bb79d87d945eb2850",
								"_tpl": "5fb6564947ce63734e3fa1da",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_sight_rear",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "09043d358210a49b5c43e68d",
								"_tpl": "5fb65363d1409e5ca04b54f5",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_barrel",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "d59a9ce74b1f104f16cdbd48",
								"_tpl": "5fbb976df9986c4cff3fe5f2",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_mount",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "67640f774af35005959871f5",
								"_tpl": "5fce0f9b55375d18a253eff2",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_mount_001",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8a8c0f4bf2d8e723ce988a5a",
								"_tpl": "5fce0f9b55375d18a253eff2",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_mount_002",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "cfecdc3746b973df1771a002",
								"_tpl": "58491f3324597764bc48fa02",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "0cf32c79b348e009fd7d3f7a",
								"_tpl": "5fc4b9b17283c4046c5814d7",
								"parentId": "4c6e58850a3bd3e923f5acf8",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 73,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "4c6e58850a3bd3e923f5acf8",
								"_tpl": "5fc4b992187fea44d52edaa9",
								"parentId": "09043d358210a49b5c43e68d",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "0089fe03a9b07b568364b2db",
								"_tpl": "5d2369418abbc306c62e0c80",
								"parentId": "8a8c0f4bf2d8e723ce988a5a",
								"slotId": "mod_tactical",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "264f6d468fc88adf45b84916",
								"_tpl": "5b057b4f5acfc4771e1bd3e9",
								"parentId": "d59a9ce74b1f104f16cdbd48",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 3,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "942b0f56f35810da8a7e9dd9",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"parentId": "af06df24bdba4fffafc713b4",
								"slotId": "main",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 8,
									"BuyRestrictionCurrent": 0
								},
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "b3e481989e0f02fe388f0db3",
								"_tpl": "5fb655b748c711690e3a8d5a",
								"parentId": "7e2a281d27d2398ff042dfd9",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 7,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "3c798da24da24a4604bddb10",
								"_tpl": "58d2947e86f77447aa070d53",
								"parentId": "9b11b2ee10327c7181a4ac3c",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 4,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "6e57a4f1f982f5ded323ccc9",
								"_tpl": "58d2912286f7744e27117493",
								"parentId": "3c798da24da24a4604bddb10",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "9b11b2ee10327c7181a4ac3c",
								"_tpl": "5c793fb92e221644f31bfb64",
								"parentId": "b3e481989e0f02fe388f0db3",
								"slotId": "mod_stock_000",
								"upd": {
									"StackObjectsCount": 1,
									"BuyRestrictionMax": 5,
									"BuyRestrictionCurrent": 0
								}
							},
							{
								"_id": "c5b6d0b9042c106f2d0459fa",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d774e764a1961e590e5fed47",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ff9b101c98078bf266c018a5",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c3347c84bdc62a30b59e7c73",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "038902c3eb5fc1ac35188a15",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fb908f48923e5da819362b13",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b8a6f790ffa69e2a0a71cb28",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "178d256b09c2d73dccb4c6e2",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0405a4a69d1184de7c2ca9ed",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bfda5d29ae4c8c0a5500a06c",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8b8c224965fde64b3ddcd321",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "740cd23efcb3396dd942878a",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1b6f31895429e2cfc8bf77b8",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4c00a58840d6b3f2fcd4795b",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1df979d065ed9bb9d539346a",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d62f42a4d09de4ec9084feea",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a37490b34ee507e847579dca",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "980a2fec6de08edfa027eb5a",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "daa8b187b59abbbd2485d2e0",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5a85d921b6cc0fe390c8a15c",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b7b42528d1175607153ce25b",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2383348ab36f7cb7b5df8d23",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5f8a80f5e54be2c700e24273",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ab36bd9e029a9ed96540222b",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3671c839e90dba63a6e45f2d",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "054919f9a17903c10a6f842b",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ffb7de0b3161adb7081ecbe3",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "22e1006c6f119cb186b674a8",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f9083dfe9949aac35e0459ef",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0abbdf35544b18d8509c3be5",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b75aecb16220d519634d8f09",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6552eb3d0b306503cf3e486e",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "804f9f2258f3ab6b5889dbc9",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "02d5eaf052465eeeaf7019aa",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9ef5bf3f1e6a0b58df468221",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a16fb561d6279ad0bd016853",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0f0608a522ba737ee2313127",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a167b405fb0cbda850f0a394",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e630dff58ade09ee6287846e",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "15a247b55fe981c8c56ba2e4",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b2c57e40d81e54f469935da2",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c8eae24f73d34c2f086ae426",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "86fc6a6caf89e1e9a0c4f066",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4d5a4b3173de759d98c07aaf",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "200832956cc85c7c570f39b5",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ca1ff31c5726c97ec9049bf0",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0088c0bdef4535e7cc199e9e",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e49fad64d8c4080eb19a8d98",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9c8b62df18ebec51e5e257fe",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8c0b649a32be8632cf81f021",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e309868e479883b565b4dccd",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7855e5c8e0e5ed6b42f6ed0e",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "baa685903ca0e95a9868d623",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "06b25651eefa825dcdbe15fb",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "af84d103f6f79471e3d6634b",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1270e58b729d573ef41f2430",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bb363db77d34926599d768f0",
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "815b828953df9e1f13534040",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"parentId": "88fd974874140b1df3f51df1",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 400000
								}
							},
							{
								"_id": "30572f69372791fabb7746f2",
								"_tpl": "59136e1e86f774432f15d133",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "2c9bf00b11854cbc165b2264",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bf7a58b3046013dfbe718604",
								"_tpl": "5a0ea79b86f7741d4a35298e",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ab695e3f81f6e2d878dace29",
								"_tpl": "5a13ef0686f7746e5a411744",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cfc16fc9b0a03993183bf092",
								"_tpl": "5a0ec70e86f7742c0b518fba",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "767b92563790de6f28777cfd",
								"_tpl": "5a145d7b86f7744cbb6f4a13",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "a4842b5e3961422bd8acbd72",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4b8ea6571c775df38f56a43c",
								"_tpl": "5648a69d4bdc2ded0b8b457b",
								"slotId": "main",
								"location": {
									"x": 10,
									"y": 3,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "979e27b5aa3427cc8984d69a",
								"_tpl": "5b40e1525acfc4771e1c6611",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d63359b7f41577ead058f003",
								"_tpl": "5b40e1525acfc4771e1c6611",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "199a5f490feb3398be7c6fc4",
								"_tpl": "5f5e467b0bc58666c37e7821",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b37d2af121d07432c2d38106",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2fb10a1587cdcaeba6dd8e3f",
								"_tpl": "5ac66cb05acfc40198510a10",
								"slotId": "main",
								"parentId": "e16dee62f9d7483fd0beb908",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "c2d092a9f07d6393edc2f3cf",
								"_tpl": "5b4736a986f774040571e998",
								"slotId": "mod_mount_000",
								"parentId": "b7ca953e41fa8dff2e5d489f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "24828d515e2869c479b6cbfe",
								"_tpl": "5b4736b986f77405cb415c10",
								"slotId": "mod_mount_002",
								"parentId": "b7ca953e41fa8dff2e5d489f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "44b7c25105682af12a8828f2",
								"_tpl": "5e21ca18e4d47f0da15e77dd",
								"slotId": "mod_muzzle",
								"parentId": "2fb10a1587cdcaeba6dd8e3f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fc379dbdf3c7ee8a867bf87e",
								"_tpl": "5ac78eaf5acfc4001926317a",
								"slotId": "mod_stock",
								"parentId": "2fb10a1587cdcaeba6dd8e3f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0a32cf7b28e143772693cae5",
								"_tpl": "6130ca3fd92c473c77020dbd",
								"slotId": "mod_charge",
								"parentId": "2fb10a1587cdcaeba6dd8e3f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "df1fb050b9285817e9700f05",
								"_tpl": "5d2c76ed48f03532f2136169",
								"slotId": "mod_reciever",
								"parentId": "2fb10a1587cdcaeba6dd8e3f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "31ab861fd3c99085d43c0bb4",
								"_tpl": "6087e663132d4d12c81fd96b",
								"slotId": "mod_pistol_grip",
								"parentId": "2fb10a1587cdcaeba6dd8e3f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b7ca953e41fa8dff2e5d489f",
								"_tpl": "5b237e425acfc4771e1be0b6",
								"slotId": "mod_gas_block",
								"parentId": "2fb10a1587cdcaeba6dd8e3f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ee07e6de224ca8ae92b05c07",
								"_tpl": "59ecc3dd86f7746dc827481c",
								"slotId": "mod_stock",
								"parentId": "fc379dbdf3c7ee8a867bf87e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8b114af4218f7e7ff711e1c1",
								"_tpl": "5c1bc5af2e221602b412949b",
								"slotId": "mod_foregrip",
								"parentId": "24828d515e2869c479b6cbfe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "639a0a1f7eba26980187d335",
								"_tpl": "58491f3324597764bc48fa02",
								"slotId": "mod_scope",
								"parentId": "df1fb050b9285817e9700f05",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "315c40e0d8a94328b451064d",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "mod_magazine",
								"parentId": "2fb10a1587cdcaeba6dd8e3f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a15c2005d0962aa97331ebf4",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bea74dce35d55294d38c8b5c",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "924cc749a4bc2c62311ce7c8",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5d15ea62bf4819c05583611e",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f731ec19f1715095d8c0429c",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7c6bd2a68707c7fb51af6fc3",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b8a55a4aed9133f391b55741",
								"_tpl": "5ac66c5d5acfc4001718d314",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f315433b2fec7a0d148ada18",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7bd69dcb7fee4e07a22c1a3a",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "658901eddd7c8862913de043",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f1a6d9644920dcd2433892ae",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "7c6bd2a68707c7fb51af6fc3",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5aff16d149517ace61c7b6ce",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "924cc749a4bc2c62311ce7c8",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2b68cca398c198dcfc6bc5ac",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "b8a55a4aed9133f391b55741",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "804519bcbba1fd95de043c65",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "f731ec19f1715095d8c0429c",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4768c73c1fccf744698024ba",
								"_tpl": "54527ac44bdc2d36668b4567",
								"parentId": "5d15ea62bf4819c05583611e",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "cdb33bf5f661c4bee21a73b9",
								"_tpl": "54527ac44bdc2d36668b4567",
								"parentId": "a15c2005d0962aa97331ebf4",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "b70e8a0d3378b4f560c4d032",
								"_tpl": "54527ac44bdc2d36668b4567",
								"parentId": "bea74dce35d55294d38c8b5c",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "33b6f225b6924db61c9a76cd",
								"_tpl": "54527ac44bdc2d36668b4567",
								"parentId": "315c40e0d8a94328b451064d",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "5935ef4834f1abfb60a147ba",
								"_tpl": "5648a69d4bdc2ded0b8b457b",
								"slotId": "main",
								"location": {
									"x": 10,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "eedcfde2c39877b6ed6d17a1",
								"_tpl": "60926df0132d4d12c81fd9df",
								"slotId": "mod_muzzle",
								"parentId": "e57c6f5557c0aba6e87f0c27",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e57c6f5557c0aba6e87f0c27",
								"_tpl": "609269c3b0e443224b421cc1",
								"slotId": "mod_muzzle",
								"parentId": "44b7c25105682af12a8828f2",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7d9579fb592a8a0dbcddecd6",
								"_tpl": "5d2369418abbc306c62e0c80",
								"slotId": "mod_tactical",
								"parentId": "c2d092a9f07d6393edc2f3cf",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e715062470ff6c2cdd3c2abb",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "98e7b8f3c5e69dbde992010c",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c8c621bb87f9ca82d95ca399",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "24089a4110309c71bf1e0c7d",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2faffa8b0745f2f60f9b302e",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "09e8a523442b447c7e3fc5f6",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "66565279723c6ee13451b40f",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b8156dcda5653996e2f59662",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c34c2ef46ce52654d9ce4900",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ab5547a00a29770397dd3ab0",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8d56f5400232ca1d13a245dc",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d50556c8f279cae2e5a1964b",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "421e000b4425b497416fdbf0",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0ab55bc1b15564a64735f562",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d21de40d9c6c01ca5cac3c45",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c120cf481ccf17f25fafa9d5",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ba7f25fe5bde3755069c90d1",
								"_tpl": "54527ac44bdc2d36668b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b6127ff409f2745b51d13fcb",
								"_tpl": "606587252535c57a13424cfd",
								"slotId": "main",
								"parentId": "e16dee62f9d7483fd0beb908",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "8193f8b69a6db37a8684c91a",
								"_tpl": "5a329052c4a28200741e22d3",
								"slotId": "mod_handguard",
								"parentId": "cc2dd099d9dcf2759ef4ede0",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9e9c967d3269f395b967bf1d",
								"_tpl": "6065878ac9cf8012264142fd",
								"slotId": "mod_barrel",
								"parentId": "cc2dd099d9dcf2759ef4ede0",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "22346bdabb9eb637a5367ccc",
								"_tpl": "5b3b99475acfc432ff4dcbee",
								"slotId": "mod_scope",
								"parentId": "2b9227fd81c1d710fc3401e9",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2b9227fd81c1d710fc3401e9",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"slotId": "mod_scope",
								"parentId": "cc2dd099d9dcf2759ef4ede0",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5a6ae24f4d454eda80d6e881",
								"_tpl": "5d443f8fa4b93678dd4a01aa",
								"slotId": "mod_muzzle",
								"parentId": "9e9c967d3269f395b967bf1d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c6e226573acdb6cf5a2e64f2",
								"_tpl": "5d44064fa4b9361e4f6eb8b5",
								"slotId": "mod_muzzle",
								"parentId": "5a6ae24f4d454eda80d6e881",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "217ade4f2a521b4a7e71d4d5",
								"_tpl": "6065dc8a132d4d12c81fd8e3",
								"slotId": "mod_gas_block",
								"parentId": "9e9c967d3269f395b967bf1d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "69c4dd098c15bd5b133231ee",
								"_tpl": "5c0102aa0db834001b734ba1",
								"slotId": "mod_mount_004",
								"parentId": "8193f8b69a6db37a8684c91a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7c2b751fa9724e17c9112d70",
								"_tpl": "5c0102b20db834001d23eebc",
								"slotId": "mod_foregrip",
								"parentId": "8193f8b69a6db37a8684c91a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a70b6ed64a38c44ce25d58d3",
								"_tpl": "5d2369418abbc306c62e0c80",
								"slotId": "mod_tactical",
								"parentId": "69c4dd098c15bd5b133231ee",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ebca72b8470a93f1dd099bdc",
								"_tpl": "5c1cd46f2e22164bef5cfedb",
								"slotId": "mod_foregrip",
								"parentId": "7c2b751fa9724e17c9112d70",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cc2dd099d9dcf2759ef4ede0",
								"_tpl": "606587a88900dc2d9a55b659",
								"slotId": "mod_reciever",
								"parentId": "b6127ff409f2745b51d13fcb",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4a185d872503af49b47db236",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "a727810ff601d42329e67986",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c5018b6641f3e2373de419f4",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "mod_magazine",
								"parentId": "b6127ff409f2745b51d13fcb",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "63e27c35d118e07a6c943159",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7e1b64f562ba34cf4c2cd678",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d11e59c01cfccd0e33edb7b1",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "999b7d2c1af0fc38591750bc",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fa198b547ea80f19425e0879",
								"_tpl": "59db3a1d86f77429e05b4e92",
								"slotId": "mod_pistol_grip",
								"parentId": "b6127ff409f2745b51d13fcb",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0361b46f119f3452069282f4",
								"_tpl": "58d2912286f7744e27117493",
								"slotId": "mod_stock",
								"parentId": "1aa0472022c8c2a7c1e199d8",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1aa0472022c8c2a7c1e199d8",
								"_tpl": "58d2946386f774496974c37e",
								"slotId": "mod_stock_000",
								"parentId": "a357385164ec9936acbd3fba",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a357385164ec9936acbd3fba",
								"_tpl": "5c793fb92e221644f31bfb64",
								"slotId": "mod_stock_001",
								"parentId": "b6127ff409f2745b51d13fcb",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "72b90406723001830e229e66",
								"_tpl": "59fafc5086f7740dbe19f6c3",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5ec3300f1b3d2ca43b537fd8",
								"_tpl": "606587bd6d0bd7580617bacc",
								"slotId": "mod_charge",
								"parentId": "b6127ff409f2745b51d13fcb",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d1513c0e212da71586e507d9",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "046fdd724fe1cb8284cc8644",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "556f72f696d5ed6806b944bd",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d0ed52fe169f1287cb5b52f8",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "52b708b6732fc0bfef9e5555",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "88f81f5192e896620d6d2f91",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fc25c856f0d368055e3c6064",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "afe137f9463e4ff028c8cac6",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "dfac5096a7f1849857f3a42d",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4f4e0c35227efeaaf5d50943",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8c26dad3a000df3e8dcff6f0",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "a727810ff601d42329e67986",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "19f1b3dfcc17f072059cd8f2",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b495bbf25a0d34a2ec6999a6",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "10111f3849470d1b88968067",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "63e27c35d118e07a6c943159",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2d23848e4eb2e9c35f9baddf",
								"_tpl": "59e0d99486f7744a32234762",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "86daf5290051137306fefaac",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "c5018b6641f3e2373de419f4",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "f027ddcbd83b497108a8fdaf",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "4a185d872503af49b47db236",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "f39dd24b5e97c86272f6f94c",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "999b7d2c1af0fc38591750bc",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "975b10c24993371ae7daa952",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "d11e59c01cfccd0e33edb7b1",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "42f028a624ecf83e9f35e4d4",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "7e1b64f562ba34cf4c2cd678",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "a23f98242f7caad498f14c5a",
								"_tpl": "59e0d99486f7744a32234762",
								"parentId": "72b90406723001830e229e66",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "abb6ea654017be84c18ebac8",
								"_tpl": "5fd4c474dd870108a754b241",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "73e6df8bbbbe970390563bb5",
								"_tpl": "5fd4c474dd870108a754b241",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "320974503e8a1d947dcbdd18",
								"_tpl": "609e860ebd219504d8507525",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4b762646aa5025480bd9353b",
								"_tpl": "609e860ebd219504d8507525",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2022b1b806f0e68cf804f6f7",
								"_tpl": "5aa7e276e5b5b000171d0647",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4987fa84292dc62971a5445b",
								"_tpl": "5aa7e276e5b5b000171d0647",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a2d11d43de379f457c7cf59c",
								"_tpl": "5aa7e373e5b5b000137b76f0",
								"slotId": "mod_equipment",
								"parentId": "2022b1b806f0e68cf804f6f7",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ed48a8abffededf60b8c1a67",
								"_tpl": "5aa7e373e5b5b000137b76f0",
								"slotId": "mod_equipment",
								"parentId": "4987fa84292dc62971a5445b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a69722ce1c4448837d5b2076",
								"_tpl": "5f60c74e3b85f6263c145586",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cbf686bf7990374fffcb3f39",
								"_tpl": "5f60c74e3b85f6263c145586",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d73efc078172c47b50c023f3",
								"_tpl": "5f60c85b58eff926626a60f7",
								"slotId": "mod_equipment",
								"parentId": "a69722ce1c4448837d5b2076",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0443acbde13736d59819efb5",
								"_tpl": "5f60c85b58eff926626a60f7",
								"slotId": "mod_equipment",
								"parentId": "cbf686bf7990374fffcb3f39",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "238dbf58c8497405ab29711b",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "af06df24bdba4fffafc713b4",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9cd4d9b30dc0921d77d47405",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c8cd013deba68fb88a2390dd",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "019f8b97903e8aee71bd822a",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6364875b4c7280679f708a9a",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "da480a931afe703da3e823d1",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cbd932313570f400f7eb791d",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6e57505fcdd0771cc6e28692",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "88a752cd7113f30fb7c9111a",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4d464a8e0a1679159e6f201b",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "18c312f1aeac2eb06d56f1b9",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "894afae6188926dcaa4d2db0",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f1704875ba85fcb681f2422c",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2bd5d5d56e7f04b805755c99",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5ff2b6e0b6c748e1fa28e851",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8651732e0b3b14ef9a269f66",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ff6d3c1fe07039b04c79ff36",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0ccd2962f4f5a2d43dbff26a",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3e76aa33c73e0fadf48938a9",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "cbd932313570f400f7eb791d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6fd8050735941f0fbd0eeb71",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "238dbf58c8497405ab29711b",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e510ea7813559f24e52158e8",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "9cd4d9b30dc0921d77d47405",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d69c029f25fbe04c042c407f",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "019f8b97903e8aee71bd822a",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d8a6c67bdf987f44ff980e84",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "6364875b4c7280679f708a9a",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5073a60e1f35ad00322cc389",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "c8cd013deba68fb88a2390dd",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1c6e83e7643b3242b316a667",
								"_tpl": "5cc80f38e4a949001152b560",
								"parentId": "da480a931afe703da3e823d1",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 50
								}
							},
							{
								"_id": "b77b23bcb676e263ac0b826d",
								"_tpl": "606dae0ab0e443224b421bb7",
								"slotId": "main",
								"parentId": "af06df24bdba4fffafc713b4",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "51eac739b7bb9a0761a16607",
								"_tpl": "6076c1b9f2cb2e02a42acedc",
								"slotId": "mod_barrel",
								"parentId": "b77b23bcb676e263ac0b826d"
							},
							{
								"_id": "ef39c818d861eeff74c4bdb9",
								"_tpl": "606ee5c81246154cad35d65e",
								"slotId": "mod_handguard",
								"parentId": "b77b23bcb676e263ac0b826d"
							},
							{
								"_id": "fbdc868de51ddd52e9268ded",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "mod_magazine",
								"parentId": "b77b23bcb676e263ac0b826d"
							},
							{
								"_id": "2a0948354b0ef717b105fe4a",
								"_tpl": "606eef46232e5a31c233d500",
								"slotId": "mod_stock",
								"parentId": "b77b23bcb676e263ac0b826d"
							},
							{
								"_id": "c7f890a216d2db42f74137ee",
								"_tpl": "606eef756d0bd7580617baf8",
								"slotId": "mod_stock",
								"parentId": "2a0948354b0ef717b105fe4a"
							},
							{
								"_id": "edda2f650f3bb6dd4ca915bd",
								"_tpl": "606f2696f2cb2e02a42aceb1",
								"slotId": "mod_tactical",
								"parentId": "c7f890a216d2db42f74137ee"
							},
							{
								"_id": "eba82f802e527e6a4546e191",
								"_tpl": "60785ce5132d4d12c81fd918",
								"slotId": "mod_mount",
								"parentId": "b77b23bcb676e263ac0b826d"
							},
							{
								"_id": "c0d9a1db0a46ebdc104886c3",
								"_tpl": "607ea812232e5a31c233d53c",
								"slotId": "mod_mount_000",
								"parentId": "ef39c818d861eeff74c4bdb9",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2440bb1b8a50294055b1e885",
								"_tpl": "606f262c6d0bd7580617bafa",
								"slotId": "mod_stock",
								"parentId": "c7f890a216d2db42f74137ee",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2a13cae9ae4b58c827819eb2",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b2c66bb17434f3849eb0ba44",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c95baabc29638a3905340111",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "da085870e25c2eed3b5ee8b7",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7c4fbaf746a74ec7a262ad69",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "986950dada74db617353741c",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c0669dbbe4573d81b6c7ba6a",
								"_tpl": "6076c87f232e5a31c233d50e",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8e112f433f2f4f751acdbc37",
								"_tpl": "5c0111ab0db834001966914d",
								"slotId": "mod_muzzle",
								"parentId": "51eac739b7bb9a0761a16607",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "881d0a1f7492e3a24cc9a01a",
								"_tpl": "59c0ec5b86f77435b128bfca",
								"slotId": "mod_muzzle",
								"parentId": "8e112f433f2f4f751acdbc37",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0bd902e2218883ea02c876ba",
								"_tpl": "56def37dd2720bec348b456a",
								"slotId": "mod_tactical",
								"parentId": "c0d9a1db0a46ebdc104886c3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f4bd58874ab1432e62047b09",
								"_tpl": "570fd6c2d2720bc6458b457f",
								"slotId": "mod_scope",
								"parentId": "eba82f802e527e6a4546e191",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "545be962b40f22aaa7de841b",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "da085870e25c2eed3b5ee8b7",
								"upd": {
									"StackObjectsCount": 6,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "360bbc34bea571aa97562864",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "983322bf998cee4ec7ecbe37",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5190aa036de6e96d15453558",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1e928ba5a038b34461d15396",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "82b1bb5725e37eceafaea97f",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0e3971e1fd057bc898c25d9f",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "42f10dc844dac12bab3c8ddb",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b9bae35b7e9aa5daa576ff61",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "02e7acf6a3cdbf2712e7c076",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ac6961f079a7730d098c63ed",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "590c6a289fe29ecbb27fceb2",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5defad7b2a1c4f306d002eb7",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "93473068bbd1450d6ee2edf2",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4485ff4c70db316c70dd7ec1",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "79b1e571b7974d3230854f2b",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b3fd54e305f510d57423056c",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c1c4ff2b4e2cd6e3066fa4d0",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "986950dada74db617353741c",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "b6b63d78c60ffd3689f2aa6f",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "b77b23bcb676e263ac0b826d",
								"slotId": "patron_in_weapon",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "a5c993df209147dbdc6f3528",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "fbdc868de51ddd52e9268ded",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "3254a555f8194f731c9f5217",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "2a13cae9ae4b58c827819eb2",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "5995b193ce112162c7778edc",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "b2c66bb17434f3849eb0ba44",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "e94ebc56f3118b4d973561cd",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "c95baabc29638a3905340111",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "ed8ab80edf4491f2536760d7",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "7c4fbaf746a74ec7a262ad69",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "a7e5d27c62f20da8ebd597be",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "c0669dbbe4573d81b6c7ba6a",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 6
								}
							},
							{
								"_id": "e60b2938cfcc056196206150",
								"_tpl": "5cc70093e4a949033c734312",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "b330c2a8b154d6401ab7afa1",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7bc5c92a35bbc555f70e1b49",
								"_tpl": "5cc80f38e4a949001152b560",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "e60b2938cfcc056196206150",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2e5611a229adc44c10a326d9",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1bc82cfb7107900e3d573e0e",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "eb00e37ac516297cc083871b",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f3bee7b05d0c7961b808ccb7",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8fa25a8cf6c3537513590f80",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ac0e34878e7213e44ccaf001",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "89e22919f636c310f9b467a1",
								"_tpl": "5fc3e466187fea44d52eda90",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a428a6a6ee2fb438be63649f",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "1bc82cfb7107900e3d573e0e",
								"upd": {
									"StackObjectsCount": 25,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7275660d302a197f125a1c05",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "89e22919f636c310f9b467a1",
								"upd": {
									"StackObjectsCount": 25,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c1a4d471b4de32059c099779",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "8fa25a8cf6c3537513590f80",
								"upd": {
									"StackObjectsCount": 25,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d686cfa21fd3e9feca6c2f8b",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "4b647c6b1decc2247c88b9fc",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c35c46633437c683fab2b230",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "d55fc010431d4e6529238c16",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bcbf5f551d232e4304660533",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "13171ff4cca4806636e1dfea",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3e3b409212bfdf739854dc02",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "d4fa4140bed049693b456f23",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8db003f6852f7f899b5b8dc7",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 10,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6313ff40332c362f18dfb101",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "638e60fc5e9f975d1197e0d9",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "332249091424d2ca789ed6c0",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2c5ffc291077d5ec5d6501e3",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "080217ee209d2bfd8c178b07",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9f2cf37e5b2c3533a252cc69",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "438ce9a4a78622a6ff578b02",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "35f85c9235057906e5012296",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6980154b18c720f34f504f4c",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c67f169a4ba235c30b5a4c29",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d059c5e8453b20c3bab6db4b",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bf5aa7c59981291d19b385a4",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "1cb12514507b72446601028d",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d55fc010431d4e6529238c16",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "148d8d96de541ff985014dae",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4b647c6b1decc2247c88b9fc",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "688bee3bb8da8994c48a79a3",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e79e8f8413dcc4f34775d9b6",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d4fa4140bed049693b456f23",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "13171ff4cca4806636e1dfea",
								"_tpl": "5fb651dc85f90547f674b6f4",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "30305c344a2eaaf517de854a",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bcab2d1dd76c8ce11b56d8f9",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a0242724c267510ad050bf51",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1e96865fdf238afcd2e4217d",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "81b3b85f464fad6d9c2644d5",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0a26d538d16e627e00b3dbfa",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fef1394ba4eb9e18e5a77953",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "dcd07cec62b5042e2d16c0ad",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cff8b27fd87d3dd28f791340",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fdd7ed486e23cb7bcb48715d",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5462118c48617cee835068e2",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "afc97c968d08a46d09d5bec1",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e0f560f918464ce6db6bcc26",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8fac788111ed0d2ec955c29f",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fc8a16ec4df66790af0bb271",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0cd10b9cf2b828786e96a8d7",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "12cf937e18df197284756541",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "eb70abb56ed926a1e13ce932",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f85b2eb6a4a2cafceb5bd10a",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "82e3c950717d581fb15fb0dc",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e1ea72658080c0058439e99e",
								"_tpl": "5cadf6eeae921500134b2799",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "82b6f2edbcc846f8fc77108d",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "43ae5902d72269d0ee4a4ba8",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "85652ddf9afe39e90629aff8",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0adc1083d2f1dd1579ec4083",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "18851e716462c9428e73f475",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f8eb95a6400ddf135434a5d2",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bc679a844f3447e7992733e3",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c73f91c521cacc72471585b4",
								"_tpl": "5b7d37845acfc400170e2f87",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f752389faacf90a60721bff8",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 10,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "749e3ee1639f17330afebd8b",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f15922ad033c3d99c8253811",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bb6c8bc08f889f855943b4dd",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a15a2bc3f592f07835cb4762",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b1cd212d4e47841c01d6fbf9",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9a15d7554d11b36297d21c34",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b905aef18911e21c20655592",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a746bbadd63f29cafb70e25c",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "36c747f54869fda8e871eabf",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b6409bd8701b6d6db75378ac",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "101ecc90889a1c0ffe913b92",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "70f6f7cf2ee6ee22014507b8",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f9254f3fb49554dc035e85a5",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6db9fda272bfee2862e9256c",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "40c841ccbda2e42347259021",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6d86db677e0246d65953f487",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "38914e925722c0bd710283ba",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "358e65bfb1b2f23fb94b250e",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "43ae5902d72269d0ee4a4ba8",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "154439772bb8ff764408533e",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "85652ddf9afe39e90629aff8",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "17496d77d16cae74d852b8ee",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "0adc1083d2f1dd1579ec4083",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f6fc684321bbefec6ab54aae",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "bc679a844f3447e7992733e3",
								"upd": {
									"StackObjectsCount": 30,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2fcd6447d3be57a752abc45e",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "4ae6ae45258e08ef2756d9b2",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "dd675f1f6e0f74f2157c6d36",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "d8e1940caaa2c0431882f24a",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1bff3862696b4f91299a09b7",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "247cf536626d007ed49979f5",
								"upd": {
									"StackObjectsCount": 20,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "924831e37b3fd028e23f8143",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "247cf536626d007ed49979f5",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b357ef6757675abac92fb5cf",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d8e1940caaa2c0431882f24a",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b5d1b9db74edbfc833751fff",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4ae6ae45258e08ef2756d9b2",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d63b140026f7f88bff54dce8",
								"_tpl": "617131a4568c120fdd29482d",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b7af0761d04c91ff0bccea8d",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3ac72ce9a85245d09b9a333c",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "2e5611a229adc44c10a326d9",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "4034001036bc5bb158eb3eb4",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "eb00e37ac516297cc083871b",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "67836819865cdbafcf0983a1",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "ac0e34878e7213e44ccaf001",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "bcd7a6699ebebabee9f1c233",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "f3bee7b05d0c7961b808ccb7",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "269438aef5d6dd4ef5ea90cd",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "924831e37b3fd028e23f8143",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "b7e7a047c604e758771afcd8",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "b357ef6757675abac92fb5cf",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "030cd1513a2ebcc94a4ca6c5",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "b5d1b9db74edbfc833751fff",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "7833e5e0fa0e11c23bafb4c0",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "d63b140026f7f88bff54dce8",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 20
								}
							},
							{
								"_id": "dbf05c9fa9c42c001ab74687",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "f8eb95a6400ddf135434a5d2",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "3ca0816e4925474637f8801d",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "18851e716462c9428e73f475",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "71871eda23ad74978596595b",
								"_tpl": "5efb0c1bd79ff02a1f5e68d9",
								"parentId": "c73f91c521cacc72471585b4",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "2df0a3806b13430cdfd791d0",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "148d8d96de541ff985014dae",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "a044222e8c46c4585513b63a",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "688bee3bb8da8994c48a79a3",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "f2a749160bdcb343af88120a",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "e79e8f8413dcc4f34775d9b6",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 30
								}
							},
							{
								"_id": "a3daa17039c4158e1f57bb31",
								"_tpl": "5d02797c86f774203f38e30a",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "27e840cbb7f1349ac2644f75",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5387ef1d1260cbfafd28570f",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3d1320c44793fe2a1e7b0c44",
								"_tpl": "5e32f56fcb6d5863cc5e5ee4",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "56fa2c1b41ed71145f014cce",
								"_tpl": "5e340dcdcb6d5863cc5e5efb",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b89d668500b5a243723b6405",
								"_tpl": "58d3db5386f77426186285a0",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4d424bda397716a4b58d2fc3",
								"_tpl": "5710c24ad2720bc3458b45a3",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d21aba2e33b6ebd0bca2db76",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "e72c6690206147077755c39c",
								"_tpl": "544fb45d4bdc2dee738b4568",
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Vertical",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"MedKit": {
										"HpResource": 400
									}
								}
							},
							{
								"_id": "938f8b1c2a43a04233b215c9",
								"_tpl": "5447a9cd4bdc2dbd208b4567",
								"slotId": "main",
								"parentId": "e16dee62f9d7483fd0beb908",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 0,
									"y": 8,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "c53916f0f482569d4b365ddd",
								"_tpl": "5b7be4895acfc400170e2dd5",
								"slotId": "mod_foregrip",
								"parentId": "cb3e7825f6b022de9e2ecb91",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0c60d3095682ff2d8d609012",
								"_tpl": "5b2240bf5acfc40dc528af69",
								"slotId": "mod_charge",
								"parentId": "938f8b1c2a43a04233b215c9",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "990c598777889fd4a8953a6d",
								"_tpl": "5d00ec68d7ad1a04a067e5be",
								"slotId": "mod_gas_block",
								"parentId": "e221479cfffda89c87354da3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "97c078f7ba435233c6f1d65e",
								"_tpl": "609269c3b0e443224b421cc1",
								"slotId": "mod_muzzle",
								"parentId": "e221479cfffda89c87354da3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3b08c3d23cbfbc0cd35e7367",
								"_tpl": "5c793fb92e221644f31bfb64",
								"slotId": "mod_stock",
								"parentId": "938f8b1c2a43a04233b215c9",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "483a8a2de05f1f675d08b107",
								"_tpl": "56def37dd2720bec348b456a",
								"slotId": "mod_tactical_003",
								"parentId": "cb3e7825f6b022de9e2ecb91",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "02d2064152f3f86728122146",
								"_tpl": "59db3a1d86f77429e05b4e92",
								"slotId": "mod_pistol_grip",
								"parentId": "938f8b1c2a43a04233b215c9",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e221479cfffda89c87354da3",
								"_tpl": "55d3632e4bdc2d972f8b4569",
								"slotId": "mod_barrel",
								"parentId": "23c8286bc2f3d1c373139a11",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "23c8286bc2f3d1c373139a11",
								"_tpl": "59bfe68886f7746004266202",
								"slotId": "mod_reciever",
								"parentId": "938f8b1c2a43a04233b215c9",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cb3e7825f6b022de9e2ecb91",
								"_tpl": "5c78f2492e221600114c9f04",
								"slotId": "mod_handguard",
								"parentId": "23c8286bc2f3d1c373139a11",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8ddcb806521e32b69cd2773a",
								"_tpl": "618ba27d9008e4636a67f61d",
								"slotId": "mod_scope",
								"parentId": "17da4ca1fd305e4d3c357175",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "17da4ca1fd305e4d3c357175",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"slotId": "mod_scope",
								"parentId": "23c8286bc2f3d1c373139a11",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "04643e541d0242a3ebb69be9",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f77ce22cb29ed8cd303d847a",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ff524531dbef35b2de9193b3",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8985df52fabb29070578396b",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c9997263f091c501684b859f",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "83db092d30a7dafb0dafca86",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "433b306f437213117aa04d29",
								"_tpl": "5e8488fa988a8701445df1e4",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9acdb89f3668c143ddb78882",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "35e9656df950795271fdbb53",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b4efa99f16deadcca2709e38",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "18ad7d3b384e407b6b919935",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7d7b44e153c03b6201a7edb1",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1f0f915fa6487d8c1cf0f55c",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a6f8bd64824dc802b34f873b",
								"_tpl": "544fb3f34bdc2d03748b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e0ac6081276308cb3325765f",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4adb802ab3607be1093be95a",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "407e9ee5177bb61f3a03b0bf",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8e8ec24d8ae3df031d0ffad4",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4f1aa59002b9203fc8e9d7a0",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "37cdfb46cb92d373754c8711",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9afd70f095f626ea97856e57",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4c2136fe652cffd4b86464f8",
								"_tpl": "5448be9a4bdc2dfd2f8b456a",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cf70e23b122d7f020293a126",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "06a3e730203b0d5b19513b12",
								"_tpl": "58d2947e86f77447aa070d53",
								"slotId": "mod_stock_000",
								"parentId": "3b08c3d23cbfbc0cd35e7367",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "13bee01cfc5cdb4b9794bd7e",
								"_tpl": "58d2912286f7744e27117493",
								"slotId": "mod_stock",
								"parentId": "06a3e730203b0d5b19513b12",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0e7f2048aa3b0eea8892bff6",
								"_tpl": "60926df0132d4d12c81fd9df",
								"slotId": "mod_muzzle",
								"parentId": "97c078f7ba435233c6f1d65e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "60a86f8b2602bbf5d2709e4f",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "779e12368f757878f62b37b4",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4304ed4b1982d43afbf5899f",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b8d7c20a7b10c18ea3257dbb",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b3817180d0976803c2a0d4c2",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b47f2fa450897da6950fbdb5",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "10b204ea1a8083c5bbea50ef",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "110d4eab955ceb83d0b2fd54",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "be477ba8bde1ffb1224a774d",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "20614bec3a1e254021ede07a",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2aab10be26d4d640c9df6b17",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fc97b37cd962f0402664fb0a",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "56bb67d313499b1ac467898a",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5b58538c86734e4561b77079",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3ed781ed64dd3f94e11b7d8b",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5b533b50bfc272ee58a937a4",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7d89122c5b49736ad0668775",
								"_tpl": "544a37c44bdc2d25388b4567",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Vertical",
									"isSearched": true
								},
								"parentId": "d82ef485d9095b4208e1147e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "35d2b03ec966a8f9bb46016c",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ff2ddd872cf8abae66aadf9f",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f33f0334df47120884b210da",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "60a86f8b2602bbf5d2709e4f",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ef829d43994f001e3afc329a",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "779e12368f757878f62b37b4",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "15093b4b53ebd288593aa6d9",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "4304ed4b1982d43afbf5899f",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e987d91dbace279ac4a4e26e",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "b8d7c20a7b10c18ea3257dbb",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e8779eb6789fffd3ee7b5c50",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "b3817180d0976803c2a0d4c2",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "921b4d48034ac51beb2a71f5",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "b47f2fa450897da6950fbdb5",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b99e8e72f1c4f48f0c9a40da",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "10b204ea1a8083c5bbea50ef",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f5738567a1198b86d3152da9",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bea0a72819a506961a2ea7b9",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bc1c0c25ab0e2805fb5e991a",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "deca2f2adc0139071415d1b7",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ca67cd2df696919cab612f49",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "28e6588a34931ba5731cfb1a",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1d62ea3543231dce414fb30e",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5605ae0c86ac9652762985ed",
								"_tpl": "59e690b686f7746c9f75e848",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cae20ed3fe7cb0aa69ca1ea7",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "be477ba8bde1ffb1224a774d",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "38460229220f39f448e2e564",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "20614bec3a1e254021ede07a",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "49f9ce20c3aca6017c9839ae",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "2aab10be26d4d640c9df6b17",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5ea5f755a600795d28e96e20",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "fc97b37cd962f0402664fb0a",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f6b7681b474f7c060c194ef4",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "56bb67d313499b1ac467898a",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "67f1ed35726738bc01ecbfa8",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "5b58538c86734e4561b77079",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b1854cd4555381dd51d5e944",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "3ed781ed64dd3f94e11b7d8b",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ce17b8a1f3a9fbfa18120f8f",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c4793f3210a32080ced0d345",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b27c3f17dd9864bba5d92374",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "871867f871da672253552afa",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "90bedd147f08bf58de83624a",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e9350b07a5e04b16a5beeab6",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c3dea30c199e8dc2f77b3771",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8bd92a455f3230c47d99cdd7",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1d34365fdfa097845114d598",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7b7ce58c916ba12363798149",
								"_tpl": "59e6906286f7746c9f75e847",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "08616521e6794e5f812fe4b1",
								"upd": {
									"StackObjectsCount": 40,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3f9b226517c5afab87de81ba",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d940d16d1cb9bfcf889e53df",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e0a80487a988e17fbf6c71b0",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a9c2ff72fcd5a8476b07b6a5",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "48ba5060958568ac772ccde3",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "12b3a5d2e390aa91ab1e3205",
								"_tpl": "5755383e24597772cb798966",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "144ca1d2c772b191aa73dc55",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a2be82383b43fac949d9777f",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4b1a67ca2246ef6dc3be2166",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8c611eb2cc3f4b5aa0cef88e",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fb488c81a8f9535691bedaf5",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "916ef9b67b0a62906774e73d",
								"_tpl": "5af0454c86f7746bf20992e8",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0efae8fdf2ffa79237c7332a",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "448c4abff203106d4cba7f40",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9cabec84becb71b0babbef79",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "45daafb738379d46de228e86",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c81f86f5d9a3bda9f3ec5c48",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b2110fa2325b44b96c5402b5",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "292dc8a697a0db6f0457753f",
								"_tpl": "5c0e530286f7747fa1419862",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c008755e774ef99037b29758",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b9d1831be4a2aa948517744d",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bd97f8b0c608da7fd3cff726",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "23348efcf2a5e9b192e0ad10",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ea920f2f2f1bb6c5112c1290",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4a51a05e834bbc84030d6ef4",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f83083c9986bf88389aaaed3",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fa52ad299b75fb4d04a00d6a",
								"_tpl": "5c0e534186f7747fa1419867",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0343c45cd7ad3599cd1c6d31",
								"_tpl": "5efb0fc6aeb21837e749c801",
								"parentId": "eede16ed3bf87f7db13661b6",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 25
								}
							},
							{
								"_id": "49c3966cb1992c65475bf027",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "204cb82ea69b0e1895f97c37",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b9ad34cf99a53281d5a11b27",
								"_tpl": "5c0e533786f7747fa23f4d47",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3f8c6314a3b53d19dd561944",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4e4f8c80bea5b26d07ade25a",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bf56ba1687fadbf7df0699af",
								"_tpl": "5ed51652f6c34d2cc26336a1",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "866565f1635d3afdefbe487b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3d35c17d38629ba30e7cb19e",
								"_tpl": "628a60ae6b1d481ff772e9c8",
								"slotId": "main",
								"parentId": "e16dee62f9d7483fd0beb908",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								},
								"location": {
									"x": 1,
									"y": 10,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "9e1baaed659df2e3fe88eeda",
								"_tpl": "628a83c29179c324ed269508",
								"slotId": "mod_gas_block",
								"parentId": "3d35c17d38629ba30e7cb19e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9ec2a211faa8bee8c5925271",
								"_tpl": "6130c43c67085e45ef1405a1",
								"slotId": "mod_muzzle",
								"parentId": "3d35c17d38629ba30e7cb19e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2b17540a2fbf0e1fb10d2799",
								"_tpl": "5dfa3d2b0dee1b22f862eade",
								"slotId": "mod_muzzle",
								"parentId": "9ec2a211faa8bee8c5925271",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ddf7bc0cee5bdda793bf287a",
								"_tpl": "56def37dd2720bec348b456a",
								"slotId": "mod_tactical",
								"parentId": "dcf7b5226e44c659ab377f4b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "dcf7b5226e44c659ab377f4b",
								"_tpl": "5b7be47f5acfc400170e2dd2",
								"slotId": "mod_mount_001",
								"parentId": "9e1baaed659df2e3fe88eeda",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c60610c7288d7789610694d7",
								"_tpl": "5b7be4895acfc400170e2dd5",
								"slotId": "mod_foregrip",
								"parentId": "9e1baaed659df2e3fe88eeda",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "77e10f999fda57be9dc096d8",
								"_tpl": "5b057b4f5acfc4771e1bd3e9",
								"slotId": "mod_foregrip",
								"parentId": "c60610c7288d7789610694d7",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ccb88c0166ae5d49dad0416f",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e95f848c539349d25fcb7ebf",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "97cb2e2dc28627186e38399f",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6fe96859c4d3372a6c04a985",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6f8efd9e340ad2d0585cdc1d",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a1efaf637cd1af1f6dcb3535",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0cb2e71285024b535a15bbc6",
								"_tpl": "59fafc9386f774067d462453",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7bb86b8491e87cc68cf1d7aa",
								"_tpl": "628c9ab845c59e5b80768a81",
								"slotId": "mod_pistol_grip",
								"parentId": "3d35c17d38629ba30e7cb19e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "8ac5f282e1fea314f2b437c3",
								"_tpl": "5b0e794b5acfc47a877359b2",
								"slotId": "mod_stock_000",
								"parentId": "3d35c17d38629ba30e7cb19e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fb8c15ac30d420e995460f8f",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"slotId": "mod_scope",
								"parentId": "6bc6aeb0db4dd49932a876d3",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "4e439a81dc94f7cae23c413c",
								"_tpl": "618ba27d9008e4636a67f61d",
								"slotId": "mod_scope",
								"parentId": "fb8c15ac30d420e995460f8f",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "6bc6aeb0db4dd49932a876d3",
								"_tpl": "5d2c772c48f0355d95672c25",
								"slotId": "mod_reciever",
								"parentId": "3d35c17d38629ba30e7cb19e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "da5b2ffcc0de3adb88c38a75",
								"_tpl": "6130ca3fd92c473c77020dbd",
								"slotId": "mod_charge",
								"parentId": "3d35c17d38629ba30e7cb19e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "edbd3a7a9fff0d5bdd4e064f",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0e92fe90d08ce1b1a24515c1",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "eff3c273ef4840c6a14a2762",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "35878840f4b5a3324f42e2a6",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "260d2e6c2fac010497826905",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a6733322424a407547f32482",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9a471abbfe2ffba410c42bae",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "f5b916fc823e3f79bf4d82fc",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "49e71c1a6b39b0881f294c0a",
								"_tpl": "5cfe8010d7ad1a59283b14c6",
								"slotId": "mod_magazine",
								"parentId": "3d35c17d38629ba30e7cb19e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1daf0c2f10bc615192d36c8d",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "9a471abbfe2ffba410c42bae",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "1961401d2cc1166ad867a33f",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "a6733322424a407547f32482",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "267188848a24f7bbb8d615a7",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "260d2e6c2fac010497826905",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bc3b874fcf7e32956573c2b5",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "35878840f4b5a3324f42e2a6",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2a6412f405a342f4e7b20a2c",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "eff3c273ef4840c6a14a2762",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "37a0f2d9a20aeb94723dd329",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "a8abfa83c140a376e401c37f",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d1c82620676668f818e379c1",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3625c95c896e2632eb425143",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "d0a6bead7bc72d1d58421c84",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7452ae54ef52bb842d594419",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7f8ef0e0f3b60805297276ae",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "ea8941d7a00bdceff34fa429",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "fafd0a6fbf40babf9f493c34",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "341e4d31559a4227a389683b",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "8f1d8e5f96d933f306a79b5e",
								"upd": {
									"StackObjectsCount": 60,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b066c855180d3e2090b2f62a",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "edbd3a7a9fff0d5bdd4e064f",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c9df86189198d30bc3a08ae1",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"slotId": "cartridges",
								"location": 0,
								"parentId": "0e92fe90d08ce1b1a24515c1",
								"upd": {
									"StackObjectsCount": 50,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "7a2df51f950220de8467ccb8",
								"_tpl": "601aa3d2b2bcb34913271e6d",
								"parentId": "49e71c1a6b39b0881f294c0a",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 50
								}
							},
							{
								"_id": "997089bd97448535cefef632",
								"_tpl": "5a154d5cfcdbcb001a3b00da",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0c3d3c1c0079b609c9311fe2",
								"_tpl": "5a16b7e1fcdbcb00165aa6c9",
								"slotId": "mod_equipment_000",
								"parentId": "997089bd97448535cefef632",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "b6d210314851d4876094b088",
								"_tpl": "5a16b7e1fcdbcb00165aa6c9",
								"slotId": "mod_equipment_000",
								"parentId": "9c398a22cefd2103a9cbff5b",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9c398a22cefd2103a9cbff5b",
								"_tpl": "5a154d5cfcdbcb001a3b00da",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "51a1ca6a946c86938574382a",
								"_tpl": "5c0e655586f774045612eeb2",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bf47027ec9f4fade27c39cea",
								"_tpl": "5c0e655586f774045612eeb2",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c7e120f64e5748b5f10fd41b",
								"_tpl": "5e4ac41886f77406a511c9a8",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "9f180942e6ea3ce882cd2d2c",
								"_tpl": "5e4ac41886f77406a511c9a8",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 9,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e8f38ac80be50ecc9718981f",
								"_tpl": "5c0e746986f7741453628fe5",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "e30df73c4e9d188fec204256",
								"_tpl": "5c0e746986f7741453628fe5",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "600951b8f6a2da6ae32c4424",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0209a8b9ebec3c27d64b3b77",
								"_tpl": "5aa2ba71e5b5b000137b758f",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "292420adff9ce66f7033f7ef",
								"_tpl": "5aa2ba71e5b5b000137b758f",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "bbc30f508bed374aa0fe4d9e",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "cee7dfc929753c6245471c71",
								"_tpl": "545cdae64bdc2d39198b4568",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b37d2af121d07432c2d38106",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c03f5702053c3eaa99bc2756",
								"_tpl": "545cdae64bdc2d39198b4568",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "cee7dfc929753c6245471c71",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "377fabcb04ddd4a035a5bcce",
								"_tpl": "5df8a4d786f77412672a1e3b",
								"slotId": "main",
								"location": {
									"x": 8,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "b37d2af121d07432c2d38106",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3d92d511255b7631dbac55b7",
								"_tpl": "5df8a4d786f77412672a1e3b",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "377fabcb04ddd4a035a5bcce",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "0397feab6408d8a36caad322",
								"_tpl": "5c093e3486f77430cb02e593",
								"slotId": "8",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "9ebe7b2d496ce22c63be8525",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "f1ba1460534dbc420ebaf47e",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "3d3af1571375b4c0abfe771a",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "5b95b08361ea8c67624d9f1f",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "02ac0d5a05051e6b0e736fbe",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "c03f6f9e178409e75986ff65",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "25870226a23fb4b81ce0d797",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "bf8189367ae2bba041f98ed3",
								"_tpl": "5d02778e86f774203e7dedbe",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"parentId": "d58bf4cc06ff1c1e56c804fe",
								"upd": {
									"StackObjectsCount": 1,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "2a259ff819ce93daea987a9a",
								"_tpl": "5d1b36a186f7742523398433",
								"parentId": "294e09e971ddf3e4e255218e",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "48a202ac7a1ae4d16456320d",
								"_tpl": "5d1b36a186f7742523398433",
								"parentId": "294e09e971ddf3e4e255218e",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "63c2814159d4513432317ac8",
								"_tpl": "5d1b36a186f7742523398433",
								"parentId": "294e09e971ddf3e4e255218e",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "6d7e79ba3d733254c03ee4a1",
								"_tpl": "5d1b36a186f7742523398433",
								"parentId": "294e09e971ddf3e4e255218e",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "bf732905f7a5b01e203f883e",
								"_tpl": "63a399193901f439517cafb6",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "bd2299692d89e70ec36bfb92",
								"_tpl": "63a397d3af870e651d58e65b",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "b5321a2fe3da61821ff2246c",
								"_tpl": "63a39f6e64283b5e9c56b289",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "28f15a571836bbaad185aa3d",
								"_tpl": "63a3a93f8a56922e82001f5d",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "2eef19f536d6bc6786a2fdcb",
								"_tpl": "63a39c7964283b5e9c56b280",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "5df63763beae15220cfd7487",
								"_tpl": "63a39f18c2d53c2c6839c1d3",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "b118a87b34c6702e17a656fd",
								"_tpl": "63a39f08cd6db0635c197600",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "44c350cd6e31ba6f3f00a205",
								"_tpl": "63a39fc0af870e651d58e6ae",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "aeb1bba8cb369c29b0978bb6",
								"_tpl": "63a39e1d234195315d4020bd",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "5173ce0ad9da0c2fb6b63c55",
								"_tpl": "6398fd8ad3de3849057f5128",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 1,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "269e2c7dfe7b4900a913eef7",
								"_tpl": "63a71ed21031ac76fe773c7f",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "b59f1b64f5e90bd4b9b89fef",
								"_tpl": "63a39c69af870e651d58e6aa",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "90c5728a75e8ac835413cf86",
								"_tpl": "63a39fdf1e21260da44a0256",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "ae9ea822c5df275bcaafbb10",
								"_tpl": "63a39cb1c9b3aa4b61683ee2",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "ed7ef975ea23817d282a6b71",
								"_tpl": "63a39667c9b3aa4b61683e98",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 2,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "3905c12101ee344a3a5f860b",
								"_tpl": "63a39ce4cd6db0635c1975fa",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "e5bec7018c7c0059afa1832e",
								"_tpl": "63a39e49cd6db0635c1975fc",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "78bf70cb58485291b16683ae",
								"_tpl": "63a39fd1c9b3aa4b61683efb",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "fa8b74099388c071f24cabcb",
								"_tpl": "63a71e781031ac76fe773c7d",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "9579b43eb6731bf2240f761a",
								"_tpl": "63a71e922b25f7513905ca20",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "5e0c844c572ba08441d62b02",
								"_tpl": "63a71e86b7f4570d3a293169",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "97d073235e2ae143fbf29ae1",
								"_tpl": "63a71eb5b7f4570d3a29316b",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "029dadf5af46b49ab6ed265c",
								"_tpl": "63a39df18a56922e82001f25",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "7687fbcae2127855452a328a",
								"_tpl": "63a39dfe3901f439517cafba",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Key": {
										"NumberOfUsages": 0
									}
								}
							},
							{
								"_id": "9a045c757b47fdcfc3bae6be",
								"_tpl": "64381b6e44b37a080d0245b9"
							},
							{
								"_id": "4def02c5f448ae5b3841c051",
								"_tpl": "64381b6e44b37a080d0245b9"
							},
							{
								"_id": "849abeadb3f674f3d0150f8c",
								"_tpl": "64381b6e44b37a080d0245b9"
							},
							{
								"_id": "b1f644f258e1cf89d255a50d",
								"_tpl": "64381b6e44b37a080d0245b9"
							},
							{
								"_id": "bd0846135a51277898f95977",
								"_tpl": "5d6e6911a4b9361bd5780d52",
								"parentId": "82b6f2edbcc846f8fc77108d",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 3,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 3
								}
							},
							{
								"_id": "63db64cbf9963741dc0d741f",
								"_tpl": "64381b6e44b37a080d0245b9"
							},
							{
								"_id": "640b2d867f4185aa520d08ba",
								"_tpl": "64381b6e44b37a080d0245b9"
							},
							{
								"_id": "531debbc2805b55a806a8c70",
								"_tpl": "5839a40f24597726f856b511",
								"parentId": "e16dee62f9d7483fd0beb908",
								"slotId": "main",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"Foldable": {
										"Folded": false
									},
									"StackObjectsCount": 1
								},
								"location": {
									"x": 1,
									"y": 12,
									"r": "Horizontal",
									"isSearched": true
								}
							},
							{
								"_id": "26b7153267d090c7e38da092",
								"_tpl": "5839a7742459773cf9693481",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "mod_reciever",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"Foldable": {
										"Folded": false
									},
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "4eca657b0330534b397ab5d3",
								"_tpl": "59d36a0086f7747e673f3946",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "mod_gas_block",
								"upd": {
									"FireMode": {
										"FireMode": "single"
									},
									"Foldable": {
										"Folded": false
									},
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "e551bdc819b3b94b68b22796",
								"_tpl": "57ffa9f4245977728561e844",
								"parentId": "4eca657b0330534b397ab5d3",
								"slotId": "mod_handguard",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "28501e0555771b4dea9ceded",
								"_tpl": "56def37dd2720bec348b456a",
								"parentId": "e551bdc819b3b94b68b22796",
								"slotId": "mod_tactical_001",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "6c6783dd4d7e30c40a934762",
								"_tpl": "615d8f5dd92c473c770212ef",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "28fbe8303f9774eb6ea107e1",
								"_tpl": "615d8f8567085e45ef1409ca",
								"parentId": "6c6783dd4d7e30c40a934762",
								"slotId": "mod_muzzle",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "3f7cfcabeb87e2ec9d350aaa",
								"_tpl": "5b057b4f5acfc4771e1bd3e9",
								"parentId": "e551bdc819b3b94b68b22796",
								"slotId": "mod_foregrip",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "53de56e6dacd903fc7a4d8b9",
								"_tpl": "6087e663132d4d12c81fd96b",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "mod_pistol_grip",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8fe85ad1777ad5b12bca0910",
								"_tpl": "63d114019e35b334d82302f7",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "mod_mount_000",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "4097b09529da60d8a6e37104",
								"_tpl": "5b3b99475acfc432ff4dcbee",
								"parentId": "4a57fdf38fc3548f779fa5de",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "b72f13283e5a1c197b05bd4d",
								"_tpl": "59ecc3dd86f7746dc827481c",
								"parentId": "2c9d874904537de3a306b167",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "2c9d874904537de3a306b167",
								"_tpl": "59ecc28286f7746d7a68aa8c",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "mod_stock",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "4a57fdf38fc3548f779fa5de",
								"_tpl": "5b3b99265acfc4704b4a1afb",
								"parentId": "8fe85ad1777ad5b12bca0910",
								"slotId": "mod_scope",
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "2c440af16ad3ed23fc552915",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "e6704482ae7d525391049c02",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "7525ef6df0776b6b440f9a63",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "e7e734d07cfee8a4b125b9b3",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "6526113201000001e5644d74",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "patron_in_weapon",
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "e6704482ae7d525391049c02",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "531debbc2805b55a806a8c70",
								"slotId": "mod_magazine",
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "47d5f68778d80f2597826f09",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "b330c2a8b154d6401ab7afa1",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "051874615cf6010119a08cf4",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "b330c2a8b154d6401ab7afa1",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "e7e734d07cfee8a4b125b9b3",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "b330c2a8b154d6401ab7afa1",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "bfcc02567f33805f61b44268",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "b330c2a8b154d6401ab7afa1",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "3f0a1facbc4add3fb5bd232d",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "b330c2a8b154d6401ab7afa1",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "7ffc7f0b047adf425ef5b2fd",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "b330c2a8b154d6401ab7afa1",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "c1eb090bf8687bdcbe6b785c",
								"_tpl": "55d482194bdc2d1d4e8b456b",
								"parentId": "b330c2a8b154d6401ab7afa1",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1,
									"Repairable": {
										"Durability": 100,
										"MaxDurability": 100
									}
								}
							},
							{
								"_id": "f550ccd2829a2f37c8df26dd",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "051874615cf6010119a08cf4",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "eb5ae315c8f0d295387f14de",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "47d5f68778d80f2597826f09",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "652616bc01000001e5c18556",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"parentId": "bb363db77d34926599d768f0",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 0,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "329d48449efda15c3028935c",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8fe931ed90d3455d3e957c1a",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "8aa03b00aa7e9489a42f3919",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "3aa4200bd3c1b8473c35332b",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "3a55db74db148e8583be05c5",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "9bbea0c26839b44a6d90c75e",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "4e665ae1eb48f2fa2990fa35",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "e6f0ac6f2e2e3e5b732e4039",
								"_tpl": "618a431df1eb8e24b8741deb",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 5,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "b3dcd360d9ce9bf2a3e25019",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 0,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "c974759cdd69cafef76212dc",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 1,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "9c4e69fe204d8b1626be9db3",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 2,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "a357c9db137c2d8eebde7d35",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 3,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "a04a2790d2655d0c9a122598",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "13b52004e7fffcf3d1b00cd2",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 5,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "a6d1d46a236769ad641bc40e",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "9b57bd41428132f88f756c31",
								"_tpl": "617fd91e5539a84ec44ce155",
								"parentId": "cf70e23b122d7f020293a126",
								"slotId": "main",
								"location": {
									"x": 7,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 1
								}
							},
							{
								"_id": "65261b8e01000001e5da70ad",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "3f0a1facbc4add3fb5bd232d",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "65261bb401000001e564e251",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "c1eb090bf8687bdcbe6b785c",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "65261bb801000001e5237ce6",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "7ffc7f0b047adf425ef5b2fd",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "65261bc201000001e5a412af",
								"_tpl": "56dff026d2720bb8668b4567",
								"parentId": "bfcc02567f33805f61b44268",
								"slotId": "cartridges",
								"location": 0,
								"upd": {
									"StackObjectsCount": 60
								}
							},
							{
								"_id": "65261c9201000001e59f76da",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"parentId": "51023c6a29c60e2fbdaffaa7",
								"slotId": "main",
								"location": {
									"x": 6,
									"y": 6,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 500000,
									"SpawnedInSession": false
								}
							},
							{
								"_id": "65261cd801000001e598f029",
								"_tpl": "5449016a4bdc2d6f028b456f",
								"parentId": "ae739c40213c1aa034d94d00",
								"slotId": "main",
								"location": {
									"x": 4,
									"y": 4,
									"r": "Horizontal",
									"isSearched": true
								},
								"upd": {
									"StackObjectsCount": 250000
								}
							}
						],
						"equipment": "5fe49444ae6628187a2e77b8",
						"stash": "5fe49444ae6628187a2e78b8",
						"sortingTable": "60dca3da42ad9b706b369aca",
						"questRaidItems": "5fe49444ae6628187a2e78b9",
						"questStashItems": "5fe49444ae6628187a2e78ba",
						"fastPanel": {},
						"hideoutAreaStashes": {
							"24": "63db64cbf9963741dc0d741f",
							"25": "640b2d867f4185aa520d08ba"
						}
					},
					"Skills": {
						"Common": [{
								"Id": "BotReload",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "BotSound",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "Endurance",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Strength",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Vitality",
								"Progress": 3400,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Health",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "StressResistance",
								"Progress": 2500,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Metabolism",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Immunity",
								"Progress": 300,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Perception",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Intellect",
								"Progress": 50,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Attention",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Charisma",
								"Progress": 2200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Memory",
								"Progress": 5200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Pistol",
								"Progress": 150,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Revolver",
								"Progress": 50,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "SMG",
								"Progress": 900,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Assault",
								"Progress": 1200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Shotgun",
								"Progress": 800,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Sniper",
								"Progress": 600,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "LMG",
								"Progress": 120,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "HMG",
								"Progress": 20,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Launcher",
								"Progress": 20,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "AttachedLauncher",
								"Progress": 20,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Throwing",
								"Progress": 200,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Melee",
								"Progress": 20,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "DMR",
								"Progress": 900,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "RecoilControl",
								"Progress": 2100,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "AimDrills",
								"Progress": 1100,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "Surgery",
								"Progress": 900,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "CovertMovement",
								"Progress": 2500,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Search",
								"Progress": 2600,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "MagDrills",
								"Progress": 700,
								"PointsEarnedDuringSession": 0,
								"LastAccess": -2147483648
							}, {
								"Id": "Sniping",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "ProneMovement",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "FieldMedicine",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "FirstAid",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "LightVests",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "HeavyVests",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "WeaponModding",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "AdvancedModding",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "NightOps",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "SilentOps",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Lockpicking",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "WeaponTreatment",
								"Progress": 900,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Freetrading",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Auctions",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Cleanoperations",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Barter",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Shadowconnections",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Taskperformance",
								"Progress": 0,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "Crafting",
								"Progress": 500,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}, {
								"Id": "HideoutManagement",
								"Progress": 700,
								"PointsEarnedDuringSession": 0,
								"LastAccess": 0
							}
						],
						"Mastering": [],
						"Points": 0
					},
					"Stats": {
						"SessionCounters": null,
						"OverallCounters": {
							"Items": []
						},
						"SessionExperienceMult": 0,
						"ExperienceBonusMult": 0,
						"TotalSessionExperience": 0,
						"LastSessionDate": 0,
						"Aggressor": null,
						"DroppedItems": [],
						"FoundInRaidItems": [],
						"Victims": [],
						"CarriedQuestItems": [],
						"DamageHistory": {
							"LethalDamagePart": "Head",
							"LethalDamage": null,
							"BodyParts": []
						},
						"LastPlayerState": null,
						"TotalInGameTime": 0,
						"SurvivorClass": "Unknown"
					},
					"Encyclopedia": {
						"56dfef82d2720bbd668b4567": true,
						"57dc324a24597759501edc20": true,
						"57dc334d245977597164366f": true,
						"59d36a0086f7747e673f3946": true,
						"58864a4f2459770fcc257101": true,
						"5448be9a4bdc2dfd2f8b456a": true,
						"544fb45d4bdc2dee738b4568": true,
						"545cdae64bdc2d39198b4568": true,
						"545cdb794bdc2d3a198b456a": true,
						"590c678286f77426c9660122": true,
						"5645bc214bdc2d363b8b4571": true,
						"584984812459776a704a82a6": true,
						"59ccfdba86f7747f2109a587": true,
						"544fb3f34bdc2d03748b456a": true,
						"590c657e86f77412b013051d": true,
						"592c2d1a86f7746dbe2af32a": true,
						"567143bf4bdc2d1a0f8b4567": true,
						"59bffbb386f77435b379b9c2": true,
						"59bffc1f86f77435b128b872": true,
						"595cf16b86f77427440c32e2": true,
						"5644bd2b4bdc2d3b4c8b4572": true,
						"59c6633186f7740cf0493bb9": true,
						"5649b0544bdc2d1b2b8b458a": true,
						"576a581d2459771e7b1bc4f1": true,
						"576a7c512459771e796e0e17": true,
						"59984ab886f7743e98271174": true,
						"59985a8086f77414ec448d1a": true,
						"599860e986f7743bb57573a6": true,
						"59ccd11386f77428f24a488f": true,
						"55801eed4bdc2d89578b4588": true,
						"559ba5b34bdc2d1f1a8b4582": true,
						"5887431f2459777e1612938f": true,
						"56083e1b4bdc2dc8488b4572": true,
						"56083eab4bdc2d26448b456a": true,
						"560e620e4bdc2d724b8b456b": true,
						"56ea8222d2720b69698b4567": true,
						"58948c8e86f77409493f7266": true,
						"5894a51286f77426d13baf02": true,
						"5894a5b586f77426d2590767": true,
						"5894a2c386f77427140b8342": true,
						"58949dea86f77409483e16a8": true,
						"5894a42086f77426d2590762": true,
						"5894a73486f77426d259076c": true,
						"5894a81786f77427140b8347": true,
						"5894a13e86f7742405482982": true,
						"58949edd86f77409483e16a9": true,
						"55d7217a4bdc2d86028b456d": true,
						"557ffd194bdc2d28148b457f": true,
						"544a5cde4bdc2d39388b456b": true,
						"5857a8bc2459772bad15db29": true,
						"5ca20abf86f77418567a43f2": true,
						"564ca99c4bdc2d16268b4589": true,
						"57cd379a24597778e7682ecf": true,
						"57dc2fa62459775949412633": true,
						"57dc32dc245977596d4ef3d3": true,
						"57dc347d245977596754e7a1": true,
						"5649ad3f4bdc2df8348b4585": true,
						"5811ce772459770e9e5f9532": true,
						"5894a05586f774094708ef75": true,
						"5648b1504bdc2d9d488b4584": true,
						"5998597786f77414ea6da093": true,
						"599860ac86f77436b225ed1a": true,
						"599851db86f77467372f0a18": true,
						"5998517986f7746017232f7e": true,
						"576a63cd2459771e796e0e11": true,
						"576a5ed62459771e9c2096cb": true,
						"56d59d3ad2720bdb418b4577": true,
						"5448bd6b4bdc2dfc2f8b4569": true,
						"5448c12b4bdc2d02308b456f": true,
						"573718ba2459775a75491131": true,
						"5649b1c04bdc2d16268b457c": true,
						"5649af094bdc2df8348b4586": true,
						"5649aa744bdc2ded0b8b457e": true,
						"5648b0744bdc2d363b8b4578": true,
						"5696686a4bdc2da3298b456a": true,
						"5449016a4bdc2d6f028b456f": true,
						"57347d7224597744596b4e72": true,
						"544fb25a4bdc2dfb738b4567": true,
						"5448fee04bdc2dbc018b4567": true,
						"544fb3364bdc2d34748b456a": true,
						"5755356824597772cb798962": true,
						"5645bcc04bdc2d363b8b4572": true,
						"5751a25924597722c463c472": true,
						"544fb37f4bdc2dee738b4567": true,
						"5e831507ea0a7c419c2f9bd9": true,
						"5648a7494bdc2d9d488b4583": true,
						"544a11ac4bdc2d470e8b456a": true,
						"55d480c04bdc2d1d4e8b456a": true,
						"56dff3afd2720bba668b4567": true,
						"5aa2b87de5b5b00016327c25": true,
						"5bffdc370db834001d23eca8": true,
						"5ac4cd105acfc40016339859": true,
						"5ac50c185acfc400163398d4": true,
						"5ac72e475acfc400180ae6fe": true,
						"5ac50da15acfc4001718d287": true,
						"5649ade84bdc2d1b2b8b4587": true,
						"5ac7655e5acfc40016339a19": true,
						"5af0454c86f7746bf20992e8": true,
						"569668774bdc2da2298b4568": true,
						"5ab8f39486f7745cd93a1cca": true,
						"5aa7cfc0e5b5b00015693143": true,
						"5d02778e86f774203e7dedbe": true,
						"557ff21e4bdc2d89578b4586": true,
						"5710c24ad2720bc3458b45a3": true,
						"5d0a29fed7ad1a002769ad08": true,
						"5d0a3e8cd7ad1a6f6a3d35bd": true,
						"5d1b371186f774253763a656": true,
						"5ca20d5986f774331e7c9602": true,
						"590c5d4b86f774784e1b9c45": true,
						"5c0e53c886f7747fa54205c7": true,
						"5e870397991fd70db46995c8": true,
						"560d5e524bdc2d25448b4571": true,
						"5e87114fe2db31558c75a120": true,
						"5e87116b81c4ed43e83cefdd": true,
						"5e87080c81c4ed43e83cefda": true,
						"5e87076ce2db31558c75a11d": true,
						"5e87071478f43e51ca2de5e1": true,
						"5e8708d4ae379e67d22e0102": true,
						"590c695186f7741e566b64a2": true,
						"57347da92459774491567cf5": true,
						"5a0c27731526d80618476ac4": true,
						"5755383e24597772cb798966": true,
						"590c661e86f7741e566b646a": true,
						"5b432b965acfc47a8774094e": true,
						"5d40407c86f774318526545a": true,
						"56e294cdd2720b603a8b4575": true,
						"5c488a752e221602b412af63": true,
						"5c48a2852e221602b21d5923": true,
						"5c48a2a42e221602b66d1e07": true,
						"5c48a14f2e2216152006edd7": true,
						"55802d5f4bdc2dac148b458e": true,
						"5c48a2c22e221602b313fb6c": true,
						"55d4887d4bdc2d962f8b4570": true,
						"570fd6c2d2720bc6458b457f": true,
						"54527a984bdc2d4e668b4567": true,
						"5e8488fa988a8701445df1e4": true,
						"5c0e530286f7747fa1419862": true,
						"5f4f9eb969cdc30ff33f09db": true,
						"59e770b986f7742cbd762754": true,
						"5d02797c86f774203f38e30a": true,
						"5d5e9c74a4b9364855191c40": true,
						"5aafbde786f774389d0cbc0f": true,
						"544a5caa4bdc2d1a388b4568": true,
						"5d5d85c586f774279a21cbdb": true,
						"5d5d940f86f7742797262046": true,
						"5beed0f50db834001c062b12": true,
						"5beec1bd0db834001e6006f3": true,
						"5beec3420db834001b095429": true,
						"5beec3e30db8340019619424": true,
						"5beecbb80db834001d2c465e": true,
						"5beec8b20db834001961942a": true,
						"5beec8c20db834001d2c465c": true,
						"5bed625c0db834001c062946": true,
						"5beec91a0db834001961942d": true,
						"5beec9450db83400970084fd": true,
						"5bf3f59f0db834001a6fa060": true,
						"5beec8ea0db834001a6f9dbf": true,
						"5c0505e00db834001b735073": true,
						"5b432d215acfc4771e1c6624": true,
						"5c0e722886f7740458316a57": true,
						"5e2af4a786f7746d3f3c3400": true,
						"5e2af47786f7746d404f3aaa": true,
						"5b40e5e25acfc4001a599bea": true,
						"5d1b36a186f7742523398433": true,
						"5ed51652f6c34d2cc26336a1": true,
						"601aa3d2b2bcb34913271e6d": true,
						"609e860ebd219504d8507525": true
					},
					"ConditionCounters": {
						"Counters": []
					},
					"BackendCounters": {},
					"InsuredItems": [],
					"Hideout": {
					  "Areas": [
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 0
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 1
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 2
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 4,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 3
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [
							{
								"locationIndex": 0,
								"item": [
									{
										"_id": "4470522e79af690954d01d5f",
										"_tpl": "5d1b36a186f7742523398433",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 1,
								"item": [
									{
										"_id": "d1fdebc6941bc9a245fde51e",
										"_tpl": "5d1b36a186f7742523398433",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 2,
								"item": [
									{
										"_id": "dd35490a7b5b88afd1ea488f",
										"_tpl": "5d1b36a186f7742523398433",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 3,
								"item": [
									{
										"_id": "2e9e972b1f9d5161d794bbd1",
										"_tpl": "5d1b36a186f7742523398433",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 4,
								"item": [
									{
										"_id": "1c2b6e4825bb2ee68caa2a0c",
										"_tpl": "5d1b36a186f7742523398433",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 5,
								"item": [
									{
										"_id": "1c2b6e4825bb2ee68caa2a0d",
										"_tpl": "5d1b36a186f7742523398433",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 6
							},
							{
								"locationIndex": 7
							}
						  ],
						  "type": 4
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 5
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 6
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 7
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 8
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 9
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 10
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 11
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 12
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 1,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 13
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 1,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 14
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 15
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 0,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 16
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 1,
						  "passiveBonusesEnabled": false,
						"slots": [
							{
								"locationIndex": 0,
								"item": [
									{
										"_id": "aa83590c14a0e7d086cd21e9",
										"_tpl": "5d1b2f3f86f774252167a52c",
										"upd": {
											"StackObjectsCount": 1,
											"Resource": {
												"Value": 299.4528,
												"UnitsConsumed": 0.5472
											}
										}
									}
								]
							},
							{
								"locationIndex": 1,
								"item": [
									{
										"_id": "a16cab64ec8a2459367330d3",
										"_tpl": "5d1b2f3f86f774252167a52c",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 2,
								"item": [
									{
										"_id": "d04d42114f2d3f11173347d0",
										"_tpl": "5d1b2f3f86f774252167a52c",
										"upd": {
											"StackObjectsCount": 1
										}
									}
								]
							},
							{
								"locationIndex": 3
							},
							{
								"locationIndex": 4
							}
						],
						  "type": 17
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 1,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 18
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 1,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 19
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 3,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 20
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 0,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 21
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 6,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 22
						},
						{
						  "active": true,
						  "completeTime": 0,
						  "constructing": false,
						  "lastRecipe": "",
						  "level": 1,
						  "passiveBonusesEnabled": true,
						  "slots": [],
						  "type": 23
						},
						{
							"type": 24,
							"level": 3,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						},
						{
							"type": 25,
							"level": 0,
							"active": true,
							"passiveBonusesEnabled": true,
							"completeTime": 0,
							"constructing": false,
							"slots": [],
							"lastRecipe": ""
						}
					  ],
					  "Improvement": {},
					  "Production": {}
					},
					"Bonuses": [{
							"type": "StashSize",
							"templateId": "566abbc34bdc2d92178b4576"
						}, {
							"type": "StashSize",
							"templateId": "5811ce572459770cba1a34ea"
						}, {
							"type": "StashSize",
							"templateId": "5811ce662459770f6f490f32"
						}, {
							"type": "StashSize",
							"templateId": "5811ce772459770e9e5f9532"
						}
					],
					"Notes": {
						"Notes": []
					},
					"Quests": [],
					"TradersInfo": {},
					"RagfairInfo": {
						"rating": 2.0,
						"isRatingGrowing": true,
						"offers": []
					},
					"WishList": []
				},
				"suits": ["5cde9ec17d6c8b04723cf479", "5cde9e957d6c8b0474535da7"],
				"dialogues": {},
				"userbuilds": {
					"equipmentBuilds": [],
					"weaponbuilds": [
						{
							"id": "3b3df48a5189033240cbc490",
							"name": "SA58",
							"root": "268a56c49239447e1ceaf2f0",
							"items": [
								{
									"_id": "268a56c49239447e1ceaf2f0",
									"_tpl": "5b0bbe4e5acfc40dc528a72d",
									"upd": {
										"Repairable": {
											"MaxDurability": 100,
											"Durability": 100
										},
										"FireMode": {
											"FireMode": "single"
										}
									}
								},
								{
									"_id": "14e6c51cadf00ff41da0d5e4",
									"_tpl": "5b7d679f5acfc4001a5c4024",
									"parentId": "268a56c49239447e1ceaf2f0",
									"slotId": "mod_pistol_grip"
								},
								{
									"_id": "a0bf32a90791e34cf55c8889",
									"_tpl": "5b7d37845acfc400170e2f87",
									"parentId": "268a56c49239447e1ceaf2f0",
									"slotId": "mod_magazine"
								},
								{
									"_id": "f9f958bc2a535f5a2a5994c4",
									"_tpl": "5b7bedd75acfc43d825283f9",
									"parentId": "268a56c49239447e1ceaf2f0",
									"slotId": "mod_handguard"
								},
								{
									"_id": "2ca0e76f55698024d1608210",
									"_tpl": "5b7be1265acfc400161d0798",
									"parentId": "268a56c49239447e1ceaf2f0",
									"slotId": "mod_barrel"
								},
								{
									"_id": "49593fe441ed1bb418a23d70",
									"_tpl": "5b099bb25acfc400186331e8",
									"parentId": "268a56c49239447e1ceaf2f0",
									"slotId": "mod_reciever"
								},
								{
									"_id": "122f645f02ac5070d40ec012",
									"_tpl": "5b099bf25acfc4001637e683",
									"parentId": "268a56c49239447e1ceaf2f0",
									"slotId": "mod_stock"
								},
								{
									"_id": "0018dc299ec4e233f1111802",
									"_tpl": "58dd3ad986f77403051cba8f",
									"parentId": "268a56c49239447e1ceaf2f0",
									"slotId": "patron_in_weapon"
								},
								{
									"_id": "329780b1a5b0191b5493ab71",
									"_tpl": "58dd3ad986f77403051cba8f",
									"parentId": "a0bf32a90791e34cf55c8889",
									"slotId": "cartridges",
									"location": 0,
									"upd": {
										"StackObjectsCount": 29
									}
								},
								{
									"_id": "d772eac3df81c4173afd95a0",
									"_tpl": "5b7be46e5acfc400170e2dcf",
									"parentId": "f9f958bc2a535f5a2a5994c4",
									"slotId": "mod_mount_000"
								},
								{
									"_id": "c27a2b62eb2f6e3d56f1ea5e",
									"_tpl": "5b7be4575acfc400161d0832",
									"parentId": "f9f958bc2a535f5a2a5994c4",
									"slotId": "mod_mount_001"
								},
								{
									"_id": "44a111b0eb1c5088212616d9",
									"_tpl": "5cf78496d7f00c065703d6ca",
									"parentId": "2ca0e76f55698024d1608210",
									"slotId": "mod_muzzle"
								},
								{
									"_id": "e636adccbab8d85117da2291",
									"_tpl": "58491f3324597764bc48fa02",
									"parentId": "49593fe441ed1bb418a23d70",
									"slotId": "mod_scope",
									"upd": {
										"Sight": {
											"ScopesCurrentCalibPointIndexes": [
												0
											],
											"ScopesSelectedModes": [
												0
											],
											"SelectedScope": 0
										}
									}
								},
								{
									"_id": "a0d5cfad2d04e990c35cab5e",
									"_tpl": "5c793fb92e221644f31bfb64",
									"parentId": "122f645f02ac5070d40ec012",
									"slotId": "mod_stock_000"
								},
								{
									"_id": "5bc87d6ae3ebd09560912f67",
									"_tpl": "5c1cd46f2e22164bef5cfedb",
									"parentId": "d772eac3df81c4173afd95a0",
									"slotId": "mod_foregrip"
								},
								{
									"_id": "317417c865aaab8c69f76cdb",
									"_tpl": "5d2369418abbc306c62e0c80",
									"parentId": "c27a2b62eb2f6e3d56f1ea5e",
									"slotId": "mod_tactical",
									"upd": {
										"Light": {
											"IsActive": true,
											"SelectedMode": 0
										}
									}
								},
								{
									"_id": "64d2d540509a3d24c4595371",
									"_tpl": "5c878e9d2e2216000f201903",
									"parentId": "44a111b0eb1c5088212616d9",
									"slotId": "mod_muzzle_000"
								},
								{
									"_id": "450d68919c5ed85dc1d54db8",
									"_tpl": "5cf78720d7f00c06595bc93e",
									"parentId": "44a111b0eb1c5088212616d9",
									"slotId": "mod_muzzle_001"
								},
								{
									"_id": "4e55d882dada542c26d2f75c",
									"_tpl": "58d2947e86f77447aa070d53",
									"parentId": "a0d5cfad2d04e990c35cab5e",
									"slotId": "mod_stock_000"
								},
								{
									"_id": "5f7bac2b1e9b653ee1f74e61",
									"_tpl": "58d2912286f7744e27117493",
									"parentId": "4e55d882dada542c26d2f75c",
									"slotId": "mod_stock"
								}
								],
							"type": "weapon"
						},
						{
							"id": "562ebd1be9d329672e3618a0",
							"name": "G28",
							"root": "d81fce1f645deecd57ad52c6",
							"items": [
									{
										"_id": "d81fce1f645deecd57ad52c6",
										"_tpl": "6176aca650224f204c1da3fb",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "11655d5299e66de5d8cd0047",
										"_tpl": "5d025cc1d7ad1a53845279ef",
										"parentId": "d81fce1f645deecd57ad52c6",
										"slotId": "mod_pistol_grip"
									},
									{
										"_id": "47d753f952516b52152a5bec",
										"_tpl": "617131a4568c120fdd29482d",
										"parentId": "d81fce1f645deecd57ad52c6",
										"slotId": "mod_magazine"
									},
									{
										"_id": "d62d733470663b8eb70a281f",
										"_tpl": "617153016c780c1e710c9a2f",
										"parentId": "d81fce1f645deecd57ad52c6",
										"slotId": "mod_stock"
									},
									{
										"_id": "b60a02a394910dcd0b4bf3e1",
										"_tpl": "61713a8fd92c473c770214a4",
										"parentId": "d81fce1f645deecd57ad52c6",
										"slotId": "mod_reciever"
									},
									{
										"_id": "3f9a13303a52a4eeaeb3b3ca",
										"_tpl": "61702d8a67085e45ef140b24",
										"parentId": "d81fce1f645deecd57ad52c6",
										"slotId": "mod_charge"
									},
									{
										"_id": "d59692183de00bcd9e6e638c",
										"_tpl": "58dd3ad986f77403051cba8f",
										"parentId": "47d753f952516b52152a5bec",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 20
										}
									},
									{
										"_id": "521f5023b7318a4d5f40ea69",
										"_tpl": "617155ee50224f204c1da3cd",
										"parentId": "d62d733470663b8eb70a281f",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "09d27aa2822322aa602e92a0",
										"_tpl": "58491f3324597764bc48fa02",
										"parentId": "b60a02a394910dcd0b4bf3e1",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "cd3c784f37487a915c0a642f",
										"_tpl": "61702be9faa1272e431522c3",
										"parentId": "b60a02a394910dcd0b4bf3e1",
										"slotId": "mod_barrel"
									},
									{
										"_id": "89cff2adb72d2e19710be96d",
										"_tpl": "61703001d92c473c77021497",
										"parentId": "b60a02a394910dcd0b4bf3e1",
										"slotId": "mod_handguard"
									},
									{
										"_id": "58863afa5ed39c7dcf3a4491",
										"_tpl": "61715e7e67085e45ef140b33",
										"parentId": "521f5023b7318a4d5f40ea69",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "03f3887a0b0917503585f376",
										"_tpl": "5dfa3cd1b33c0951220c079b",
										"parentId": "cd3c784f37487a915c0a642f",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "8e4f4f6e5760b3162633c045",
										"_tpl": "61702f1b67085e45ef140b26",
										"parentId": "cd3c784f37487a915c0a642f",
										"slotId": "mod_gas_block"
									},
									{
										"_id": "ee6982f8894d41d2fdab6c59",
										"_tpl": "5a7dbfc1159bd40016548fde",
										"parentId": "89cff2adb72d2e19710be96d",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "f18c528e2ec002eebd066a24",
										"_tpl": "5d2369418abbc306c62e0c80",
										"parentId": "89cff2adb72d2e19710be96d",
										"slotId": "mod_tactical_002",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "1329ef0df744ea775dde3f57",
										"_tpl": "5dfa3d2b0dee1b22f862eade",
										"parentId": "03f3887a0b0917503585f376",
										"slotId": "mod_muzzle"
									}
								],
							"type": "weapon"
						},
						{
							"id": "f0f1c4f6ad973e4cdd31b3cc",
							"name": "UMP45",
							"root": "56b49630d8e5ae8fedb77c5d",
							"items": [
									{
										"_id": "56b49630d8e5ae8fedb77c5d",
										"_tpl": "5fc3e272f8b6a877a729eac5",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"Foldable": {
												"Folded": false
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "7d0032474bbf714d1239d64f",
										"_tpl": "5fc3e466187fea44d52eda90",
										"parentId": "56b49630d8e5ae8fedb77c5d",
										"slotId": "mod_magazine"
									},
									{
										"_id": "72ea143157ef48971bf4227d",
										"_tpl": "58491f3324597764bc48fa02",
										"parentId": "56b49630d8e5ae8fedb77c5d",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "c7119bf70d33862058766b91",
										"_tpl": "5fc3e4ee7283c4046c5814af",
										"parentId": "56b49630d8e5ae8fedb77c5d",
										"slotId": "mod_stock"
									},
									{
										"_id": "b5dddb73fb25280c4cd51bd9",
										"_tpl": "5fc3e4a27283c4046c5814ab",
										"parentId": "56b49630d8e5ae8fedb77c5d",
										"slotId": "mod_barrel"
									},
									{
										"_id": "dc6c6ec13c454eb4ecc36413",
										"_tpl": "5fc53954f8b6a877a729eaeb",
										"parentId": "56b49630d8e5ae8fedb77c5d",
										"slotId": "mod_mount_000"
									},
									{
										"_id": "ba308a3ba9dccf96b8a71923",
										"_tpl": "5fc5396e900b1d5091531e72",
										"parentId": "56b49630d8e5ae8fedb77c5d",
										"slotId": "mod_mount_001"
									},
									{
										"_id": "5272b636536f56867b7bf5bd",
										"_tpl": "5fc5396e900b1d5091531e72",
										"parentId": "56b49630d8e5ae8fedb77c5d",
										"slotId": "mod_mount_002"
									},
									{
										"_id": "640711061389e5c422dceac4",
										"_tpl": "5efb0fc6aeb21837e749c801",
										"parentId": "7d0032474bbf714d1239d64f",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 25
										}
									},
									{
										"_id": "d99e728e7ba0fcaa16facda7",
										"_tpl": "6130c4d51cb55961fa0fd49f",
										"parentId": "b5dddb73fb25280c4cd51bd9",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "292112a8a313f2c2bc8f6198",
										"_tpl": "59fc48e086f77463b1118392",
										"parentId": "dc6c6ec13c454eb4ecc36413",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "a1697b641d14d98854e2fbfc",
										"_tpl": "5d2369418abbc306c62e0c80",
										"parentId": "5272b636536f56867b7bf5bd",
										"slotId": "mod_tactical",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									}
								],
							"type": "weapon"
						},
						{
							"id": "07d3fa2df5541b17d8b3746d",
							"name": "Ash12",
							"root": "b0492383acd5a4b53301f849",
							"items": [
									{
										"_id": "b0492383acd5a4b53301f849",
										"_tpl": "5cadfbf7ae92152ac412eeef",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "06f729e3ec2cc7c2e007cf34",
										"_tpl": "5caf187cae92157c28402e43",
										"parentId": "b0492383acd5a4b53301f849",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "4a80df247da70a49478eddcd",
										"_tpl": "5caf1109ae9215753c44119f",
										"parentId": "b0492383acd5a4b53301f849",
										"slotId": "mod_magazine"
									},
									{
										"_id": "644659c1d1c295468af6fe8d",
										"_tpl": "5cdaa99dd7f00c002412d0b2",
										"parentId": "b0492383acd5a4b53301f849",
										"slotId": "mod_handguard"
									},
									{
										"_id": "e40feedc3242e1eb1f4b339c",
										"_tpl": "6171407e50224f204c1da3c5",
										"parentId": "b0492383acd5a4b53301f849",
										"slotId": "mod_scope"
									},
									{
										"_id": "2a41911ee1c30cc5ce2aac69",
										"_tpl": "5d2369418abbc306c62e0c80",
										"parentId": "b0492383acd5a4b53301f849",
										"slotId": "mod_tactical_002",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "ef23097795755cbfed95e6f4",
										"_tpl": "5cadf6eeae921500134b2799",
										"parentId": "4a80df247da70a49478eddcd",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 20
										}
									},
									{
										"_id": "f55f09db6d5707cb79e981e0",
										"_tpl": "5a7dbfc1159bd40016548fde",
										"parentId": "644659c1d1c295468af6fe8d",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "2661b729eaef9f43453b04b5",
										"_tpl": "5b3b99475acfc432ff4dcbee",
										"parentId": "e40feedc3242e1eb1f4b339c",
										"slotId": "mod_scope_000",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "a7e59cd2bf174ac63bfd3acc",
										"_tpl": "577d128124597739d65d0e56",
										"parentId": "e40feedc3242e1eb1f4b339c",
										"slotId": "mod_scope_001"
									},
									{
										"_id": "41517e6587a5a32db092babd",
										"_tpl": "577d141e24597739c5255e01",
										"parentId": "a7e59cd2bf174ac63bfd3acc",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									}
								],
							"type": "weapon"
						},
						{
							"id": "34efc571d0cec8ccf403549d",
							"name": "P90",
							"root": "dd843713676f27335a2e1cf2",
							"items": [
									{
										"_id": "dd843713676f27335a2e1cf2",
										"_tpl": "5cc82d76e24e8d00134b4b83",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "3176bde7a4b120c881e8548f",
										"_tpl": "5cc70093e4a949033c734312",
										"parentId": "dd843713676f27335a2e1cf2",
										"slotId": "mod_magazine"
									},
									{
										"_id": "fe8c9fbfba45b0c6cdff5c5a",
										"_tpl": "5cc700b9e4a949000f0f0f25",
										"parentId": "dd843713676f27335a2e1cf2",
										"slotId": "mod_stock"
									},
									{
										"_id": "ba4fd3a338a84993ae240496",
										"_tpl": "5cc700ede4a949033c734315",
										"parentId": "dd843713676f27335a2e1cf2",
										"slotId": "mod_reciever"
									},
									{
										"_id": "bf6e9893ab3007b659dc4b82",
										"_tpl": "5cc701aae4a949000e1ea45c",
										"parentId": "dd843713676f27335a2e1cf2",
										"slotId": "mod_barrel"
									},
									{
										"_id": "b42303c6a17eacea5ec94840",
										"_tpl": "5cc6ea85e4a949000e1ea3c3",
										"parentId": "dd843713676f27335a2e1cf2",
										"slotId": "mod_charge"
									},
									{
										"_id": "019781e3a852d7c1b317ced9",
										"_tpl": "5cc700cae4a949035e43ba72",
										"parentId": "fe8c9fbfba45b0c6cdff5c5a",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "a9bc42064c0a3fade8bfc145",
										"_tpl": "5cc7012ae4a949001252b43e",
										"parentId": "ba4fd3a338a84993ae240496",
										"slotId": "mod_mount_001"
									},
									{
										"_id": "1005b7f0273f44c276ab6e33",
										"_tpl": "58491f3324597764bc48fa02",
										"parentId": "ba4fd3a338a84993ae240496",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "630bc500ddeb1d8696b8f869",
										"_tpl": "5cc82796e24e8d000f5859a8",
										"parentId": "bf6e9893ab3007b659dc4b82",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "1bcab9783bcfcbafc084afd7",
										"_tpl": "5d2369418abbc306c62e0c80",
										"parentId": "a9bc42064c0a3fade8bfc145",
										"slotId": "mod_tactical",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "776dab288b2f085945d070df",
										"_tpl": "5cebec00d7f00c065c53522a",
										"parentId": "630bc500ddeb1d8696b8f869",
										"slotId": "mod_muzzle"
									}
								],
							"type": "weapon"
						},
						{
							"id": "7f23489af05b4840f3fb9f3a",
							"name": "Vector45",
							"root": "ee55b56a73c2c664ef3c70f1",
							"items": [
									{
										"_id": "ee55b56a73c2c664ef3c70f1",
										"_tpl": "5fb64bc92b1b027b1f50bcf2",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"Foldable": {
												"Folded": false
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "23d55299ee384a653e76bcc3",
										"_tpl": "5fb651dc85f90547f674b6f4",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_magazine"
									},
									{
										"_id": "ea34495c42869be39a9e703b",
										"_tpl": "5fb6567747ce63734e3fa1dc",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_sight_front",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "c73c714b24f597298304c6ae",
										"_tpl": "5fb6564947ce63734e3fa1da",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_sight_rear",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "5ddf0a2cbe6136ba90115046",
										"_tpl": "58491f3324597764bc48fa02",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "a937fddce820f072049dcfa0",
										"_tpl": "5fb655b748c711690e3a8d5a",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_stock"
									},
									{
										"_id": "939f445c327cf8e61e19d8ab",
										"_tpl": "5fb65363d1409e5ca04b54f5",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_barrel"
									},
									{
										"_id": "bcd026f643914c6ae8c99670",
										"_tpl": "5fbb976df9986c4cff3fe5f2",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_mount"
									},
									{
										"_id": "1e937b23ef67265a4d334be0",
										"_tpl": "5fce0f9b55375d18a253eff2",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_mount_001"
									},
									{
										"_id": "3ee1559ebae1365fbb2ec723",
										"_tpl": "5fce0f9b55375d18a253eff2",
										"parentId": "ee55b56a73c2c664ef3c70f1",
										"slotId": "mod_mount_002"
									},
									{
										"_id": "aab0b288f526f173ff41733f",
										"_tpl": "5efb0fc6aeb21837e749c801",
										"parentId": "23d55299ee384a653e76bcc3",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 30
										}
									},
									{
										"_id": "09243bb027055ed7a9ed9efb",
										"_tpl": "5c793fb92e221644f31bfb64",
										"parentId": "a937fddce820f072049dcfa0",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "26bbb6be4454334beffc5c09",
										"_tpl": "5fc4b992187fea44d52edaa9",
										"parentId": "939f445c327cf8e61e19d8ab",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "4bda6f829f0eb4e7334c0435",
										"_tpl": "5b057b4f5acfc4771e1bd3e9",
										"parentId": "bcd026f643914c6ae8c99670",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "d0c0c653d66374773df79818",
										"_tpl": "5d2369418abbc306c62e0c80",
										"parentId": "3ee1559ebae1365fbb2ec723",
										"slotId": "mod_tactical",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "521b09ae4e2cf9535d0d892e",
										"_tpl": "58d2947e86f77447aa070d53",
										"parentId": "09243bb027055ed7a9ed9efb",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "9c3d84ea579b955b330a92cb",
										"_tpl": "58d2912286f7744e27117493",
										"parentId": "521b09ae4e2cf9535d0d892e",
										"slotId": "mod_stock"
									},
									{
										"_id": "36f02a4e6c1572d218497142",
										"_tpl": "5fc4b9b17283c4046c5814d7",
										"parentId": "26bbb6be4454334beffc5c09",
										"slotId": "mod_muzzle"
									}
								],
							"type": "weapon"
						},
						{
							"id": "4ff8c007e93f82b11a9a5fa9",
							"name": "AK101",
							"root": "8894267b5447d86491e6b076",
							"items": [
									{
										"_id": "8894267b5447d86491e6b076",
										"_tpl": "5ac66cb05acfc40198510a10",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"Foldable": {
												"Folded": false
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "19dcb0cfd6c6da0d1fb4cb8b",
										"_tpl": "5b237e425acfc4771e1be0b6",
										"parentId": "8894267b5447d86491e6b076",
										"slotId": "mod_gas_block"
									},
									{
										"_id": "2c28dd603993e80e2d6c6bec",
										"_tpl": "5e21ca18e4d47f0da15e77dd",
										"parentId": "8894267b5447d86491e6b076",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "0533700f94cf6b7b314ddca7",
										"_tpl": "6087e663132d4d12c81fd96b",
										"parentId": "8894267b5447d86491e6b076",
										"slotId": "mod_pistol_grip"
									},
									{
										"_id": "6f85ed916c5bdf457ed62d80",
										"_tpl": "5d2c76ed48f03532f2136169",
										"parentId": "8894267b5447d86491e6b076",
										"slotId": "mod_reciever"
									},
									{
										"_id": "21094b0bd304cc739f39cf59",
										"_tpl": "5ac78eaf5acfc4001926317a",
										"parentId": "8894267b5447d86491e6b076",
										"slotId": "mod_stock"
									},
									{
										"_id": "40bbd7458ba10589bb458737",
										"_tpl": "5ac66c5d5acfc4001718d314",
										"parentId": "8894267b5447d86491e6b076",
										"slotId": "mod_magazine"
									},
									{
										"_id": "ab8def21f939c08cdc1bda02",
										"_tpl": "6130ca3fd92c473c77020dbd",
										"parentId": "8894267b5447d86491e6b076",
										"slotId": "mod_charge"
									},
									{
										"_id": "3f28ec4b3059d31ab70844b4",
										"_tpl": "5b4736a986f774040571e998",
										"parentId": "19dcb0cfd6c6da0d1fb4cb8b",
										"slotId": "mod_mount_000"
									},
									{
										"_id": "55a83285019e7405a9978701",
										"_tpl": "5b4736b986f77405cb415c10",
										"parentId": "19dcb0cfd6c6da0d1fb4cb8b",
										"slotId": "mod_mount_002"
									},
									{
										"_id": "626400a160d3c33527c3ddd8",
										"_tpl": "609269c3b0e443224b421cc1",
										"parentId": "2c28dd603993e80e2d6c6bec",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "814df26855e7ca7a943ead17",
										"_tpl": "58491f3324597764bc48fa02",
										"parentId": "6f85ed916c5bdf457ed62d80",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "51df4e5c437ee573050cd322",
										"_tpl": "59ecc3dd86f7746dc827481c",
										"parentId": "21094b0bd304cc739f39cf59",
										"slotId": "mod_stock"
									},
									{
										"_id": "6e8d128e68946dbf26ae6ad3",
										"_tpl": "54527ac44bdc2d36668b4567",
										"parentId": "40bbd7458ba10589bb458737",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 30
										}
									},
									{
										"_id": "2b078e87b6314b6c5608d67d",
										"_tpl": "5d2369418abbc306c62e0c80",
										"parentId": "3f28ec4b3059d31ab70844b4",
										"slotId": "mod_tactical",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "e5ca59760ba4d61f6c383b13",
										"_tpl": "5c1bc5af2e221602b412949b",
										"parentId": "55a83285019e7405a9978701",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "b9b422525155e731567bb439",
										"_tpl": "60926df0132d4d12c81fd9df",
										"parentId": "626400a160d3c33527c3ddd8",
										"slotId": "mod_muzzle"
									}
								],
							"type": "weapon"
						},
						{
							"id": "11c87363cd19eceabe638159",
							"name": "Mk47",
							"root": "bf8980bc113ec4791a7578ec",
							"items": [
									{
										"_id": "bf8980bc113ec4791a7578ec",
										"_tpl": "606587252535c57a13424cfd",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "800c1dd42086186db9b27e47",
										"_tpl": "59db3a1d86f77429e05b4e92",
										"parentId": "bf8980bc113ec4791a7578ec",
										"slotId": "mod_pistol_grip"
									},
									{
										"_id": "30009c25831bf560ba42e264",
										"_tpl": "59fafc5086f7740dbe19f6c3",
										"parentId": "bf8980bc113ec4791a7578ec",
										"slotId": "mod_magazine"
									},
									{
										"_id": "ed6f89a2665a153c678da0df",
										"_tpl": "606587a88900dc2d9a55b659",
										"parentId": "bf8980bc113ec4791a7578ec",
										"slotId": "mod_reciever"
									},
									{
										"_id": "7f9e10a098e98c2dafdb2755",
										"_tpl": "5c793fb92e221644f31bfb64",
										"parentId": "bf8980bc113ec4791a7578ec",
										"slotId": "mod_stock_001"
									},
									{
										"_id": "f02b0ec14947868d59cace71",
										"_tpl": "606587bd6d0bd7580617bacc",
										"parentId": "bf8980bc113ec4791a7578ec",
										"slotId": "mod_charge"
									},
									{
										"_id": "8a07795bcdcc997ea6db46aa",
										"_tpl": "59e0d99486f7744a32234762",
										"parentId": "30009c25831bf560ba42e264",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 30
										}
									},
									{
										"_id": "baaa1a1146ca63822a626fb3",
										"_tpl": "5b3b99265acfc4704b4a1afb",
										"parentId": "ed6f89a2665a153c678da0df",
										"slotId": "mod_scope"
									},
									{
										"_id": "ad94ba4220d7d98465df6a11",
										"_tpl": "6065878ac9cf8012264142fd",
										"parentId": "ed6f89a2665a153c678da0df",
										"slotId": "mod_barrel"
									},
									{
										"_id": "625a15f090de1fff4967a8a4",
										"_tpl": "5a329052c4a28200741e22d3",
										"parentId": "ed6f89a2665a153c678da0df",
										"slotId": "mod_handguard"
									},
									{
										"_id": "0c6fe1ea8b7794378d198839",
										"_tpl": "58d2946386f774496974c37e",
										"parentId": "7f9e10a098e98c2dafdb2755",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "45fba130ee5eb063bb60e62f",
										"_tpl": "5b3b99475acfc432ff4dcbee",
										"parentId": "baaa1a1146ca63822a626fb3",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "95ba5b45b2570067817da764",
										"_tpl": "5d443f8fa4b93678dd4a01aa",
										"parentId": "ad94ba4220d7d98465df6a11",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "1be56cb228a9f44041570ef5",
										"_tpl": "6065dc8a132d4d12c81fd8e3",
										"parentId": "ad94ba4220d7d98465df6a11",
										"slotId": "mod_gas_block"
									},
									{
										"_id": "e997b199a647951099030c27",
										"_tpl": "5c0102b20db834001d23eebc",
										"parentId": "625a15f090de1fff4967a8a4",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "3727df95f0a0c38c6c50c6ff",
										"_tpl": "5c0102aa0db834001b734ba1",
										"parentId": "625a15f090de1fff4967a8a4",
										"slotId": "mod_mount_004"
									},
									{
										"_id": "4919c86d0fc5d7e30fb1c28a",
										"_tpl": "5d44064fa4b9361e4f6eb8b5",
										"parentId": "95ba5b45b2570067817da764",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "9a70db3a18a4723d6ff6cea6",
										"_tpl": "5c1cd46f2e22164bef5cfedb",
										"parentId": "e997b199a647951099030c27",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "977d9b9caddfe67418330481",
										"_tpl": "5d2369418abbc306c62e0c80",
										"parentId": "3727df95f0a0c38c6c50c6ff",
										"slotId": "mod_tactical",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "25fdeeec5ab96a7be5598b02",
										"_tpl": "58d2912286f7744e27117493",
										"parentId": "0c6fe1ea8b7794378d198839",
										"slotId": "mod_stock"
									}
								],
							"type": "weapon"
						},
						{
							"id": "29ab50dd9de4109922143b4d",
							"name": "MP155",
							"root": "09c8416ab3b626d0bb9c4203",
							"items": [
									{
										"_id": "09c8416ab3b626d0bb9c4203",
										"_tpl": "606dae0ab0e443224b421bb7",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "0c3aa16f7d7826260f2dea1b",
										"_tpl": "6076c1b9f2cb2e02a42acedc",
										"parentId": "09c8416ab3b626d0bb9c4203",
										"slotId": "mod_barrel"
									},
									{
										"_id": "6c77ab9eac7260b91e5e4dd6",
										"_tpl": "606ee5c81246154cad35d65e",
										"parentId": "09c8416ab3b626d0bb9c4203",
										"slotId": "mod_handguard"
									},
									{
										"_id": "5cddb46707a40f7d55a2b246",
										"_tpl": "6076c87f232e5a31c233d50e",
										"parentId": "09c8416ab3b626d0bb9c4203",
										"slotId": "mod_magazine"
									},
									{
										"_id": "b7548e57ce7aeb68a05567b2",
										"_tpl": "606eef46232e5a31c233d500",
										"parentId": "09c8416ab3b626d0bb9c4203",
										"slotId": "mod_stock"
									},
									{
										"_id": "e31af76495fac565713a7eb7",
										"_tpl": "60785ce5132d4d12c81fd918",
										"parentId": "09c8416ab3b626d0bb9c4203",
										"slotId": "mod_mount"
									},
									{
										"_id": "93d4c7c2bca28b15fae6ddc7",
										"_tpl": "5d6e6911a4b9361bd5780d52",
										"parentId": "09c8416ab3b626d0bb9c4203",
										"slotId": "patron_in_weapon"
									},
									{
										"_id": "d33a81fee5d1c8ec8c3a295f",
										"_tpl": "5c0111ab0db834001966914d",
										"parentId": "0c3aa16f7d7826260f2dea1b",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "3a61ccabd0bf24e2a7aca587",
										"_tpl": "607ea812232e5a31c233d53c",
										"parentId": "6c77ab9eac7260b91e5e4dd6",
										"slotId": "mod_mount_000"
									},
									{
										"_id": "aa742043879d660821d21e69",
										"_tpl": "5d6e6911a4b9361bd5780d52",
										"parentId": "5cddb46707a40f7d55a2b246",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 6
										}
									},
									{
										"_id": "5a66fce868a726cb6f6b2533",
										"_tpl": "606eef756d0bd7580617baf8",
										"parentId": "b7548e57ce7aeb68a05567b2",
										"slotId": "mod_stock"
									},
									{
										"_id": "9e29e86421bb8d7cecea9347",
										"_tpl": "570fd6c2d2720bc6458b457f",
										"parentId": "e31af76495fac565713a7eb7",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "05ef173908038174012f7723",
										"_tpl": "59c0ec5b86f77435b128bfca",
										"parentId": "d33a81fee5d1c8ec8c3a295f",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "0a8cd85c07d8b5b1da1f93fa",
										"_tpl": "56def37dd2720bec348b456a",
										"parentId": "3a61ccabd0bf24e2a7aca587",
										"slotId": "mod_tactical",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "3072a88ea2d551681b4585f3",
										"_tpl": "606f262c6d0bd7580617bafa",
										"parentId": "5a66fce868a726cb6f6b2533",
										"slotId": "mod_stock"
									},
									{
										"_id": "fe3b24c20ddebf7fcbaaabe3",
										"_tpl": "606f2696f2cb2e02a42aceb1",
										"parentId": "5a66fce868a726cb6f6b2533",
										"slotId": "mod_tactical",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									}
								],
							"type": "weapon"
						},
						{
							"id": "e7936630a2c0d64112788602",
							"name": "M4A1",
							"root": "a480cb04e8a1b3c03862fe07",
							"items": [
									{
										"_id": "a480cb04e8a1b3c03862fe07",
										"_tpl": "5447a9cd4bdc2dbd208b4567",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "96527a4d089c2c18dceb3f0c",
										"_tpl": "59db3a1d86f77429e05b4e92",
										"parentId": "a480cb04e8a1b3c03862fe07",
										"slotId": "mod_pistol_grip"
									},
									{
										"_id": "4e51c8127df4928348601c51",
										"_tpl": "59bfe68886f7746004266202",
										"parentId": "a480cb04e8a1b3c03862fe07",
										"slotId": "mod_reciever"
									},
									{
										"_id": "495e0c756611d7f78c09316f",
										"_tpl": "5c793fb92e221644f31bfb64",
										"parentId": "a480cb04e8a1b3c03862fe07",
										"slotId": "mod_stock"
									},
									{
										"_id": "7d4c825194094be438766b93",
										"_tpl": "5b2240bf5acfc40dc528af69",
										"parentId": "a480cb04e8a1b3c03862fe07",
										"slotId": "mod_charge"
									},
									{
										"_id": "bb24af9074b5381f25076b61",
										"_tpl": "5b3b99265acfc4704b4a1afb",
										"parentId": "4e51c8127df4928348601c51",
										"slotId": "mod_scope"
									},
									{
										"_id": "146ff2e06ae76487ee013faf",
										"_tpl": "55d3632e4bdc2d972f8b4569",
										"parentId": "4e51c8127df4928348601c51",
										"slotId": "mod_barrel"
									},
									{
										"_id": "9980bcc79fc7ed2c77c17fa3",
										"_tpl": "5c78f2492e221600114c9f04",
										"parentId": "4e51c8127df4928348601c51",
										"slotId": "mod_handguard"
									},
									{
										"_id": "f355f3cd68c31215acf4deda",
										"_tpl": "58d2947e86f77447aa070d53",
										"parentId": "495e0c756611d7f78c09316f",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "4713eb2e0312ec140cb5a229",
										"_tpl": "618ba27d9008e4636a67f61d",
										"parentId": "bb24af9074b5381f25076b61",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									},
									{
										"_id": "39cc988aa9e78e471813ef3f",
										"_tpl": "609269c3b0e443224b421cc1",
										"parentId": "146ff2e06ae76487ee013faf",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "1dea65169749146969e81937",
										"_tpl": "5d00ec68d7ad1a04a067e5be",
										"parentId": "146ff2e06ae76487ee013faf",
										"slotId": "mod_gas_block"
									},
									{
										"_id": "1da200de64995349172abf37",
										"_tpl": "5b7be4895acfc400170e2dd5",
										"parentId": "9980bcc79fc7ed2c77c17fa3",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "be720edc664af932932f3788",
										"_tpl": "56def37dd2720bec348b456a",
										"parentId": "9980bcc79fc7ed2c77c17fa3",
										"slotId": "mod_tactical_003",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "f1f3f0f0cab7992d9bf29d7a",
										"_tpl": "60926df0132d4d12c81fd9df",
										"parentId": "39cc988aa9e78e471813ef3f",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "2747648813a2ecae05b81a42",
										"_tpl": "58d2912286f7744e27117493",
										"parentId": "f355f3cd68c31215acf4deda",
										"slotId": "mod_stock"
									}
								],
							"type": "weapon"
						},
						{
							"id": "efa26b788869e44e1aba2b26",
							"name": "RD704",
							"root": "44e5329adcc29bd81bff85fc",
							"items": [
									{
										"_id": "44e5329adcc29bd81bff85fc",
										"_tpl": "628a60ae6b1d481ff772e9c8",
										"upd": {
											"Repairable": {
												"MaxDurability": 100,
												"Durability": 100
											},
											"FireMode": {
												"FireMode": "single"
											}
										}
									},
									{
										"_id": "2dc061942241070991bfab9b",
										"_tpl": "628a83c29179c324ed269508",
										"parentId": "44e5329adcc29bd81bff85fc",
										"slotId": "mod_gas_block"
									},
									{
										"_id": "d51608fb1de72820d5f10c97",
										"_tpl": "6130c43c67085e45ef1405a1",
										"parentId": "44e5329adcc29bd81bff85fc",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "a96c305883f093ae74bd5424",
										"_tpl": "628c9ab845c59e5b80768a81",
										"parentId": "44e5329adcc29bd81bff85fc",
										"slotId": "mod_pistol_grip"
									},
									{
										"_id": "64bc890dbd65cafbe592218f",
										"_tpl": "5d2c772c48f0355d95672c25",
										"parentId": "44e5329adcc29bd81bff85fc",
										"slotId": "mod_reciever"
									},
									{
										"_id": "7e8845a9b18030a1c0de32be",
										"_tpl": "5b0e794b5acfc47a877359b2",
										"parentId": "44e5329adcc29bd81bff85fc",
										"slotId": "mod_stock_000"
									},
									{
										"_id": "763f09c02bffc9aca1a8f4de",
										"_tpl": "5cfe8010d7ad1a59283b14c6",
										"parentId": "44e5329adcc29bd81bff85fc",
										"slotId": "mod_magazine"
									},
									{
										"_id": "5449e333954dbdfd9f958c66",
										"_tpl": "6130ca3fd92c473c77020dbd",
										"parentId": "44e5329adcc29bd81bff85fc",
										"slotId": "mod_charge"
									},
									{
										"_id": "c37c96576051f4d23e4ea2db",
										"_tpl": "5b7be47f5acfc400170e2dd2",
										"parentId": "2dc061942241070991bfab9b",
										"slotId": "mod_mount_001"
									},
									{
										"_id": "c9e15cddb62d39dc65b50734",
										"_tpl": "5b7be4895acfc400170e2dd5",
										"parentId": "2dc061942241070991bfab9b",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "7d11292f9e8628dc4c59ed7d",
										"_tpl": "5dfa3d2b0dee1b22f862eade",
										"parentId": "d51608fb1de72820d5f10c97",
										"slotId": "mod_muzzle"
									},
									{
										"_id": "1265b311600dd9dca3899141",
										"_tpl": "5b3b99265acfc4704b4a1afb",
										"parentId": "64bc890dbd65cafbe592218f",
										"slotId": "mod_scope"
									},
									{
										"_id": "f73ae9db60fca0dcfa6bd0eb",
										"_tpl": "601aa3d2b2bcb34913271e6d",
										"parentId": "763f09c02bffc9aca1a8f4de",
										"slotId": "cartridges",
										"location": 0,
										"upd": {
											"StackObjectsCount": 50
										}
									},
									{
										"_id": "147ebcb14d43d9b3441de5aa",
										"_tpl": "56def37dd2720bec348b456a",
										"parentId": "c37c96576051f4d23e4ea2db",
										"slotId": "mod_tactical",
										"upd": {
											"Light": {
												"IsActive": true,
												"SelectedMode": 0
											}
										}
									},
									{
										"_id": "30191c0ea06acb1487748514",
										"_tpl": "5b057b4f5acfc4771e1bd3e9",
										"parentId": "c9e15cddb62d39dc65b50734",
										"slotId": "mod_foregrip"
									},
									{
										"_id": "94808546f03f64c618ffb670",
										"_tpl": "618ba27d9008e4636a67f61d",
										"parentId": "1265b311600dd9dca3899141",
										"slotId": "mod_scope",
										"upd": {
											"Sight": {
												"ScopesCurrentCalibPointIndexes": [
													0
												],
												"ScopesSelectedModes": [
													0
												],
												"SelectedScope": 0
											}
										}
									}
								]
							"type": "weapon"
						},
						{
							"id": "8f61a5c00644d135c67fc3ae",
							"name": "SaigaHeatGun",
							"root": "ab715e668bfed1cfed1f91f6",
							"items": [
								{
									"_id": "ab715e668bfed1cfed1f91f6",
									"_tpl": "576165642459773c7a400233",
									"upd": {
										"Repairable": {
											"MaxDurability": 100,
											"Durability": 97.3092346
										},
										"Foldable": {
											"Folded": false
										},
										"FireMode": {
											"FireMode": "single"
										}
									}
								},
								{
									"_id": "c37b6e8db9e02f68a7b0b205",
									"_tpl": "591ee00d86f774592f7b841e",
									"parentId": "ab715e668bfed1cfed1f91f6",
									"slotId": "mod_mount_000"
								},
								{
									"_id": "a8273f2d83d73d211ecfb060",
									"_tpl": "5f63418ef5750b524b45f116",
									"parentId": "ab715e668bfed1cfed1f91f6",
									"slotId": "mod_handguard"
								},
								{
									"_id": "ea37a0f44e5814f36c464907",
									"_tpl": "59fb137a86f7740adb646af1",
									"parentId": "ab715e668bfed1cfed1f91f6",
									"slotId": "mod_muzzle"
								},
								{
									"_id": "77a260b159890af2d288fdba",
									"_tpl": "5649ade84bdc2d1b2b8b4587",
									"parentId": "ab715e668bfed1cfed1f91f6",
									"slotId": "mod_pistol_grip"
								},
								{
									"_id": "ec70d5ae3370caa7523c235d",
									"_tpl": "57616c112459773cce774d66",
									"parentId": "ab715e668bfed1cfed1f91f6",
									"slotId": "mod_reciever"
								},
								{
									"_id": "d4f753770b21d22c173b6388",
									"_tpl": "57a9b9ce2459770ee926038d",
									"parentId": "ab715e668bfed1cfed1f91f6",
									"slotId": "mod_sight_rear",
									"upd": {
										"Sight": {
											"ScopesCurrentCalibPointIndexes": [
												0
											],
											"ScopesSelectedModes": [
												0
											],
											"SelectedScope": 0
										}
									}
								},
								{
									"_id": "6465cc5dbfc471ed62e6e307",
									"_tpl": "57616ca52459773c69055192",
									"parentId": "ab715e668bfed1cfed1f91f6",
									"slotId": "mod_stock"
								},
								{
									"_id": "f36d8744787a4e14b173e784",
									"_tpl": "5cf8f3b0d7f00c00217872ef",
									"parentId": "ab715e668bfed1cfed1f91f6",
									"slotId": "mod_magazine"
								},
								{
									"_id": "7cfc70b9511b672862bac01f",
									"_tpl": "5d6e6911a4b9361bd5780d52",
									"parentId": "ab715e668bfed1cfed1f91f6",
									"slotId": "patron_in_weapon",
									"upd": {
										"SpawnedInSession": true
									}
								},
								{
									"_id": "c3b649a3bd05004c39df5b30",
									"_tpl": "58491f3324597764bc48fa02",
									"parentId": "c37b6e8db9e02f68a7b0b205",
									"slotId": "mod_scope",
									"upd": {
										"Sight": {
											"ScopesCurrentCalibPointIndexes": [
												0
											],
											"ScopesSelectedModes": [
												0
											],
											"SelectedScope": 0
										}
									}
								},
								{
									"_id": "5dd9146c4240ad0f261aa632",
									"_tpl": "5b3a337e5acfc4704b4a19a0",
									"parentId": "c37b6e8db9e02f68a7b0b205",
									"slotId": "mod_tactical",
									"upd": {
										"Light": {
											"IsActive": true,
											"SelectedMode": 0
										}
									}
								},
								{
									"_id": "deac8a783d49d7b7968e6231",
									"_tpl": "5b057b4f5acfc4771e1bd3e9",
									"parentId": "a8273f2d83d73d211ecfb060",
									"slotId": "mod_foregrip"
								},
								{
									"_id": "531dec36a1e67d21b0e30d6c",
									"_tpl": "5a7b483fe899ef0016170d15",
									"parentId": "a8273f2d83d73d211ecfb060",
									"slotId": "mod_tactical_000",
									"upd": {
										"Light": {
											"IsActive": true,
											"SelectedMode": 0
										}
									}
								},
								{
									"_id": "6444508f936302693101a5b4",
									"_tpl": "5b3a337e5acfc4704b4a19a0",
									"parentId": "a8273f2d83d73d211ecfb060",
									"slotId": "mod_tactical_001",
									"upd": {
										"Light": {
											"IsActive": true,
											"SelectedMode": 0
										}
									}
								},
								{
									"_id": "34384c12698839b7f8c663c6",
									"_tpl": "5b3a337e5acfc4704b4a19a0",
									"parentId": "a8273f2d83d73d211ecfb060",
									"slotId": "mod_tactical_002",
									"upd": {
										"Light": {
											"IsActive": true,
											"SelectedMode": 0
										}
									}
								},
								{
									"_id": "7cd1305b8f9947e5c060e7fe",
									"_tpl": "5b3a337e5acfc4704b4a19a0",
									"parentId": "a8273f2d83d73d211ecfb060",
									"slotId": "mod_tactical_003",
									"upd": {
										"Light": {
											"IsActive": true,
											"SelectedMode": 0
										}
									}
								},
								{
									"_id": "cbf28972b861cb17366606b6",
									"_tpl": "5b3a337e5acfc4704b4a19a0",
									"parentId": "a8273f2d83d73d211ecfb060",
									"slotId": "mod_tactical_004",
									"upd": {
										"Light": {
											"IsActive": true,
											"SelectedMode": 0
										}
									}
								},
								{
									"_id": "dd3468f45e087cbb5bfb0235",
									"_tpl": "5a0c59791526d8dba737bba7",
									"parentId": "6465cc5dbfc471ed62e6e307",
									"slotId": "mod_stock"
								},
								{
									"_id": "200259b6189aa5b783c4193a",
									"_tpl": "5d6e6911a4b9361bd5780d52",
									"parentId": "f36d8744787a4e14b173e784",
									"slotId": "cartridges",
									"location": 0,
									"upd": {
										"StackObjectsCount": 8
									}
								}
							]
						}
					],
				},				
				"trader": {
					"initialLoyaltyLevel": 4,
					"initialStanding": 6.5,
					"initialSalesSum": 10000000,
					"jaegerUnlocked": true
				}
			}
		}
    }

}
    
module.exports = { mod: new GigaChad() }